@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -70,6 +70,11 @@
 #define MOD_CFG_VIEW_1          "VIEW_1"
 #define MOD_CFG_VIEW_2          "VIEW_2"
 #define MOD_CFG_VIEW_3          "VIEW_3"
+#define MOD_CFG_STATE           "STATE"
+#define MOD_CFG_WIN_POS_X       "WIN_POS_X"
+#define MOD_CFG_WIN_POS_Y       "WIN_POS_Y"
+#define MOD_CFG_WIN_WIDTH       "WIN_WIDTH"
+#define MOD_CFG_WIN_HEIGHT      "WIN_HEIGHT"
 
 /* list specific */
 #define MOD_CFG_LIST_SECTION   "LIST"
