@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -41,7 +41,7 @@
 #include "gpredict-utils.h"
 #include "gtk-azel-plot.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include <goocanvas.h>
 
@@ -58,23 +58,23 @@
 #define MARKER_SIZE 5
 
 
-static void gtk_azel_plot_class_init  (GtkAzelPlotClass *class);
-static void gtk_azel_plot_init        (GtkAzelPlot *polview);
-static void gtk_azel_plot_destroy     (GtkObject *object);
-static void size_allocate_cb           (GtkWidget *widget,
-										GtkAllocation *allocation,
-										gpointer data);
-static gboolean on_motion_notify       (GooCanvasItemView *view,
-										GooCanvasItemView *target,
-										GdkEventMotion *event,
-										gpointer data);
-static void on_item_view_created       (GooCanvasView     *view,
-										GooCanvasItemView *item_view,
-										GooCanvasItem     *item,
-										gpointer           data);
-static void on_canvas_realized         (GtkWidget *canvas, gpointer data);
-static GooCanvasModelSimple* create_canvas_model (GtkAzelPlot *polv);
-static void get_canvas_bg_color        (GtkAzelPlot *polv, GdkColor *color);
+static void gtk_azel_plot_class_init    (GtkAzelPlotClass *class);
+static void gtk_azel_plot_init          (GtkAzelPlot *polview);
+static void gtk_azel_plot_destroy       (GtkObject *object);
+static void size_allocate_cb            (GtkWidget *widget,
+										 GtkAllocation *allocation,
+										 gpointer data);
+static gboolean on_motion_notify        (GooCanvasItem *item,
+										 GooCanvasItem *target,
+										 GdkEventMotion *event,
+										 gpointer data);
+static void on_item_created             (GooCanvas *canvas,
+										 GooCanvasItem *item,
+										 GooCanvasItemModel *model,
+										 gpointer data);
+static void on_canvas_realized          (GtkWidget *canvas, gpointer data);
+static GooCanvasItemModel* create_canvas_model (GtkAzelPlot *polv);
+static void get_canvas_bg_color         (GtkAzelPlot *polv, GdkColor *color);
 static void xy_to_graph (GtkAzelPlot *p, gfloat x, gfloat y, gdouble *t, gdouble *az, gdouble *el);
 static void az_to_xy (GtkAzelPlot *p, gdouble t, gdouble az, gdouble *x, gdouble *y);
 static void el_to_xy (GtkAzelPlot *p, gdouble t, gdouble el, gdouble *x, gdouble *y);
@@ -147,6 +147,7 @@ gtk_azel_plot_init (GtkAzelPlot *polview)
 	polview->extratick = FALSE;
 }
 
+
 static void
 gtk_azel_plot_destroy (GtkObject *object)
 {
@@ -155,7 +156,6 @@ gtk_azel_plot_destroy (GtkObject *object)
 }
 
 
-
 /** \brief Create a new GtkAzelPlot widget.
  *  \param cfgdata The configuration data of the parent module.
  *  \param sats Pointer to the hash table containing the asociated satellites.
@@ -165,12 +165,11 @@ GtkWidget*
 gtk_azel_plot_new (qth_t *qth, pass_t *pass)
 {
 	GtkWidget *polv;
-	GooCanvasModelSimple *canvas_model;
+	GooCanvasItemModel *root;
 	GdkColor bg_color = {0, 0xFFFF, 0xFFFF, 0xFFFF};
 	guint i,n;
 	pass_detail_t *detail;
 
-
 	polv = g_object_new (GTK_TYPE_AZEL_PLOT, NULL);
 
 	GTK_AZEL_PLOT (polv)->qth  = qth;
@@ -197,19 +196,19 @@ gtk_azel_plot_new (qth_t *qth, pass_t *pass)
 		GTK_AZEL_PLOT (polv)->maxaz = 180.0;
 
 	/* create the canvas */
-	GTK_AZEL_PLOT (polv)->canvas = goo_canvas_view_new ();
+	GTK_AZEL_PLOT (polv)->canvas = goo_canvas_new ();
 	get_canvas_bg_color (GTK_AZEL_PLOT (polv), &bg_color);
 	gtk_widget_modify_base (GTK_AZEL_PLOT (polv)->canvas, GTK_STATE_NORMAL, &bg_color);
 	gtk_widget_set_size_request (GTK_AZEL_PLOT (polv)->canvas,
 								 POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
-	goo_canvas_view_set_bounds (GOO_CANVAS_VIEW (GTK_AZEL_PLOT (polv)->canvas), 0, 0,
+	goo_canvas_set_bounds (GOO_CANVAS (GTK_AZEL_PLOT (polv)->canvas), 0, 0,
 								POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
 
 	/* connect size-request signal */
 	g_signal_connect (GTK_AZEL_PLOT (polv)->canvas, "size-allocate",
 					  G_CALLBACK (size_allocate_cb), polv);
-	g_signal_connect (GTK_AZEL_PLOT (polv)->canvas, "item_view_created",
-					  (GtkSignalFunc) on_item_view_created, polv);
+	g_signal_connect (GTK_AZEL_PLOT (polv)->canvas, "item_created",
+					  (GtkSignalFunc) on_item_created, polv);
 	g_signal_connect_after (GTK_AZEL_PLOT (polv)->canvas, "realize",
 							(GtkSignalFunc) on_canvas_realized, polv);
 
@@ -217,10 +216,10 @@ gtk_azel_plot_new (qth_t *qth, pass_t *pass)
 
 
 	/* Create the canvas model */
-	canvas_model = create_canvas_model (GTK_AZEL_PLOT (polv));
-	goo_canvas_view_set_model (GOO_CANVAS_VIEW (GTK_AZEL_PLOT (polv)->canvas),
-							   GOO_CANVAS_MODEL (canvas_model));
-	g_object_unref (canvas_model);
+	root = create_canvas_model (GTK_AZEL_PLOT (polv));
+	goo_canvas_set_root_item_model (GOO_CANVAS (GTK_AZEL_PLOT (polv)->canvas), root);
+
+	g_object_unref (root);
 
 	gtk_container_add (GTK_CONTAINER (polv), GTK_AZEL_PLOT (polv)->canvas);
 
@@ -228,11 +227,10 @@ gtk_azel_plot_new (qth_t *qth, pass_t *pass)
 }
 
 
-static GooCanvasModelSimple *
+static GooCanvasItemModel *
 create_canvas_model (GtkAzelPlot *polv)
 {
-	GooCanvasModelSimple *canvas_model;
-	GooCanvasItem *root;
+	GooCanvasItemModel *root;
 	guint32 col;
 	guint i;
 	gdouble xstep,ystep;
@@ -241,10 +239,7 @@ create_canvas_model (GtkAzelPlot *polv)
 	gchar  buff[7];
 	gchar *txt;
 
-
-	canvas_model = goo_canvas_model_simple_new ();
-
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_group_model_new (NULL, NULL);
 
 	/* graph dimensions */
 	polv->width = POLV_DEFAULT_SIZE;
@@ -259,16 +254,16 @@ create_canvas_model (GtkAzelPlot *polv)
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_AXIS_COL);
 
 	/* frame */
-	polv->frame = goo_canvas_rect_new (root,
-									   (gdouble) polv->x0,
-									   (gdouble) polv->ymax,
-									   (gdouble) (polv->xmax - polv->x0),
-									   (gdouble) (polv->y0 - POLV_Y_MARGIN),
-									   "stroke-color-rgba", 0x000000FF,
-									   "line-cap", CAIRO_LINE_CAP_SQUARE,
-									   "line-join", CAIRO_LINE_JOIN_MITER,
-									   "line-width", 1.0,
-									   NULL);
+	polv->frame = goo_canvas_rect_model_new (root,
+											 (gdouble) polv->x0,
+											 (gdouble) polv->ymax,
+											 (gdouble) (polv->xmax - polv->x0),
+											 (gdouble) (polv->y0 - POLV_Y_MARGIN),
+											 "stroke-color-rgba", 0x000000FF,
+											 "line-cap", CAIRO_LINE_CAP_SQUARE,
+											 "line-join", CAIRO_LINE_JOIN_MITER,
+											 "line-width", 1.0,
+											 NULL);
 
 	xstep = (polv->xmax - polv->x0) / (AZEL_PLOT_NUM_TICKS+1); 
 	ystep = (polv->y0 - polv->ymax) / (AZEL_PLOT_NUM_TICKS+1);
@@ -277,28 +272,28 @@ create_canvas_model (GtkAzelPlot *polv)
 	for (i = 0; i < AZEL_PLOT_NUM_TICKS; i++) {
 
 		/* bottom x tick marks */
-		polv->xticksb[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) (polv->x0 + (i+1) * xstep),
-														 (gdouble) polv->y0,
-														 (gdouble) (polv->x0 + (i+1) * xstep),
-														 (gdouble) (polv->y0 - MARKER_SIZE),
-														 "fill-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 1.0,
-														 NULL);
+		polv->xticksb[i] = goo_canvas_polyline_model_new_line (root,
+															  (gdouble) (polv->x0 + (i+1) * xstep),
+															  (gdouble) polv->y0,
+															  (gdouble) (polv->x0 + (i+1) * xstep),
+															  (gdouble) (polv->y0 - MARKER_SIZE),
+															  "fill-color-rgba", col,
+															  "line-cap", CAIRO_LINE_CAP_SQUARE,
+															  "line-join", CAIRO_LINE_JOIN_MITER,
+															  "line-width", 1.0,
+															  NULL);
 
 		/* top x tick marks */
-		polv->xtickst[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) (polv->x0 + (i+1) * xstep),
-														 (gdouble) polv->ymax,
-														 (gdouble) (polv->x0 + (i+1) * xstep),
-														 (gdouble) (polv->ymax + MARKER_SIZE),
-														 "fill-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 1.0,
-														 NULL);
+		polv->xtickst[i] = goo_canvas_polyline_model_new_line (root,
+															   (gdouble) (polv->x0 + (i+1) * xstep),
+															   (gdouble) polv->ymax,
+															   (gdouble) (polv->x0 + (i+1) * xstep),
+															   (gdouble) (polv->ymax + MARKER_SIZE),
+															   "fill-color-rgba", col,
+															   "line-cap", CAIRO_LINE_CAP_SQUARE,
+															   "line-join", CAIRO_LINE_JOIN_MITER,
+															   "line-width", 1.0,
+															   NULL);
 
 		/* x tick labels */
 		/* get time */
@@ -315,141 +310,138 @@ create_canvas_model (GtkAzelPlot *polv)
 		
 		buff[6]='\0';
 
-		polv->xlab[i] = goo_canvas_text_new (root, buff,
-											 (gfloat) (polv->x0 + (i+1) * xstep),
-											 (gfloat) (polv->y0 + 5),
-											 -1,
-											 GTK_ANCHOR_N,
-											 "font", "Sans 8",
-											 "fill-color-rgba", 0x000000FF,
-											 NULL);
-
+		polv->xlab[i] = goo_canvas_text_model_new (root, buff,
+												   (gfloat) (polv->x0 + (i+1) * xstep),
+												   (gfloat) (polv->y0 + 5),
+												   -1,
+												   GTK_ANCHOR_N,
+												   "font", "Sans 8",
+												   "fill-color-rgba", 0x000000FF,
+												   NULL);
 
 		/* left y tick marks */
-		polv->yticksl[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) polv->x0,
-														 (gdouble) (polv->y0 - (i+1) * ystep),
-														 (gdouble) (polv->x0 + MARKER_SIZE),
-														 (gdouble) (polv->y0 - (i+1) * ystep),
-														 "fill-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 1.0,
-														 NULL);
+		polv->yticksl[i] = goo_canvas_polyline_model_new_line (root,
+															   (gdouble) polv->x0,
+															   (gdouble) (polv->y0 - (i+1) * ystep),
+															   (gdouble) (polv->x0 + MARKER_SIZE),
+															   (gdouble) (polv->y0 - (i+1) * ystep),
+															   "fill-color-rgba", col,
+															   "line-cap", CAIRO_LINE_CAP_SQUARE,
+															   "line-join", CAIRO_LINE_JOIN_MITER,
+															   "line-width", 1.0,
+															   NULL);
 
 		/* right y tick marks */
-		polv->yticksr[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) polv->xmax,
-														 (gdouble) (polv->y0 - (i+1) * ystep),
-														 (gdouble) (polv->xmax - MARKER_SIZE),
-														 (gdouble) (polv->y0 - (i+1) * ystep),
-														 "fill-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 1.0,
-														 NULL);
+		polv->yticksr[i] = goo_canvas_polyline_model_new_line (root,
+															   (gdouble) polv->xmax,
+															   (gdouble) (polv->y0 - (i+1) * ystep),
+															   (gdouble) (polv->xmax - MARKER_SIZE),
+															   (gdouble) (polv->y0 - (i+1) * ystep),
+															   "fill-color-rgba", col,
+															   "line-cap", CAIRO_LINE_CAP_SQUARE,
+															   "line-join", CAIRO_LINE_JOIN_MITER,
+															   "line-width", 1.0,
+															   NULL);
 
 		/* Az tick labels */
 		txt = g_strdup_printf ("%.0f\302\260", polv->maxaz / (AZEL_PLOT_NUM_TICKS+1) * (i+1));
-		polv->azlab[i] = goo_canvas_text_new (root, txt,
-											  (gfloat) (polv->x0 - 5),
-											  (gfloat) (polv->y0 - (i+1) * ystep),
-											  -1,
-											  GTK_ANCHOR_E,
-											  "font", "Sans 8",
-											  "fill-color-rgba", 0x0000BFFF,
-											  NULL);
+		polv->azlab[i] = goo_canvas_text_model_new (root, txt,
+													(gfloat) (polv->x0 - 5),
+													(gfloat) (polv->y0 - (i+1) * ystep),
+													-1,
+													GTK_ANCHOR_E,
+													"font", "Sans 8",
+													"fill-color-rgba", 0x0000BFFF,
+													NULL);
 		g_free (txt);
 
 		/* El tick labels */
 		txt = g_strdup_printf ("%.0f\302\260", 90.0 / (AZEL_PLOT_NUM_TICKS+1) * (i+1));
-		polv->ellab[i] = goo_canvas_text_new (root, txt,
-											  (gfloat) (polv->xmax + 5),
-											  (gfloat) (polv->y0 - (i+1) * ystep),
-											  -1,
-											  GTK_ANCHOR_W,
-											  "font", "Sans 8",
-											  "fill-color-rgba", 0xBF0000FF,
-											  NULL);
+		polv->ellab[i] = goo_canvas_text_model_new (root, txt,
+													(gfloat) (polv->xmax + 5),
+													(gfloat) (polv->y0 - (i+1) * ystep),
+													-1,
+													GTK_ANCHOR_W,
+													"font", "Sans 8",
+													"fill-color-rgba", 0xBF0000FF,
+													NULL);
 		g_free (txt);
 
 	}
 
 	/* x legend */
 	if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_LOCAL_TIME)) {
-		polv->xleg = goo_canvas_text_new (root, _("Local Time"),
-										  (gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
-										  (gfloat) (polv->height - 5),
-										  -1,
-										  GTK_ANCHOR_S,
-										  "font", "Sans 9",
-										  "fill-color-rgba", 0x000000FF,
-										  NULL);
+		polv->xleg = goo_canvas_text_model_new (root, _("Local Time"),
+												(gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
+												(gfloat) (polv->height - 5),
+												-1,
+												GTK_ANCHOR_S,
+												"font", "Sans 9",
+												"fill-color-rgba", 0x000000FF,
+												NULL);
 	}
 	else {
-		polv->xleg = goo_canvas_text_new (root, _("UTC"),
-										  (gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
-										  (gfloat) (polv->height - 5),
-										  -1,
-										  GTK_ANCHOR_S,
-										  "font", "Sans 9",
-										  "fill-color-rgba", 0x000000FF,
-										  NULL);
+		polv->xleg = goo_canvas_text_model_new (root, _("UTC"),
+												(gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
+												(gfloat) (polv->height - 5),
+												-1,
+												GTK_ANCHOR_S,
+												"font", "Sans 9",
+												"fill-color-rgba", 0x000000FF,
+												NULL);
 	}
 
 	/* cursor text in upper right corner */
-	polv->curs = goo_canvas_text_new (root, "",
-									  (gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
-									  5.0,
-									  -1,
-									  GTK_ANCHOR_N,
-									  "font", "Sans 8",
-									  "fill-color-rgba", 0x000000FF,
-									  NULL);
+	polv->curs = goo_canvas_text_model_new (root, "",
+											(gfloat) (polv->x0 + (polv->xmax - polv->x0) / 2),
+											5.0,
+											-1,
+											GTK_ANCHOR_N,
+											"font", "Sans 8",
+											"fill-color-rgba", 0x000000FF,
+											NULL);
 
 	/* Az legend */
-	polv->azleg = goo_canvas_text_new (root, _("Az"),
-									   (gfloat) (polv->x0 - 7),
-									   (gfloat) polv->ymax,
-									   -1,
-									   GTK_ANCHOR_NE,
-									   "font", "Sans 9",
-									   "fill-color-rgba", 0x0000BFFF,
-									   NULL);
+	polv->azleg = goo_canvas_text_model_new (root, _("Az"),
+											 (gfloat) (polv->x0 - 7),
+											 (gfloat) polv->ymax,
+											 -1,
+											 GTK_ANCHOR_NE,
+											 "font", "Sans 9",
+											 "fill-color-rgba", 0x0000BFFF,
+											 NULL);
 
 	/* El legend */
-	polv->elleg = goo_canvas_text_new (root, _("El"),
-									   (gfloat) (polv->xmax + 7),
-									   (gfloat) polv->ymax,
-									   -1,
-									   GTK_ANCHOR_NW,
-									   "font", "Sans 9",
-									   "fill-color-rgba", 0xBF0000FF,
-									   NULL);
+	polv->elleg = goo_canvas_text_model_new (root, _("El"),
+											 (gfloat) (polv->xmax + 7),
+											 (gfloat) polv->ymax,
+											 -1,
+											 GTK_ANCHOR_NW,
+											 "font", "Sans 9",
+											 "fill-color-rgba", 0xBF0000FF,
+											 NULL);
 
 	/* Az graph */
-	polv->azg = goo_canvas_polyline_new_line (root, 0, 0, 10, 10,
-											  "stroke-color-rgba", 0x0000BFFF,
-											  "line-cap", CAIRO_LINE_CAP_SQUARE,
-											  "line-join", CAIRO_LINE_JOIN_MITER,
-											  "line-width", 1.0,
-											  NULL);
+	polv->azg = goo_canvas_polyline_model_new_line (root, 0, 0, 10, 10,
+													"stroke-color-rgba", 0x0000BFFF,
+													"line-cap", CAIRO_LINE_CAP_SQUARE,
+													"line-join", CAIRO_LINE_JOIN_MITER,
+													"line-width", 1.0,
+													NULL);
 
 	/* El graph */
-	polv->elg = goo_canvas_polyline_new_line (root, 30, 30, 40, 40,
-											  "stroke-color-rgba", 0xBF0000FF,
-											  "fill-color-rgba", 0xBF00001A,
-											  "line-cap", CAIRO_LINE_CAP_SQUARE,
-											  "line-join", CAIRO_LINE_JOIN_MITER,
-											  "line-width", 1.0,
-											  NULL);
+	polv->elg = goo_canvas_polyline_model_new_line (root, 30, 30, 40, 40,
+													"stroke-color-rgba", 0xBF0000FF,
+													"fill-color-rgba", 0xBF00001A,
+													"line-cap", CAIRO_LINE_CAP_SQUARE,
+													"line-join", CAIRO_LINE_JOIN_MITER,
+													"line-width", 1.0,
+													NULL);
 
-	return canvas_model;
+	return root;
 }
 
 
-
-
 /** \brief Manage new size allocation.
  *
  * This function is called when the canvas receives a new size allocation,
@@ -627,8 +619,6 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 }
 
 
-
-
 /** \brief Convert Az/El to canvas based XY coordinates. */
 /* static void */
 /* graph_to_xy (GtkAzelPlot *p, gdouble t, gdouble az, gdouble el, gfloat *x, gfloat *y) */
@@ -639,7 +629,6 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 /* } */
 
 
-
 /** \brief Convert canvas based coordinates to Az/El. */
 static void
 xy_to_graph    (GtkAzelPlot *p, gfloat x, gfloat y, gdouble *t, gdouble *az, gdouble *el)
@@ -661,6 +650,7 @@ xy_to_graph    (GtkAzelPlot *p, gfloat x, gfloat y, gdouble *t, gdouble *az, gdo
 
 }
 
+
 static void
 az_to_xy (GtkAzelPlot *p, gdouble t, gdouble az, gdouble *x, gdouble *y)
 {
@@ -695,8 +685,8 @@ el_to_xy (GtkAzelPlot *p, gdouble t, gdouble el, gdouble *x, gdouble *y)
 
 /** \brief Manage mouse motion events. */
 static gboolean
-on_motion_notify (GooCanvasItemView *view,
-				  GooCanvasItemView *target,
+on_motion_notify (GooCanvasItem *item,
+				  GooCanvasItem *target,
 				  GdkEventMotion *event,
 				  gpointer data)
 {
@@ -707,7 +697,6 @@ on_motion_notify (GooCanvasItemView *view,
 	gchar *text;
 	gchar  buff[10];
 
-
 	if (polv->cursinfo) {
 
 		/* get (x,y) */
@@ -751,31 +740,29 @@ on_motion_notify (GooCanvasItemView *view,
 
 
 /** \brief Finish canvas item setup.
- *  \param view
- *  \param item_view
- *  \param item
+ *  \param canvas 
+ *  \param item 
+ *  \param model 
  *  \param data Pointer to the GtkAzelPlot object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
  * the corresponding signals to the created items.
  */
 static void
-on_item_view_created (GooCanvasView     *view,
-					  GooCanvasItemView *item_view,
-					  GooCanvasItem     *item,
-					  gpointer           data)
+on_item_created (GooCanvas *canvas,
+				 GooCanvasItem *item,
+				 GooCanvasItemModel *model,
+				 gpointer data)
 {
-	if (!goo_canvas_item_get_parent (item))	{
+	if (!goo_canvas_item_model_get_parent (model)) {
 		/* root item / canvas */
-		g_signal_connect (item_view, "motion_notify_event",
+		g_signal_connect (item, "motion_notify_event",
 						  (GtkSignalFunc) on_motion_notify, data);
 	}
 
 }
 
 
-
-
 /** \brief Retrieve background color.
  *
  * This function retrieves the canvas background color, which is in 0xRRGGBBAA
@@ -808,5 +795,3 @@ get_canvas_bg_color (GtkAzelPlot *polv, GdkColor *color)
 	color->green = 257 * g;
 	color->blue  = 257 * b;
 }
-
-
