@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -41,7 +41,7 @@
 #include "gpredict-utils.h"
 #include "gtk-polar-plot.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include <goocanvas.h>
 
@@ -56,30 +56,30 @@
 #define MARKER_SIZE_HALF 2
 
 
-static void gtk_polar_plot_class_init  (GtkPolarPlotClass *class);
-static void gtk_polar_plot_init        (GtkPolarPlot *polview);
-static void gtk_polar_plot_destroy     (GtkObject *object);
-static void size_allocate_cb           (GtkWidget *widget,
-										GtkAllocation *allocation,
-										gpointer data);
-static void create_track               (GtkPolarPlot *pv);
-static void update_track               (GtkPolarPlot *pv);
-static GooCanvasItem *create_time_tick (GtkPolarPlot *pv, gdouble time, gfloat x, gfloat y);
-static void correct_pole_coor          (GtkPolarPlot *polv, polar_plot_pole_t pole,
-										gfloat *x, gfloat *y, GtkAnchorType *anch);
-static gboolean on_motion_notify       (GooCanvasItemView *view,
-										GooCanvasItemView *target,
-										GdkEventMotion *event,
-										gpointer data);
-static void on_item_view_created       (GooCanvasView     *view,
-										GooCanvasItemView *item_view,
-										GooCanvasItem     *item,
-										gpointer           data);
-static void on_canvas_realized         (GtkWidget *canvas, gpointer data);
-static GooCanvasModelSimple* create_canvas_model (GtkPolarPlot *polv);
-static void get_canvas_bg_color        (GtkPolarPlot *polv, GdkColor *color);
-static void azel_to_xy                 (GtkPolarPlot *p, gdouble az, gdouble el, gfloat *x, gfloat *y);
-static void xy_to_azel                 (GtkPolarPlot *p, gfloat x, gfloat y, gfloat *az, gfloat *el);
+static void gtk_polar_plot_class_init          (GtkPolarPlotClass *class);
+static void gtk_polar_plot_init                (GtkPolarPlot *polview);
+static void gtk_polar_plot_destroy             (GtkObject *object);
+static void size_allocate_cb                   (GtkWidget *widget,
+												GtkAllocation *allocation,
+												gpointer data);
+static void create_track                       (GtkPolarPlot *pv);
+static void update_track                       (GtkPolarPlot *pv);
+static GooCanvasItemModel *create_time_tick    (GtkPolarPlot *pv, gdouble time, gfloat x, gfloat y);
+static void correct_pole_coor                  (GtkPolarPlot *polv, polar_plot_pole_t pole,
+												gfloat *x, gfloat *y, GtkAnchorType *anch);
+static gboolean on_motion_notify               (GooCanvasItem *item,
+												GooCanvasItem *target,
+												GdkEventMotion *event,
+												gpointer data);
+static void on_item_created                    (GooCanvas *canvas,
+												GooCanvasItem *item,
+												GooCanvasItemModel *model,
+												gpointer data);
+static void on_canvas_realized                 (GtkWidget *canvas, gpointer data);
+static GooCanvasItemModel* create_canvas_model (GtkPolarPlot *polv);
+static void get_canvas_bg_color                (GtkPolarPlot *polv, GdkColor *color);
+static void azel_to_xy                         (GtkPolarPlot *p, gdouble az, gdouble el, gfloat *x, gfloat *y);
+static void xy_to_azel                         (GtkPolarPlot *p, gfloat x, gfloat y, gfloat *az, gfloat *el);
 
 
 static GtkVBoxClass *parent_class = NULL;
@@ -147,6 +147,7 @@ gtk_polar_plot_init (GtkPolarPlot *polview)
 	polview->extratick = FALSE;
 }
 
+
 static void
 gtk_polar_plot_destroy (GtkObject *object)
 {
@@ -155,7 +156,6 @@ gtk_polar_plot_destroy (GtkObject *object)
 }
 
 
-
 /** \brief Create a new GtkPolarPlot widget.
  *  \param cfgdata The configuration data of the parent module.
  *  \param sats Pointer to the hash table containing the asociated satellites.
@@ -165,10 +165,9 @@ GtkWidget*
 gtk_polar_plot_new (qth_t *qth, pass_t *pass)
 {
 	GtkWidget *polv;
-	GooCanvasModelSimple *canvas_model;
+	GooCanvasItemModel *root;
 	GdkColor bg_color = {0, 0xFFFF, 0xFFFF, 0xFFFF};
 
-
 	polv = g_object_new (GTK_TYPE_POLAR_PLOT, NULL);
 
 	GTK_POLAR_PLOT (polv)->qth  = qth;
@@ -181,52 +180,46 @@ gtk_polar_plot_new (qth_t *qth, pass_t *pass)
 	GTK_POLAR_PLOT (polv)->cursinfo = TRUE;
 
 	/* create the canvas */
-	GTK_POLAR_PLOT (polv)->canvas = goo_canvas_view_new ();
+	GTK_POLAR_PLOT (polv)->canvas = goo_canvas_new ();
 	get_canvas_bg_color (GTK_POLAR_PLOT (polv), &bg_color);
 	gtk_widget_modify_base (GTK_POLAR_PLOT (polv)->canvas, GTK_STATE_NORMAL, &bg_color);
 	gtk_widget_set_size_request (GTK_POLAR_PLOT (polv)->canvas,
 								 POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
-	goo_canvas_view_set_bounds (GOO_CANVAS_VIEW (GTK_POLAR_PLOT (polv)->canvas), 0, 0,
-								POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
+	goo_canvas_set_bounds (GOO_CANVAS (GTK_POLAR_PLOT (polv)->canvas), 0, 0,
+							POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
 
 	/* connect size-request signal */
 	g_signal_connect (GTK_POLAR_PLOT (polv)->canvas, "size-allocate",
 					  G_CALLBACK (size_allocate_cb), polv);
-	g_signal_connect (GTK_POLAR_PLOT (polv)->canvas, "item_view_created",
-					  (GtkSignalFunc) on_item_view_created, polv);
+	g_signal_connect (GTK_POLAR_PLOT (polv)->canvas, "item_created",
+					  (GtkSignalFunc) on_item_created, polv);
 	g_signal_connect_after (GTK_POLAR_PLOT (polv)->canvas, "realize",
 							(GtkSignalFunc) on_canvas_realized, polv);
 
 	gtk_widget_show (GTK_POLAR_PLOT (polv)->canvas);
 
-
 	/* Create the canvas model */
-	canvas_model = create_canvas_model (GTK_POLAR_PLOT (polv));
-	goo_canvas_view_set_model (GOO_CANVAS_VIEW (GTK_POLAR_PLOT (polv)->canvas),
-							   GOO_CANVAS_MODEL (canvas_model));
-	g_object_unref (canvas_model);
+	root = create_canvas_model (GTK_POLAR_PLOT (polv));
+	goo_canvas_set_root_item_model (GOO_CANVAS (GTK_POLAR_PLOT (polv)->canvas), root);
+
+	g_object_unref (root);
 	create_track (GTK_POLAR_PLOT (polv));
 
 	gtk_container_add (GTK_CONTAINER (polv), GTK_POLAR_PLOT (polv)->canvas);
 
-
 	return polv;
 }
 
 
-static GooCanvasModelSimple *
+static GooCanvasItemModel *
 create_canvas_model (GtkPolarPlot *polv)
 {
-	GooCanvasModelSimple *canvas_model;
-	GooCanvasItem *root;
+	GooCanvasItemModel *root;
 	gfloat x,y;
 	guint32 col;
 	GtkAnchorType anch = GTK_ANCHOR_CENTER;
 
-
-	canvas_model = goo_canvas_model_simple_new ();
-
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_group_model_new (NULL, NULL);
 
 	/* graph dimensions */
 	polv->size = POLV_DEFAULT_SIZE;
@@ -237,114 +230,113 @@ create_canvas_model (GtkPolarPlot *polv)
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_AXIS_COL);
 
 	/* Add elevation circles at 0, 30 and 60 deg */
-	polv->C00 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										polv->r, polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C00 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  polv->r, polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
-	polv->C30 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										0.6667 * polv->r, 0.6667 * polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C30 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  0.6667 * polv->r, 0.6667 * polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
-
-	polv->C60 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										0.333 * polv->r, 0.3333 * polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C60 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  0.333 * polv->r, 0.3333 * polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
 	/* add horixontal and vertical guidance lines */
-	polv->hl = goo_canvas_polyline_new_line (root,
-											 polv->cx - polv->r - POLV_LINE_EXTRA,
-											 polv->cy,
-											 polv->cx + polv->r + POLV_LINE_EXTRA,
-											 polv->cy,
-											 "stroke-color-rgba", col,
-											 "line-width", 1.0,
-											 NULL);
-	polv->vl = goo_canvas_polyline_new_line (root,
-											 polv->cx,
-											 polv->cy - polv->r - POLV_LINE_EXTRA,
-											 polv->cx,
-											 polv->cy + polv->r + POLV_LINE_EXTRA,
-											 "stroke-color-rgba", col,
-											 "line-width", 1.0,
-											 NULL);
+	polv->hl = goo_canvas_polyline_model_new_line (root,
+												   polv->cx - polv->r - POLV_LINE_EXTRA,
+												   polv->cy,
+												   polv->cx + polv->r + POLV_LINE_EXTRA,
+												   polv->cy,
+												   "stroke-color-rgba", col,
+												   "line-width", 1.0,
+												   NULL);
+	polv->vl = goo_canvas_polyline_model_new_line (root,
+												   polv->cx,
+												   polv->cy - polv->r - POLV_LINE_EXTRA,
+												   polv->cx,
+												   polv->cy + polv->r + POLV_LINE_EXTRA,
+												   "stroke-color-rgba", col,
+												   "line-width", 1.0,
+												   NULL);
 
 	/* N, S, E and W labels.  */
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_TICK_COL);
 	azel_to_xy (polv, 0.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_PLOT_POLE_N, &x, &y, &anch);
-	polv->N = goo_canvas_text_new (root, _("N"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->N = goo_canvas_text_model_new (root, _("N"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 180.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_PLOT_POLE_S, &x, &y, &anch);
-	polv->S = goo_canvas_text_new (root, _("S"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->S = goo_canvas_text_model_new (root, _("S"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 90.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_PLOT_POLE_E, &x, &y, &anch);
-	polv->E = goo_canvas_text_new (root, _("E"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->E = goo_canvas_text_model_new (root, _("E"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 270.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_PLOT_POLE_W, &x, &y, &anch);
-	polv->W = goo_canvas_text_new (root, _("W"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->W = goo_canvas_text_model_new (root, _("W"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	/* cursor text */
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_INFO_COL);
-	polv->curs = goo_canvas_text_new (root, "",
-									  polv->cx - polv->r - 2*POLV_LINE_EXTRA,
-									  polv->cy + polv->r + POLV_LINE_EXTRA,
-									  -1,
-									  GTK_ANCHOR_W,
-									  "font", "Sans 8",
-									  "fill-color-rgba", col,
-									  NULL);
+	polv->curs = goo_canvas_text_model_new (root, "",
+											polv->cx - polv->r - 2*POLV_LINE_EXTRA,
+											polv->cy + polv->r + POLV_LINE_EXTRA,
+											-1,
+											GTK_ANCHOR_W,
+											"font", "Sans 8",
+											"fill-color-rgba", col,
+											NULL);
 
 	/* location info */
-	polv->locnam = goo_canvas_text_new (root, polv->qth->name,
-										polv->cx - polv->r - 2*POLV_LINE_EXTRA,
-										polv->cy - polv->r - POLV_LINE_EXTRA,
-										-1,
-										GTK_ANCHOR_SW,
-										"font", "Sans 8",
-										"fill-color-rgba", col,
-										NULL);
+	polv->locnam = goo_canvas_text_model_new (root, polv->qth->name,
+											  polv->cx - polv->r - 2*POLV_LINE_EXTRA,
+											  polv->cy - polv->r - POLV_LINE_EXTRA,
+											  -1,
+											  GTK_ANCHOR_SW,
+											  "font", "Sans 8",
+											  "fill-color-rgba", col,
+											  NULL);
 
-	return canvas_model;
+	return root;
 }
 
 
@@ -560,18 +552,16 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 static void
 create_track (GtkPolarPlot *pv)
 {
-	gint            i;
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
-	pass_detail_t  *detail;
-	guint           num;
-	GooCanvasPoints *points;
-	gfloat          x,y;
-	guint32         col;
-	guint           tres,ttidx;
+	gint               i;
+	GooCanvasItemModel *root;
+	pass_detail_t      *detail;
+	guint              num;
+	GooCanvasPoints    *points;
+	gfloat             x,y;
+	guint32            col;
+	guint              tres,ttidx;
 
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (pv->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (pv->canvas));
 
 	/* create points */
 	num = g_slist_length (pv->pass->details);
@@ -612,32 +602,30 @@ create_track (GtkPolarPlot *pv)
 	/* create poly-line */
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_TRACK_COL);
 
-	pv->track = goo_canvas_item_new (root, GOO_TYPE_CANVAS_POLYLINE,
-									 "points", points,
-									 "line-width", 1.0,
-									 "stroke-color-rgba", col,
-									 "line-cap", CAIRO_LINE_CAP_SQUARE,
-									 "line-join", CAIRO_LINE_JOIN_MITER,
-									 NULL);
+	pv->track = goo_canvas_polyline_model_new (root, FALSE, 0,
+											   "points", points,
+											   "line-width", 1.0,
+											   "stroke-color-rgba", col,
+											   "line-cap", CAIRO_LINE_CAP_SQUARE,
+											   "line-join", CAIRO_LINE_JOIN_MITER,
+											   NULL);
 	goo_canvas_points_unref (points);
 
 
 }
 
-static GooCanvasItem *
+
+static GooCanvasItemModel *
 create_time_tick (GtkPolarPlot *pv, gdouble time, gfloat x, gfloat y)
 {
-	GooCanvasItem  *item;
-	time_t          t;
-	gchar           buff[7];
-	GtkAnchorType   anchor;
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
-	guint32         col;
+	GooCanvasItemModel *item;
+	time_t             t;
+	gchar              buff[7];
+	GtkAnchorType      anchor;
+	GooCanvasItemModel *root;
+	guint32            col;
 
-
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (pv->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (pv->canvas));
 
 	col = sat_cfg_get_int (SAT_CFG_INT_POLAR_TRACK_COL);
 
@@ -661,12 +649,12 @@ create_time_tick (GtkPolarPlot *pv, gdouble time, gfloat x, gfloat y)
 		x += 5;
 	}
 
-	item = goo_canvas_text_new (root, buff,
-								(gdouble) x, (gdouble) y,
-								-1, anchor,
-								"font", "Sans 7",
-								"fill-color-rgba", col,
-								NULL);
+	item = goo_canvas_text_model_new (root, buff,
+									  (gdouble) x, (gdouble) y,
+									  -1, anchor,
+									  "font", "Sans 7",
+									  "fill-color-rgba", col,
+									  NULL);
 				    
 	return item;
 }
@@ -782,7 +770,6 @@ azel_to_xy (GtkPolarPlot *p, gdouble az, gdouble el, gfloat *x, gfloat *y)
 }
 
 
-
 /** \brief Convert canvas based coordinates to Az/El. */
 static void
 xy_to_azel    (GtkPolarPlot *p, gfloat x, gfloat y, gfloat *az, gfloat *el)
@@ -831,11 +818,10 @@ xy_to_azel    (GtkPolarPlot *p, gfloat x, gfloat y, gfloat *az, gfloat *el)
 }
 
 
-
 /** \brief Manage mouse motion events. */
 static gboolean
-on_motion_notify (GooCanvasItemView *view,
-				  GooCanvasItemView *target,
+on_motion_notify (GooCanvasItem *item,
+				  GooCanvasItem *target,
 				  GdkEventMotion *event,
 				  gpointer data)
 {
@@ -843,7 +829,6 @@ on_motion_notify (GooCanvasItemView *view,
 	gfloat az,el;
 	gchar *text;
 
-
 	if (polv->cursinfo) {
 
 		xy_to_azel (polv, event->x, event->y, &az, &el);
@@ -864,31 +849,29 @@ on_motion_notify (GooCanvasItemView *view,
 
 
 /** \brief Finish canvas item setup.
- *  \param view
- *  \param item_view
+ *  \param canvas 
  *  \param item
+ *  \param model 
  *  \param data Pointer to the GtkPolarPlot object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
  * the corresponding signals to the created items.
  */
 static void
-on_item_view_created (GooCanvasView     *view,
-					  GooCanvasItemView *item_view,
-					  GooCanvasItem     *item,
-					  gpointer           data)
+on_item_created (GooCanvas *canvas,
+				 GooCanvasItem *item,
+				 GooCanvasItemModel *model,
+				 gpointer data)
 {
-	if (!goo_canvas_item_get_parent (item))	{
+	if (!goo_canvas_item_model_get_parent (model))	{
 		/* root item / canvas */
-		g_signal_connect (item_view, "motion_notify_event",
+		g_signal_connect (item, "motion_notify_event",
 						  (GtkSignalFunc) on_motion_notify, data);
 	}
 
 }
 
 
-
-
 /** \brief Retrieve background color.
  *
  * This function retrieves the canvas background color, which is in 0xRRGGBBAA
@@ -921,5 +904,3 @@ get_canvas_bg_color (GtkPolarPlot *polv, GdkColor *color)
 	color->green = 257 * g;
 	color->blue  = 257 * b;
 }
-
-
