@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -36,7 +36,7 @@
 #include "sat-cfg.h"
 #include "mod-cfg-get-param.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "gtk-polar-view.h"
 #include "time-tools.h"
@@ -48,8 +48,8 @@
 
 
 static void track_toggled (GtkCheckMenuItem *item, gpointer data);
-static void target_toggled (GtkCheckMenuItem *item, gpointer data);
-static GooCanvasItem *create_time_tick (GtkPolarView *pv, gdouble time, gfloat x, gfloat y);
+/* static void target_toggled (GtkCheckMenuItem *item, gpointer data); */
+static GooCanvasItemModel *create_time_tick (GtkPolarView *pv, gdouble time, gfloat x, gfloat y);
 
 /** \brief Show satellite popup menu.
  *  \param sat Pointer to the satellite data.
@@ -170,19 +170,18 @@ gtk_polar_view_popup_exec (sat_t *sat,
 static void
 track_toggled (GtkCheckMenuItem *item, gpointer data)
 {
-	GtkPolarView   *pv = GTK_POLAR_VIEW (data);
-	sat_obj_t      *obj = NULL;
-	sat_t          *sat;
-	qth_t          *qth;
-	gint            idx,i;
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
-	pass_detail_t  *detail;
-	guint           num;
-	GooCanvasPoints *points;
-	gfloat          x,y;
-	guint32         col;
-	guint           tres,ttidx;
+	GtkPolarView       *pv = GTK_POLAR_VIEW (data);
+	sat_obj_t          *obj = NULL;
+	sat_t              *sat;
+	qth_t              *qth;
+	gint               idx,i;
+	GooCanvasItemModel *root;
+	pass_detail_t      *detail;
+	guint              num;
+	GooCanvasPoints    *points;
+	gfloat             x,y;
+	guint32            col;
+	guint              tres,ttidx;
 
 
 	/* get satellite object */
@@ -201,8 +200,7 @@ track_toggled (GtkCheckMenuItem *item, gpointer data)
 	obj->showtrack = !obj->showtrack;
 	gtk_check_menu_item_set_active (item, obj->showtrack);
 
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (pv->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (pv->canvas));
 
 	if (obj->showtrack) {
 		/* add sky track */
@@ -249,32 +247,32 @@ track_toggled (GtkCheckMenuItem *item, gpointer data)
 							   MOD_CFG_POLAR_TRACK_COL,
 							   SAT_CFG_INT_POLAR_TRACK_COL);
 
-		obj->track = goo_canvas_item_new (root, GOO_TYPE_CANVAS_POLYLINE,
-										  "points", points,
-										  "line-width", 1.0,
-										  "stroke-color-rgba", col,
-										  "line-cap", CAIRO_LINE_CAP_SQUARE,
-										  "line-join", CAIRO_LINE_JOIN_MITER,
-										  NULL);
+		obj->track = goo_canvas_polyline_model_new (root, FALSE, 0,
+													"points", points,
+													"line-width", 1.0,
+													"stroke-color-rgba", col,
+													"line-cap", CAIRO_LINE_CAP_SQUARE,
+													"line-join", CAIRO_LINE_JOIN_MITER,
+													NULL);
 		goo_canvas_points_unref (points);
 
 		/* put track on the bottom of the sack */
-		goo_canvas_item_lower (obj->track, NULL);
+		goo_canvas_item_model_lower (obj->track, NULL);
 
 	}
 	else {
 		/* delete sky track */
-		idx = goo_canvas_item_find_child (root, obj->track);
+		idx = goo_canvas_item_model_find_child (root, obj->track);
 
 		if (idx != -1) {
-			goo_canvas_item_remove_child (root, idx);
+			goo_canvas_item_model_remove_child (root, idx);
 		}
 
 		for (i = 0; i < TRACK_TICK_NUM; i++) {
-			idx = goo_canvas_item_find_child (root, obj->trtick[i]);
+			idx = goo_canvas_item_model_find_child (root, obj->trtick[i]);
 
 			if (idx != -1) {
-				goo_canvas_item_remove_child (root, idx);
+				goo_canvas_item_model_remove_child (root, idx);
 			}
 		}
 	}
@@ -282,7 +280,7 @@ track_toggled (GtkCheckMenuItem *item, gpointer data)
 }
 
 
-
+#if 0
 /** \brief Manage toggling of Set Target.
  *  \param item The menu item that was toggled.
  *  \param data Pointer to the GtkPolarView structure.
@@ -309,23 +307,20 @@ target_toggled (GtkCheckMenuItem *item, gpointer data)
 	obj->istarget = !obj->istarget;
 	gtk_check_menu_item_set_active (item, obj->istarget);
 }
+#endif
 
 
-
-static GooCanvasItem *
+static GooCanvasItemModel *
 create_time_tick (GtkPolarView *pv, gdouble time, gfloat x, gfloat y)
 {
-	GooCanvasItem  *item;
-	time_t          t;
-	gchar           buff[7];
-	GtkAnchorType   anchor;
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
-	guint32         col;
+	GooCanvasItemModel *item;
+	time_t             t;
+	gchar              buff[7];
+	GtkAnchorType      anchor;
+	GooCanvasItemModel *root;
+	guint32            col;
 
-
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (pv->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (pv->canvas));
 
 	col = mod_cfg_get_int (pv->cfgdata,
 						   MOD_CFG_POLAR_SECTION,
@@ -352,14 +347,14 @@ create_time_tick (GtkPolarView *pv, gdouble time, gfloat x, gfloat y)
 		x += 5;
 	}
 
-	item = goo_canvas_text_new (root, buff,
-								(gdouble) x, (gdouble) y,
-								-1, anchor,
-								"font", "Sans 7",
-								"fill-color-rgba", col,
-								NULL);
-				    
-	goo_canvas_item_lower (item, NULL);
+	item = goo_canvas_text_model_new (root, buff,
+									  (gdouble) x, (gdouble) y,
+									  -1, anchor,
+									  "font", "Sans 7",
+									  "fill-color-rgba", col,
+									  NULL);
+
+	goo_canvas_item_model_lower (item, NULL);
 
 	return item;
 }
