@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -43,7 +43,7 @@
 #include "gtk-polar-view-popup.h"
 #include "gtk-polar-view.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include <goocanvas.h>
 
@@ -68,25 +68,25 @@ static void update_sat                 (gpointer key, gpointer value, gpointer d
 static void update_track               (gpointer key, gpointer value, gpointer data);
 static void correct_pole_coor          (GtkPolarView *polv, polar_view_pole_t pole,
 										gfloat *x, gfloat *y, GtkAnchorType *anch);
-static gboolean on_motion_notify       (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_motion_notify       (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventMotion *event,
 										gpointer data);
-static void on_item_view_created       (GooCanvasView     *view,
-										GooCanvasItemView *item_view,
-										GooCanvasItem     *item,
-										gpointer           data);
+static void on_item_created            (GooCanvas *canvas,
+										GooCanvasItem *item,
+										GooCanvasItemModel *model,
+										gpointer data);
 static void on_canvas_realized         (GtkWidget *canvas, gpointer data);
-static gboolean on_button_press        (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_button_press        (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventButton *event,
 										gpointer data);
-static gboolean on_button_release      (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_button_release      (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventButton *event,
 										gpointer data);
 static void clear_selection            (gpointer key, gpointer val, gpointer data);
-static GooCanvasModelSimple* create_canvas_model (GtkPolarView *polv);
+static GooCanvasItemModel* create_canvas_model (GtkPolarView *polv);
 static void get_canvas_bg_color        (GtkPolarView *polv, GdkColor *color);
 
 
@@ -162,6 +162,7 @@ gtk_polar_view_init (GtkPolarView *polview)
 	polview->extratick = FALSE;
 }
 
+
 static void
 gtk_polar_view_destroy (GtkObject *object)
 {
@@ -170,27 +171,25 @@ gtk_polar_view_destroy (GtkObject *object)
 }
 
 
-
 /** \brief Create a new GtkPolarView widget.
  *  \param cfgdata The configuration data of the parent module.
  *  \param sats Pointer to the hash table containing the asociated satellites.
  *  \param qth Pointer to the ground station data.
  */
-GtkWidget*
+GtkWidget *
 gtk_polar_view_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 {
 	GtkWidget *polv;
-	GooCanvasModelSimple *canvas_model;
+	GooCanvasItemModel *root;
 	GdkColor bg_color = {0, 0xFFFF, 0xFFFF, 0xFFFF};
 
-
 	polv = g_object_new (GTK_TYPE_POLAR_VIEW, NULL);
 
 	GTK_POLAR_VIEW (polv)->cfgdata = cfgdata;
 	GTK_POLAR_VIEW (polv)->sats = sats;
 	GTK_POLAR_VIEW (polv)->qth  = qth;
 
-	/* FIXME: use g_has_table_new_full */
+
 	GTK_POLAR_VIEW (polv)->obj  = g_hash_table_new_full (g_int_hash,
 														 g_int_equal,
 														 g_free,
@@ -230,31 +229,29 @@ gtk_polar_view_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 														 SAT_CFG_BOOL_POL_SHOW_EXTRA_AZ_TICKS);
 
 	/* create the canvas */
-	GTK_POLAR_VIEW (polv)->canvas = goo_canvas_view_new ();
+	GTK_POLAR_VIEW (polv)->canvas = goo_canvas_new ();
 	get_canvas_bg_color (GTK_POLAR_VIEW (polv), &bg_color);
 	gtk_widget_modify_base (GTK_POLAR_VIEW (polv)->canvas, GTK_STATE_NORMAL, &bg_color);
 	gtk_widget_set_size_request (GTK_POLAR_VIEW (polv)->canvas,
 								 POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
-	goo_canvas_view_set_bounds (GOO_CANVAS_VIEW (GTK_POLAR_VIEW (polv)->canvas), 0, 0,
+	goo_canvas_set_bounds (GOO_CANVAS (GTK_POLAR_VIEW (polv)->canvas), 0, 0,
 								POLV_DEFAULT_SIZE, POLV_DEFAULT_SIZE);
 
 	/* connect size-request signal */
 	g_signal_connect (GTK_POLAR_VIEW (polv)->canvas, "size-allocate",
 					  G_CALLBACK (size_allocate_cb), polv);
-	g_signal_connect (GTK_POLAR_VIEW (polv)->canvas, "item_view_created",
-					  (GtkSignalFunc) on_item_view_created, polv);
+	g_signal_connect (GTK_POLAR_VIEW (polv)->canvas, "item_created",
+					  (GtkSignalFunc) on_item_created, polv);
 	g_signal_connect_after (GTK_POLAR_VIEW (polv)->canvas, "realize",
 							(GtkSignalFunc) on_canvas_realized, polv);
 
 	gtk_widget_show (GTK_POLAR_VIEW (polv)->canvas);
 
-
 	/* Create the canvas model */
-	canvas_model = create_canvas_model (GTK_POLAR_VIEW (polv));
-	goo_canvas_view_set_model (GOO_CANVAS_VIEW (GTK_POLAR_VIEW (polv)->canvas),
-							   GOO_CANVAS_MODEL (canvas_model));
-	g_object_unref (canvas_model);
+	root = create_canvas_model (GTK_POLAR_VIEW (polv));
+	goo_canvas_set_root_item_model (GOO_CANVAS (GTK_POLAR_VIEW (polv)->canvas), root);
 
+	g_object_unref (root);
 
 	//gtk_box_pack_start (GTK_BOX (polv), GTK_POLAR_VIEW (polv)->swin, TRUE, TRUE, 0);
 	gtk_container_add (GTK_CONTAINER (polv), GTK_POLAR_VIEW (polv)->canvas);
@@ -263,19 +260,15 @@ gtk_polar_view_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 }
 
 
-static GooCanvasModelSimple *
+static GooCanvasItemModel *
 create_canvas_model (GtkPolarView *polv)
 {
-	GooCanvasModelSimple *canvas_model;
-	GooCanvasItem *root;
+	GooCanvasItemModel *root;
 	gfloat x,y;
 	guint32 col;
 	GtkAnchorType anch = GTK_ANCHOR_CENTER;
 
-
-	canvas_model = goo_canvas_model_simple_new ();
-
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_group_model_new (NULL, NULL);
 
 	/* graph dimensions */
 	polv->size = POLV_DEFAULT_SIZE;
@@ -289,45 +282,45 @@ create_canvas_model (GtkPolarView *polv)
 						   SAT_CFG_INT_POLAR_AXIS_COL);
 
 	/* Add elevation circles at 0, 30 and 60 deg */
-	polv->C00 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										polv->r, polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C00 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  polv->r, polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
-	polv->C30 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										0.6667 * polv->r, 0.6667 * polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C30 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  0.6667 * polv->r, 0.6667 * polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
-
-	polv->C60 = goo_canvas_ellipse_new (root,
-										polv->cx, polv->cy,
-										0.333 * polv->r, 0.3333 * polv->r,
-										"line-width", 1.0,
-										"stroke-color-rgba", col,
-										NULL);
+	polv->C60 = goo_canvas_ellipse_model_new (root,
+											  polv->cx, polv->cy,
+											  0.333 * polv->r, 0.3333 * polv->r,
+											  "line-width", 1.0,
+											  "stroke-color-rgba", col,
+											  NULL);
 
 	/* add horixontal and vertical guidance lines */
-	polv->hl = goo_canvas_polyline_new_line (root,
-											 polv->cx - polv->r - POLV_LINE_EXTRA,
-											 polv->cy,
-											 polv->cx + polv->r + POLV_LINE_EXTRA,
-											 polv->cy,
-											 "stroke-color-rgba", col,
-											 "line-width", 1.0,
-											 NULL);
-	polv->vl = goo_canvas_polyline_new_line (root,
-											 polv->cx,
-											 polv->cy - polv->r - POLV_LINE_EXTRA,
-											 polv->cx,
-											 polv->cy + polv->r + POLV_LINE_EXTRA,
-											 "stroke-color-rgba", col,
-											 "line-width", 1.0,
-											 NULL);
+	polv->hl = goo_canvas_polyline_model_new_line (root,
+												   polv->cx - polv->r - POLV_LINE_EXTRA,
+												   polv->cy,
+												   polv->cx + polv->r + POLV_LINE_EXTRA,
+												   polv->cy,
+												   "stroke-color-rgba", col,
+												   "line-width", 1.0,
+												   NULL);
+
+	polv->vl = goo_canvas_polyline_model_new_line (root,
+												   polv->cx,
+												   polv->cy - polv->r - POLV_LINE_EXTRA,
+												   polv->cx,
+												   polv->cy + polv->r + POLV_LINE_EXTRA,
+												   "stroke-color-rgba", col,
+												   "line-width", 1.0,
+												   NULL);
 
 	/* N, S, E and W labels.  */
 	col = mod_cfg_get_int (polv->cfgdata,
@@ -336,95 +329,95 @@ create_canvas_model (GtkPolarView *polv)
 						   SAT_CFG_INT_POLAR_TICK_COL);
 	azel_to_xy (polv, 0.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_VIEW_POLE_N, &x, &y, &anch);
-	polv->N = goo_canvas_text_new (root, _("N"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->N = goo_canvas_text_model_new (root, _("N"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 180.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_VIEW_POLE_S, &x, &y, &anch);
-	polv->S = goo_canvas_text_new (root, _("S"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->S = goo_canvas_text_model_new (root, _("S"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 90.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_VIEW_POLE_E, &x, &y, &anch);
-	polv->E = goo_canvas_text_new (root, _("E"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->E = goo_canvas_text_model_new (root, _("E"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	azel_to_xy (polv, 270.0, 0.0, &x, &y);
 	correct_pole_coor (polv, POLAR_VIEW_POLE_W, &x, &y, &anch);
-	polv->W = goo_canvas_text_new (root, _("W"),
-								   x,
-								   y,
-								   -1,
-								   anch,
-								   "font", "Sans 10",
-								   "fill-color-rgba", col,
-								   NULL);
+	polv->W = goo_canvas_text_model_new (root, _("W"),
+										 x,
+										 y,
+										 -1,
+										 anch,
+										 "font", "Sans 10",
+										 "fill-color-rgba", col,
+										 NULL);
 
 	/* cursor text */
 	col = mod_cfg_get_int (polv->cfgdata,
 						   MOD_CFG_POLAR_SECTION,
 						   MOD_CFG_POLAR_INFO_COL,
 						   SAT_CFG_INT_POLAR_INFO_COL);
-	polv->curs = goo_canvas_text_new (root, "",
-									  polv->cx - polv->r - 2*POLV_LINE_EXTRA,
-									  polv->cy + polv->r + POLV_LINE_EXTRA,
-									  -1,
-									  GTK_ANCHOR_W,
-									  "font", "Sans 8",
-									  "fill-color-rgba", col,
-									  NULL);
+	polv->curs = goo_canvas_text_model_new (root, "",
+											polv->cx - polv->r - 2*POLV_LINE_EXTRA,
+											polv->cy + polv->r + POLV_LINE_EXTRA,
+											-1,
+											GTK_ANCHOR_W,
+											"font", "Sans 8",
+											"fill-color-rgba", col,
+											NULL);
 
 	/* location info */
-	polv->locnam = goo_canvas_text_new (root, polv->qth->name,
-										polv->cx - polv->r - 2*POLV_LINE_EXTRA,
-										polv->cy - polv->r - POLV_LINE_EXTRA,
-										-1,
-										GTK_ANCHOR_SW,
-										"font", "Sans 8",
-										"fill-color-rgba", col,
-										NULL);
+	polv->locnam = goo_canvas_text_model_new (root, polv->qth->name,
+											  polv->cx - polv->r - 2*POLV_LINE_EXTRA,
+											  polv->cy - polv->r - POLV_LINE_EXTRA,
+											  -1,
+											  GTK_ANCHOR_SW,
+											  "font", "Sans 8",
+											  "fill-color-rgba", col,
+											  NULL);
 
 	/* next event */
-	polv->next = goo_canvas_text_new (root, "",
-									  polv->cx + polv->r + 2*POLV_LINE_EXTRA,
-									  polv->cy - polv->r - POLV_LINE_EXTRA,
-									  -1,
-									  GTK_ANCHOR_E,
-									  "font", "Sans 8",
-									  "fill-color-rgba", col,
-									  "alignment", PANGO_ALIGN_RIGHT,
-									  NULL);
+	polv->next = goo_canvas_text_model_new (root, "",
+											polv->cx + polv->r + 2*POLV_LINE_EXTRA,
+											polv->cy - polv->r - POLV_LINE_EXTRA,
+											-1,
+											GTK_ANCHOR_E,
+											"font", "Sans 8",
+											"fill-color-rgba", col,
+											"alignment", PANGO_ALIGN_RIGHT,
+											NULL);
 
 	/* selected satellite text */
-	polv->sel = goo_canvas_text_new (root, "",
-									 polv->cx + polv->r + 2*POLV_LINE_EXTRA,
-									 polv->cy + polv->r + POLV_LINE_EXTRA,
-									 -1,
-									 GTK_ANCHOR_E,
-									 "font", "Sans 8",
-									 "fill-color-rgba", col,
-									 "alignment", PANGO_ALIGN_RIGHT,
-									 NULL);
+	polv->sel = goo_canvas_text_model_new (root, "",
+										   polv->cx + polv->r + 2*POLV_LINE_EXTRA,
+										   polv->cy + polv->r + POLV_LINE_EXTRA,
+										   -1,
+										   GTK_ANCHOR_E,
+										   "font", "Sans 8",
+										   "fill-color-rgba", col,
+										   "alignment", PANGO_ALIGN_RIGHT,
+										   NULL);
 
-	return canvas_model;
+	return root;
 }
 
 
@@ -649,6 +642,7 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 
 }
 
+
 void
 gtk_polar_view_update          (GtkWidget  *widget)
 {
@@ -694,7 +688,7 @@ gtk_polar_view_update          (GtkWidget  *widget)
 					/* extract hours */
 					h = (guint) floor (s/3600);
 					s -= 3600*h;
-			
+
 					/* leading zero */
 					if ((h > 0) && (h < 10))
 						ch = g_strdup ("0");
@@ -762,17 +756,16 @@ gtk_polar_view_update          (GtkWidget  *widget)
 static void
 update_sat    (gpointer key, gpointer value, gpointer data)
 {
-	gint           *catnum;
-	sat_t          *sat = SAT(value);
-	GtkPolarView   *polv = GTK_POLAR_VIEW (data);
-	sat_obj_t      *obj = NULL;
-	gfloat          x,y;
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
-	gint            idx,i;
-	gdouble         now;// = get_current_daynum ();
-	gchar          *text;
-	guint32         colour;
+	gint               *catnum;
+	sat_t              *sat = SAT(value);
+	GtkPolarView       *polv = GTK_POLAR_VIEW (data);
+	sat_obj_t          *obj = NULL;
+	gfloat             x,y;
+	GooCanvasItemModel *root;
+	gint               idx,i;
+	gdouble            now;// = get_current_daynum ();
+	gchar             *text;
+	guint32            colour;
 
 
 	catnum = g_new0 (gint, 1);
@@ -795,29 +788,28 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 		if (obj != NULL) {
 
 			/* remove sat from canvas */
-			model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (polv->canvas));
-			root = goo_canvas_model_get_root_item (model);
+			root = goo_canvas_get_root_item_model (GOO_CANVAS (polv->canvas));
 
-			idx = goo_canvas_item_find_child (root, obj->marker);
+			idx = goo_canvas_item_model_find_child (root, obj->marker);
 			if (idx != -1) {
-				goo_canvas_item_remove_child (root, idx);
+				goo_canvas_item_model_remove_child (root, idx);
 			}
 
-			idx = goo_canvas_item_find_child (root, obj->label);
+			idx = goo_canvas_item_model_find_child (root, obj->label);
 			if (idx != -1) {
-				goo_canvas_item_remove_child (root, idx);
+				goo_canvas_item_model_remove_child (root, idx);
 			}
 
 			/* remove sky track */
 			if (obj->showtrack) {
-				idx = goo_canvas_item_find_child (root, obj->track);
+				idx = goo_canvas_item_model_find_child (root, obj->track);
 				if (idx != -1)
-					goo_canvas_item_remove_child (root, idx);
+					goo_canvas_item_model_remove_child (root, idx);
 
 				for (i = 0; i < TRACK_TICK_NUM; i++) {
-					idx = goo_canvas_item_find_child (root, obj->trtick[i]);
+					idx = goo_canvas_item_model_find_child (root, obj->trtick[i]);
 					if (idx != -1)
-						goo_canvas_item_remove_child (root, idx);
+						goo_canvas_item_model_remove_child (root, idx);
 				}
 			}
 			
@@ -869,54 +861,57 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 				gchar        *ch,*cm,*cs;
 				gdouble       number, now;
 
+				if (sat->los > 0.0) {
+					now = polv->tstamp;//get_current_daynum ();
+					number = sat->los - now;
 
-				now = polv->tstamp;//get_current_daynum ();
-				number = sat->los - now;
+					/* convert julian date to seconds */
+					s = (guint) (number * 86400);
 
-				/* convert julian date to seconds */
-				s = (guint) (number * 86400);
+					/* extract hours */
+					h = (guint) floor (s/3600);
+					s -= 3600*h;
 
-				/* extract hours */
-				h = (guint) floor (s/3600);
-				s -= 3600*h;
+					/* leading zero */
+					if ((h > 0) && (h < 10))
+						ch = g_strdup ("0");
+					else
+						ch = g_strdup ("");
 
-				/* leading zero */
-				if ((h > 0) && (h < 10))
-					ch = g_strdup ("0");
-				else
-					ch = g_strdup ("");
+					/* extract minutes */
+					m = (guint) floor (s/60);
+					s -= 60*m;
 
-				/* extract minutes */
-				m = (guint) floor (s/60);
-				s -= 60*m;
+					/* leading zero */
+					if (m < 10)
+						cm = g_strdup ("0");
+					else
+						cm = g_strdup ("");
 
-				/* leading zero */
-				if (m < 10)
-					cm = g_strdup ("0");
-				else
-					cm = g_strdup ("");
+					/* leading zero */
+					if (s < 10)
+						cs = g_strdup (":0");
+					else
+						cs = g_strdup (":");
 
-				/* leading zero */
-				if (s < 10)
-					cs = g_strdup (":0");
-				else
-					cs = g_strdup (":");
-
-				if (h > 0) {
-					text = g_strdup_printf ("%s\nLOS in %s%d:%s%d%s%d",
-											sat->tle.sat_name, ch, h, cm, m, cs, s);
+					if (h > 0) {
+						text = g_strdup_printf (_("%s\nLOS in %s%d:%s%d%s%d"),
+												sat->tle.sat_name, ch, h, cm, m, cs, s);
+					}
+					else {
+						text = g_strdup_printf (_("%s\nLOS in %s%d%s%d"),
+												sat->tle.sat_name, cm, m, cs, s);
+					}
+					g_free (ch);
+					g_free (cm);
+					g_free (cs);
 				}
 				else {
-					text = g_strdup_printf ("%s\nLOS in %s%d%s%d",
-											sat->tle.sat_name, cm, m, cs, s);
+					text = g_strdup_printf (_("%s\nAlways in range"), sat->tle.sat_name);
 				}
-
 				g_object_set (polv->sel, "text", text, NULL);
 
 				g_free (text);
-				g_free (ch);
-				g_free (cm);
-				g_free (cs);
 			}
 
 			g_free (catnum);
@@ -928,39 +923,38 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 			obj->showtrack = FALSE;
 			obj->istarget = FALSE;
 
-			model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (polv->canvas));
-			root = goo_canvas_model_get_root_item (model);
+			root = goo_canvas_get_root_item_model (GOO_CANVAS (polv->canvas));
 
 			colour = mod_cfg_get_int (polv->cfgdata,
 									  MOD_CFG_POLAR_SECTION,
 									  MOD_CFG_POLAR_SAT_COL,
 									  SAT_CFG_INT_POLAR_SAT_COL);
 
-			obj->marker = goo_canvas_rect_new (root,
-											   x - MARKER_SIZE_HALF,
-											   y - MARKER_SIZE_HALF,
-											   2*MARKER_SIZE_HALF,
-											   2*MARKER_SIZE_HALF,
-											   "fill-color-rgba", colour,
-											   "stroke-color-rgba", colour,
-											   NULL);
-			obj->label = goo_canvas_text_new (root, sat->tle.sat_name,
-											  x,
-											  y+2,
-											  -1,
-											  GTK_ANCHOR_NORTH,
-											  "font", "Sans 8",
-											  "fill-color-rgba", colour,
-											  NULL);
+			obj->marker = goo_canvas_rect_model_new (root,
+													 x - MARKER_SIZE_HALF,
+													 y - MARKER_SIZE_HALF,
+													 2*MARKER_SIZE_HALF,
+													 2*MARKER_SIZE_HALF,
+													 "fill-color-rgba", colour,
+													 "stroke-color-rgba", colour,
+													 NULL);
+			obj->label = goo_canvas_text_model_new (root, sat->tle.sat_name,
+													x,
+													y+2,
+													-1,
+													GTK_ANCHOR_NORTH,
+													"font", "Sans 8",
+													"fill-color-rgba", colour,
+													NULL);
 			
-			goo_canvas_item_raise (obj->marker, NULL);
-			goo_canvas_item_raise (obj->label, NULL);
+			goo_canvas_item_model_raise (obj->marker, NULL);
+			goo_canvas_item_model_raise (obj->label, NULL);
 
 			g_object_set_data (G_OBJECT (obj->marker), "catnum", GINT_TO_POINTER(*catnum));
 			g_object_set_data (G_OBJECT (obj->label), "catnum", GINT_TO_POINTER(*catnum));
 
 			/* get info about the current pass */
-			obj->pass = get_current_pass (sat, polv->qth);
+			obj->pass = get_current_pass (sat, polv->qth, now);
 
 			/* add sat to hash table */
 			g_hash_table_insert (polv->obj, catnum, obj);
@@ -971,7 +965,6 @@ update_sat    (gpointer key, gpointer value, gpointer data)
 }
 
 
-
 /** \brief Update sky track drawing after size allocate. */
 static void
 update_track (gpointer key, gpointer value, gpointer data)
@@ -1081,7 +1074,6 @@ azel_to_xy (GtkPolarView *p, gdouble az, gdouble el, gfloat *x, gfloat *y)
 }
 
 
-
 /** \brief Convert canvas based coordinates to Az/El. */
 void
 xy_to_azel    (GtkPolarView *p, gfloat x, gfloat y, gfloat *az, gfloat *el)
@@ -1130,11 +1122,10 @@ xy_to_azel    (GtkPolarView *p, gfloat x, gfloat y, gfloat *az, gfloat *el)
 }
 
 
-
 /** \brief Manage mouse motion events. */
 static gboolean
-on_motion_notify (GooCanvasItemView *view,
-				  GooCanvasItemView *target,
+on_motion_notify (GooCanvasItem *item,
+				  GooCanvasItem *target,
 				  GdkEventMotion *event,
 				  gpointer data)
 {
@@ -1142,7 +1133,6 @@ on_motion_notify (GooCanvasItemView *view,
 	gfloat az,el;
 	gchar *text;
 
-
 	if (polv->cursinfo) {
 
 		xy_to_azel (polv, event->x, event->y, &az, &el);
@@ -1163,36 +1153,35 @@ on_motion_notify (GooCanvasItemView *view,
 
 
 /** \brief Finish canvas item setup.
- *  \param view
- *  \param item_view
+ *  \param canvas 
  *  \param item
+ *  \param model 
  *  \param data Pointer to the GtkPolarView object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
  * the corresponding signals to the created items.
  */
 static void
-on_item_view_created (GooCanvasView     *view,
-					  GooCanvasItemView *item_view,
-					  GooCanvasItem     *item,
-					  gpointer           data)
+on_item_created (GooCanvas *canvas,
+				 GooCanvasItem *item,
+				 GooCanvasItemModel *model,
+				 gpointer data)
 {
-	if (!goo_canvas_item_get_parent (item))	{
+	if (!goo_canvas_item_model_get_parent (model))	{
 		/* root item / canvas */
-		g_signal_connect (item_view, "motion_notify_event",
+		g_signal_connect (item, "motion_notify_event",
 						  (GtkSignalFunc) on_motion_notify, data);
 	}
 
 	else if (!g_object_get_data (G_OBJECT (item), "skip-signal-connection")) {
-		g_signal_connect (item_view, "button_press_event",
+		g_signal_connect (item, "button_press_event",
 						  (GtkSignalFunc) on_button_press, data);
-		g_signal_connect (item_view, "button_release_event",
+		g_signal_connect (item, "button_release_event",
 						  (GtkSignalFunc) on_button_release, data);
 	}
 }
 
 
-
 /** \brief Manage button press events
  *
  * This function is called when a mouse button is pressed on a satellite object.
@@ -1200,18 +1189,17 @@ on_item_view_created (GooCanvasView     *view,
  * created and executed.
  */
 static gboolean
-on_button_press (GooCanvasItemView *view,
-				 GooCanvasItemView *target,
+on_button_press (GooCanvasItem *item,
+				 GooCanvasItem *target,
 				 GdkEventButton *event,
 				 gpointer data)
 {
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
+	GooCanvasItemModel *model = goo_canvas_item_get_model (item);
 	GtkPolarView  *polv = GTK_POLAR_VIEW (data);
-	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "catnum"));
+	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (model), "catnum"));
 	gint *catpoint = NULL;
 	sat_t *sat = NULL;
 
-
 	switch (event->button) {
 
 		/* pop-up menu */
@@ -1254,23 +1242,21 @@ on_button_press (GooCanvasItemView *view,
  * deselecting a satellite
  */
 static gboolean
-on_button_release (GooCanvasItemView *view,
-				   GooCanvasItemView *target,
+on_button_release (GooCanvasItem *item,
+				   GooCanvasItem *target,
 				   GdkEventButton *event,
 				   gpointer data)
 {
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
+	GooCanvasItemModel *model = goo_canvas_item_get_model (item);
 	GtkPolarView *polv = GTK_POLAR_VIEW (data);
-	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "catnum"));
+	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (model), "catnum"));
 	gint *catpoint = NULL;
 	sat_obj_t *obj = NULL;
 	guint32  color;
 
-
 	catpoint = g_try_new0 (gint, 1);
 	*catpoint = catnum;
 
-
 	switch (event->button) {
 
 		/* Select / de-select satellite */
@@ -1356,7 +1342,6 @@ clear_selection (gpointer key, gpointer val, gpointer data)
 }
 
 
-
 void
 gtk_polar_view_reconf          (GtkWidget  *widget, GKeyFile *cfgdat)
 {
@@ -1410,4 +1395,3 @@ gtk_polar_view_reload_sats (GtkWidget *polv, GHashTable *sats)
 	GTK_POLAR_VIEW (polv)->naos = 0.0;
 	GTK_POLAR_VIEW (polv)->ncat = 0;
 }
-
