@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -59,14 +59,14 @@ typedef struct _GtkPolarViewClass   GtkPolarViewClass;
 
 /** \brief Satellite object on graph. */
 typedef struct {
-	gboolean       selected;  /*!< Satellite is selected. */
-	gboolean       showtrack; /*!< Show ground track. */
-	gboolean       istarget;  /*!< Is this object the target. */
-	pass_t        *pass;      /*!< Details of the current pass. */
-	GooCanvasItem *marker;    /*!< Item showing position of satellite. */
-	GooCanvasItem *label;     /*!< Item showing the satellite name. */
-	GooCanvasItem *track;     /*!< Sky track. */
-	GooCanvasItem *trtick[TRACK_TICK_NUM]; /*!< Time ticks along the sky track */
+	gboolean            selected;               /*!< Satellite is selected. */
+	gboolean            showtrack;              /*!< Show ground track. */
+	gboolean            istarget;               /*!< Is this object the target. */
+	pass_t             *pass;                   /*!< Details of the current pass. */
+	GooCanvasItemModel *marker;                 /*!< Item showing position of satellite. */
+	GooCanvasItemModel *label;                  /*!< Item showing the satellite name. */
+	GooCanvasItemModel *track;                  /*!< Sky track. */
+	GooCanvasItemModel *trtick[TRACK_TICK_NUM]; /*!< Time ticks along the sky track */
 } sat_obj_t;
 
 #define SAT_OBJ(obj) ((sat_obj_t *)obj)
@@ -97,13 +97,13 @@ struct _GtkPolarView
 
 	GtkWidget  *canvas;   /*!< The canvas widget */
 
-	GooCanvasItem *C00, *C30, *C60; /*!< 0, 30 and 60 deg elevation circles */
-	GooCanvasItem *hl, *vl;         /*!< horizontal and vertical lines */
-	GooCanvasItem *N,*S,*E,*W;      /*!< North, South, East and West labels */
-	GooCanvasItem *locnam;          /*!< Location name */
-	GooCanvasItem *curs;            /*!< cursor tracking text */
-	GooCanvasItem *next;            /*!< next event text */
-	GooCanvasItem *sel;             /*!< Text showing info about selected satellite. */
+	GooCanvasItemModel *C00, *C30, *C60; /*!< 0, 30 and 60 deg elevation circles */
+	GooCanvasItemModel *hl, *vl;         /*!< horizontal and vertical lines */
+	GooCanvasItemModel *N,*S,*E,*W;      /*!< North, South, East and West labels */
+	GooCanvasItemModel *locnam;          /*!< Location name */
+	GooCanvasItemModel *curs;            /*!< cursor tracking text */
+	GooCanvasItemModel *next;            /*!< next event text */
+	GooCanvasItemModel *sel;             /*!< Text showing info about selected satellite. */
 
 	gdouble     naos;     /*!< Next event time */
 	gint        ncat;     /*!< Next event catnum */
