@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -35,7 +35,7 @@
 #include "sat-cfg.h"
 #include "mod-cfg-get-param.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "gtk-sat-map.h"
 #include "orbit-tools.h"
@@ -50,7 +50,7 @@
 
 static void coverage_toggled (GtkCheckMenuItem *item, gpointer data);
 static void track_toggled (GtkCheckMenuItem *item, gpointer data);
-static void target_toggled (GtkCheckMenuItem *item, gpointer data);
+/* static void target_toggled (GtkCheckMenuItem *item, gpointer data); */
 
 
 /** \brief Show satellite popup menu.
@@ -265,7 +265,7 @@ track_toggled (GtkCheckMenuItem *item, gpointer data)
 }
 
 
-
+#if 0
 /** \brief Manage toggling of Set Target.
  *  \param item The menu item that was toggled.
  *  \param data Pointer to the GtkSatMap structure.
@@ -292,4 +292,5 @@ target_toggled (GtkCheckMenuItem *item, gpointer data)
 	obj->istarget = !obj->istarget;
 	gtk_check_menu_item_set_active (item, obj->istarget);
 }
+#endif
 
