@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
   Copyright (C)  2006-2007  William J Beksi, KC2EXL.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
@@ -56,11 +56,11 @@
 #include "locator.h"
 #include "sat-debugger.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include <goocanvas.h>
 
-#define MARKER_SIZE_HALF 	1
+#define MARKER_SIZE_HALF	1
 
 static void gtk_sat_map_class_init (GtkSatMapClass *class);
 static void gtk_sat_map_init       (GtkSatMap *polview);
@@ -71,26 +71,26 @@ static void update_sat             (gpointer key, gpointer value, gpointer data)
 static void plot_sat               (gpointer key, gpointer value, gpointer data);
 static void lonlat_to_xy           (GtkSatMap *m, gdouble lon, gdouble lat, gfloat *x, gfloat *y);
 static void xy_to_lonlat           (GtkSatMap *m, gfloat x, gfloat y, gfloat *lon, gfloat *lat);
-static gboolean on_motion_notify   (GooCanvasItemView *view,
-									GooCanvasItemView *target,
-									GdkEventMotion    *event,
-									gpointer           data);
-static void on_item_view_created   (GooCanvasView     *view,
-									GooCanvasItemView *item_view,
-									GooCanvasItem     *item,
-									gpointer           data);
+static gboolean on_motion_notify   (GooCanvasItem *item,
+									GooCanvasItem *target,
+									GdkEventMotion *event,
+									gpointer data);
+static void on_item_created        (GooCanvas *canvas,
+									GooCanvasItem *item,
+									GooCanvasItemModel *model,
+									gpointer data);
 static void on_canvas_realized     (GtkWidget *canvas, gpointer data);
-static gboolean on_button_press    (GooCanvasItemView *view,
-									GooCanvasItemView *target,
-									GdkEventButton    *event,
-									gpointer           data);
-static gboolean on_button_release  (GooCanvasItemView *view,
-									GooCanvasItemView *target,
-									GdkEventButton    *event,
-									gpointer          data);
+static gboolean on_button_press    (GooCanvasItem *item,
+									GooCanvasItem *target,
+									GdkEventButton *event,
+									gpointer data);
+static gboolean on_button_release  (GooCanvasItem *item,
+									GooCanvasItem *target,
+									GdkEventButton *event,
+									gpointer data);
 static void clear_selection        (gpointer key, gpointer val, gpointer data);
 static void load_map_file          (GtkSatMap *satmap);
-static GooCanvasModelSimple*       create_canvas_model (GtkSatMap *satmap);
+static GooCanvasItemModel*         create_canvas_model (GtkSatMap *satmap);
 static gdouble arccos              (gdouble, gdouble);
 static gboolean pole_is_covered    (sat_t *sat);
 static gboolean mirror_lon         (sat_t *sat, gdouble rangelon, gdouble *mlon);
@@ -101,7 +101,7 @@ static void sort_points_y          (GtkSatMap *satmap, sat_t *sat, GooCanvasPoin
 static gint compare_coordinates_x  (gconstpointer a, gconstpointer b, gpointer data);
 static gint compare_coordinates_y  (gconstpointer a, gconstpointer b, gpointer data);
 static void update_selected        (GtkSatMap *satmap, sat_t *sat);
-static void draw_grid_lines        (GtkSatMap *satmap, GooCanvasItem *root);
+static void draw_grid_lines        (GtkSatMap *satmap, GooCanvasItemModel *root);
 static void redraw_grid_lines      (GtkSatMap *satmap);
 
 static GtkVBoxClass *parent_class = NULL;
@@ -202,7 +202,7 @@ GtkWidget*
 gtk_sat_map_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 {
 	GtkWidget *satmap;
-	GooCanvasModelSimple *canvas_model;
+	GooCanvasItemModel *root;
 	guint32 col;
 
 	satmap = g_object_new (GTK_TYPE_SAT_MAP, NULL);
@@ -252,7 +252,7 @@ gtk_sat_map_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 	GTK_SAT_MAP (satmap)->infobgd = rgba2html (col);
 
 	/* create the canvas */
-	GTK_SAT_MAP (satmap)->canvas = goo_canvas_view_new ();
+	GTK_SAT_MAP (satmap)->canvas = goo_canvas_new ();
 
 	/* safely load a background map */
 	load_map_file (GTK_SAT_MAP (satmap));
@@ -262,29 +262,29 @@ gtk_sat_map_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
 	   even though the map shrinks => better to set default size of
 	   main container window.
 	*/
-	/* 	gtk_widget_set_size_request (GTK_SAT_MAP (satmap)->canvas, */
-	/* 	gdk_pixbuf_get_width (GTK_SAT_MAP (satmap)->origmap), */
+	/*  gtk_widget_set_size_request (GTK_SAT_MAP (satmap)->canvas, */
+	/*  gdk_pixbuf_get_width (GTK_SAT_MAP (satmap)->origmap), */
 	/*  gdk_pixbuf_get_height (GTK_SAT_MAP (satmap)->origmap)); */
 
-	goo_canvas_view_set_bounds (GOO_CANVAS_VIEW (GTK_SAT_MAP (satmap)->canvas), 0, 0,
-								gdk_pixbuf_get_width (GTK_SAT_MAP (satmap)->origmap),
-								gdk_pixbuf_get_height (GTK_SAT_MAP (satmap)->origmap));
+	goo_canvas_set_bounds (GOO_CANVAS (GTK_SAT_MAP (satmap)->canvas), 0, 0,
+							gdk_pixbuf_get_width (GTK_SAT_MAP (satmap)->origmap),
+							gdk_pixbuf_get_height (GTK_SAT_MAP (satmap)->origmap));
 
 	/* connect size-request signal */
 	g_signal_connect (GTK_SAT_MAP (satmap)->canvas, "size-allocate",
 					  G_CALLBACK (size_allocate_cb), satmap);
-	g_signal_connect (GTK_SAT_MAP (satmap)->canvas, "item_view_created",
-					  (GtkSignalFunc) on_item_view_created, satmap);
+	g_signal_connect (GTK_SAT_MAP (satmap)->canvas, "item_created",
+					  (GtkSignalFunc) on_item_created, satmap);
 	g_signal_connect_after (GTK_SAT_MAP (satmap)->canvas, "realize",
 							(GtkSignalFunc) on_canvas_realized, satmap);
 
 	gtk_widget_show (GTK_SAT_MAP (satmap)->canvas);
 
 	/* create the canvas model */
-	canvas_model = create_canvas_model (GTK_SAT_MAP (satmap));
-	goo_canvas_view_set_model (GOO_CANVAS_VIEW (GTK_SAT_MAP (satmap)->canvas),
-							   GOO_CANVAS_MODEL (canvas_model));
-	g_object_unref (canvas_model);
+	root = create_canvas_model (GTK_SAT_MAP (satmap));
+	goo_canvas_set_root_item_model (GOO_CANVAS (GTK_SAT_MAP (satmap)->canvas), root);
+
+	g_object_unref (root);
 
 	/* plot each sat on the canvas */
 	g_hash_table_foreach (GTK_SAT_MAP (satmap)->sats, plot_sat, GTK_SAT_MAP (satmap));
@@ -303,18 +303,15 @@ gtk_sat_map_new (GKeyFile *cfgdata, GHashTable *sats, qth_t *qth)
  *  on the canvas.
  *
  */
-static GooCanvasModelSimple *
+static GooCanvasItemModel *
 create_canvas_model (GtkSatMap *satmap)
 {
-	GooCanvasModelSimple *canvas_model;
-	GooCanvasItem *root;
+	GooCanvasItemModel *root;
 	gchar *buff;
 	gfloat x,y;
 	guint32 col;
 
-	canvas_model = goo_canvas_model_simple_new ();
-
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_group_model_new (NULL, NULL);
 
 	/* map dimensions */
 	satmap->width = gdk_pixbuf_get_width (satmap->origmap);
@@ -323,12 +320,13 @@ create_canvas_model (GtkSatMap *satmap)
 	satmap->y0 = 0;
 
 	/* background map */
-	satmap->map = goo_canvas_image_new (root,
-										satmap->origmap,
-										satmap->x0,
-										satmap->y0,
-										NULL);
-	goo_canvas_item_lower (satmap->map, NULL);
+	satmap->map = goo_canvas_image_model_new (root,
+											  satmap->origmap,
+											  satmap->x0,
+											  satmap->y0,
+											  NULL);
+
+	goo_canvas_item_model_lower (satmap->map, NULL);
 
 	/* grid lines */
 	draw_grid_lines (satmap, root);
@@ -341,20 +339,21 @@ create_canvas_model (GtkSatMap *satmap)
 
 	lonlat_to_xy (satmap, satmap->qth->lon, satmap->qth->lat, &x, &y);
 	
-	satmap->qthmark = goo_canvas_rect_new (root,
-										   x - MARKER_SIZE_HALF,
-										   y - MARKER_SIZE_HALF,
-										   2 * MARKER_SIZE_HALF,
-										   2 * MARKER_SIZE_HALF,
-										   "fill-color-rgba", col,
-										   "stroke-color-rgba", col,
-										   NULL);
-	satmap->qthlabel = goo_canvas_text_new (root, satmap->qth->name,
-											x, y+2,	-1,
-											GTK_ANCHOR_NORTH,
-											"font", "Sans 8",
-											"fill-color-rgba", col,
-											NULL);
+	satmap->qthmark = goo_canvas_rect_model_new (root,
+												 x - MARKER_SIZE_HALF,
+												 y - MARKER_SIZE_HALF,
+												 2 * MARKER_SIZE_HALF,
+												 2 * MARKER_SIZE_HALF,
+												 "fill-color-rgba", col,
+												 "stroke-color-rgba", col,
+												 NULL);
+
+	satmap->qthlabel = goo_canvas_text_model_new (root, satmap->qth->name,
+												  x, y+2, -1,
+												  GTK_ANCHOR_NORTH,
+												  "font", "Sans 8",
+												  "fill-color-rgba", col,
+												  NULL);
 
 	/* QTH info */
 	col = mod_cfg_get_int (satmap->cfgdata,
@@ -362,13 +361,13 @@ create_canvas_model (GtkSatMap *satmap)
 						   MOD_CFG_MAP_INFO_COL,
 						   SAT_CFG_INT_MAP_INFO_COL);
 
-	satmap->locnam = goo_canvas_text_new (root, "",
-										  satmap->x0 + 2, satmap->y0 + 1, -1,
-										  GTK_ANCHOR_NORTH_WEST,
-										  "font", "Sans 8",
-										  "fill-color-rgba", col,
-										  "use-markup", TRUE,
-										  NULL);
+	satmap->locnam = goo_canvas_text_model_new (root, "",
+												satmap->x0 + 2, satmap->y0 + 1, -1,
+												GTK_ANCHOR_NORTH_WEST,
+												"font", "Sans 8",
+												"fill-color-rgba", col,
+												"use-markup", TRUE,
+												NULL);
 
 	/* set text only if QTH info is enabled */
 	if (satmap->qthinfo) {
@@ -388,14 +387,14 @@ create_canvas_model (GtkSatMap *satmap)
 	}
 
 	/* next event */
-	satmap->next = goo_canvas_text_new (root, "",
-										satmap->x0+satmap->width - 2,
-										satmap->y0 + 1, -1,
-										GTK_ANCHOR_NORTH_EAST,
-										"font", "Sans 8",
-										"fill-color-rgba", col,
-										"use-markup", TRUE,
-										NULL);
+	satmap->next = goo_canvas_text_model_new (root, "",
+											  satmap->x0+satmap->width - 2,
+											  satmap->y0 + 1, -1,
+											  GTK_ANCHOR_NORTH_EAST,
+											  "font", "Sans 8",
+											  "fill-color-rgba", col,
+											  "use-markup", TRUE,
+											  NULL);
 
 	/* set text only if QTH info is enabled */
 	if (satmap->eventinfo) {
@@ -406,28 +405,28 @@ create_canvas_model (GtkSatMap *satmap)
 	}
 
 	/* cursor track */
-	satmap->curs = goo_canvas_text_new (root, "",
-										satmap->x0 + 2,
-										satmap->y0 + satmap->height - 1,
-										-1,
-										GTK_ANCHOR_SOUTH_WEST,
-										"font", "Sans 8",
-										"fill-color-rgba", col,
-										"use-markup", TRUE,
-										NULL);
+	satmap->curs = goo_canvas_text_model_new (root, "",
+											  satmap->x0 + 2,
+											  satmap->y0 + satmap->height - 1,
+											  -1,
+											  GTK_ANCHOR_SOUTH_WEST,
+											  "font", "Sans 8",
+											  "fill-color-rgba", col,
+											  "use-markup", TRUE,
+											  NULL);
 
 	/* info about a selected satellite */
-	satmap->sel = goo_canvas_text_new (root, "",
-									   satmap->x0 + satmap->width - 2,
-									   satmap->y0 + satmap->height - 1,
-									   -1,
-									   GTK_ANCHOR_SOUTH_EAST,
-									   "font", "Sans 8",
-									   "fill-color-rgba", col,
-									   "use-markup", TRUE,
-									   NULL);
+	satmap->sel = goo_canvas_text_model_new (root, "",
+											 satmap->x0 + satmap->width - 2,
+											 satmap->y0 + satmap->height - 1,
+											 -1,
+											 GTK_ANCHOR_SOUTH_EAST,
+											 "font", "Sans 8",
+											 "fill-color-rgba", col,
+											 "use-markup", TRUE,
+											 NULL);
 
-	return canvas_model;
+	return root;
 }
 
 
@@ -473,7 +472,7 @@ update_map_size (GtkSatMap *satmap)
 	GtkAllocation allocation;
 	GdkPixbuf *pbuf;
 	gfloat x, y;
-	gfloat ratio;	/* ratio between map width and height */
+	gfloat ratio;   /* ratio between map width and height */
 	gfloat size;    /* size = min (alloc.w, ratio*alloc.h) */
 
 	if (GTK_WIDGET_REALIZED (satmap)) {
@@ -581,10 +580,10 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 	GtkSatMap *satmap = GTK_SAT_MAP(data);
 
 	/* raise info items */
-	goo_canvas_item_raise (satmap->sel, NULL);
-	goo_canvas_item_raise (satmap->locnam, NULL);
-	goo_canvas_item_raise (satmap->next, NULL);
-	goo_canvas_item_raise (satmap->curs, NULL);
+	goo_canvas_item_model_raise (satmap->sel, NULL);
+	goo_canvas_item_model_raise (satmap->locnam, NULL);
+	goo_canvas_item_model_raise (satmap->next, NULL);
+	goo_canvas_item_model_raise (satmap->curs, NULL);
 }
 
 
@@ -756,8 +755,8 @@ xy_to_lonlat (GtkSatMap *p, gfloat x, gfloat y, gfloat *lon, gfloat *lat)
  * is to update the cursor text with lat and lon coordinates.
  */
 static gboolean
-on_motion_notify (GooCanvasItemView *view,
-				  GooCanvasItemView *target,
+on_motion_notify (GooCanvasItem *item,
+				  GooCanvasItem *target,
 				  GdkEventMotion *event,
 				  gpointer data)
 {
@@ -787,6 +786,10 @@ on_motion_notify (GooCanvasItemView *view,
 
 
 /** \brief Finish canvas item setup.
+ *  \param canvas 
+ *  \param item
+ *  \param model 
+ *  \param data Pointer to the GtkSatMap object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
  * the corresponding signals to the created items.
@@ -797,21 +800,21 @@ on_motion_notify (GooCanvasItemView *view,
  * \bug Should filter out QTH or do we want to click on the QTH?
  */
 static void
-on_item_view_created (GooCanvasView     *view,
-					  GooCanvasItemView *item_view,
-					  GooCanvasItem     *item,
-					  gpointer           data)
+on_item_created (GooCanvas *canvas,
+				 GooCanvasItem *item,
+				 GooCanvasItemModel *model,
+				 gpointer data)
 {
-	if (!goo_canvas_item_get_parent (item))	{
+	if (!goo_canvas_item_model_get_parent (model)) {
 		/* root item / canvas */
-		g_signal_connect (item_view, "motion_notify_event",
+		g_signal_connect (item, "motion_notify_event",
 						  (GtkSignalFunc) on_motion_notify, data);
 	}
 
 	else if (!g_object_get_data (G_OBJECT (item), "skip-signal-connection")) {
-		g_signal_connect (item_view, "button_press_event",
+		g_signal_connect (item, "button_press_event",
 						  (GtkSignalFunc) on_button_press, data);
-		g_signal_connect (item_view, "button_release_event",
+		g_signal_connect (item, "button_release_event",
 						  (GtkSignalFunc) on_button_release, data);
 	}
 }
@@ -824,15 +827,14 @@ on_item_view_created (GooCanvasView     *view,
  * created and executed.
  */
 static gboolean
-on_button_press (GooCanvasItemView *view,
-				 GooCanvasItemView *target,
+on_button_press (GooCanvasItem *item,
+				 GooCanvasItem *target,
 				 GdkEventButton *event,
 				 gpointer data)
 {
-
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
+	GooCanvasItemModel *model = goo_canvas_item_get_model (item);
 	GtkSatMap *satmap = GTK_SAT_MAP (data);
-	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "catnum"));
+	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (model), "catnum"));
 	gint *catpoint = NULL;
 	sat_t *sat = NULL;
 
@@ -873,15 +875,14 @@ on_button_press (GooCanvasItemView *view,
  * deselecting a satellite
  */
 static gboolean
-on_button_release (GooCanvasItemView *view,
-				   GooCanvasItemView *target,
+on_button_release (GooCanvasItem *item,
+				   GooCanvasItem *target,
 				   GdkEventButton *event,
 				   gpointer data)
 {
-
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
+	GooCanvasItemModel *model = goo_canvas_item_get_model (item);
 	GtkSatMap *satmap = GTK_SAT_MAP (data);
-	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "catnum"));
+	gint catnum = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (model), "catnum"));
 	gint *catpoint = NULL;
 	sat_map_obj_t *obj = NULL;
 	guint32  col;
@@ -1626,8 +1627,7 @@ plot_sat (gpointer key, gpointer value, gpointer data)
 	GtkSatMap *satmap = GTK_SAT_MAP (data);
 	sat_map_obj_t *obj = NULL;
 	sat_t *sat = SAT(value);
-	GooCanvasModel *model;
-	GooCanvasItem  *root;
+	GooCanvasItemModel *root;
 	gint *catnum;
 	guint32 col,covcol;
 	gfloat x,y;
@@ -1651,8 +1651,7 @@ plot_sat (gpointer key, gpointer value, gpointer data)
 	obj->track_data.lines = NULL;
 	obj->track_orbit = 0;
 
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (satmap->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (satmap->canvas));
 
 	/* satellite color */
 	col = mod_cfg_get_int (satmap->cfgdata,
@@ -1671,23 +1670,23 @@ plot_sat (gpointer key, gpointer value, gpointer data)
 		covcol = 0x00000000;
 	}
 
-	obj->marker = goo_canvas_rect_new (root,
-									   x - MARKER_SIZE_HALF,
-									   y - MARKER_SIZE_HALF,
-									   2 * MARKER_SIZE_HALF,
-									   2 * MARKER_SIZE_HALF,
-									   "fill-color-rgba", col,
-									   "stroke-color-rgba", col,
-									   NULL);
+	obj->marker = goo_canvas_rect_model_new (root,
+											 x - MARKER_SIZE_HALF,
+											 y - MARKER_SIZE_HALF,
+											 2 * MARKER_SIZE_HALF,
+											 2 * MARKER_SIZE_HALF,
+											 "fill-color-rgba", col,
+											 "stroke-color-rgba", col,
+											 NULL);
 
-	obj->label = goo_canvas_text_new (root, sat->tle.sat_name,
-									  x, 
-									  y+2,	
-									  -1,
-									  GTK_ANCHOR_NORTH,
-									  "font", "Sans 8",
-									  "fill-color-rgba", col,
-									  NULL);
+	obj->label = goo_canvas_text_model_new (root, sat->tle.sat_name,
+											x, 
+											y+2,
+											-1,
+											GTK_ANCHOR_NORTH,
+											"font", "Sans 8",
+											"fill-color-rgba", col,
+											NULL);
 
 	g_object_set_data (G_OBJECT (obj->marker), "catnum", GINT_TO_POINTER (*catnum));
 	g_object_set_data (G_OBJECT (obj->label), "catnum", GINT_TO_POINTER (*catnum));
@@ -1701,28 +1700,28 @@ plot_sat (gpointer key, gpointer value, gpointer data)
 	obj->oldrcnum = obj->newrcnum;
 
 	/* always create first part of range circle */
-	obj->range1 = goo_canvas_item_new (root, GOO_TYPE_CANVAS_POLYLINE,
-									   "points", points1,
-									   "line-width", 1.0,
-									   "fill-color-rgba", covcol,
-									   "stroke-color-rgba", col,
-									   "line-cap", CAIRO_LINE_CAP_SQUARE,
-									   "line-join", CAIRO_LINE_JOIN_MITER,
-									   NULL);
+	obj->range1 = goo_canvas_polyline_model_new (root, FALSE, 0,
+												 "points", points1,
+												 "line-width", 1.0,
+												 "fill-color-rgba", covcol,
+												 "stroke-color-rgba", col,
+												 "line-cap", CAIRO_LINE_CAP_SQUARE,
+												 "line-join", CAIRO_LINE_JOIN_MITER,
+												 NULL);
 	g_object_set_data (G_OBJECT (obj->range1), "catnum", GINT_TO_POINTER (*catnum));
 	
 	/* create second part if available */
 	if (obj->newrcnum == 2) {
 		//g_print ("N1:%d  N2:%d\n", points1->num_points, points2->num_points);
 
-		obj->range2 = goo_canvas_item_new (root, GOO_TYPE_CANVAS_POLYLINE,
-										   "points", points2,
-										   "line-width", 1.0,
-										   "fill-color-rgba", covcol,
-										   "stroke-color-rgba", col,
-										   "line-cap", CAIRO_LINE_CAP_SQUARE,
-										   "line-join", CAIRO_LINE_JOIN_MITER,
-										   NULL);
+		obj->range2 = goo_canvas_polyline_model_new (root, FALSE, 0,
+													 "points", points2,
+													 "line-width", 1.0,
+													 "fill-color-rgba", covcol,
+													 "stroke-color-rgba", col,
+													 "line-cap", CAIRO_LINE_CAP_SQUARE,
+													 "line-join", CAIRO_LINE_JOIN_MITER,
+													 NULL);
 		g_object_set_data (G_OBJECT (obj->range2), "catnum", GINT_TO_POINTER (*catnum));
 
 	}
@@ -1740,22 +1739,20 @@ plot_sat (gpointer key, gpointer value, gpointer data)
 static void
 update_sat (gpointer key, gpointer value, gpointer data)
 {
-	gint			*catnum;
-	GtkSatMap		*satmap = GTK_SAT_MAP (data);
-	sat_map_obj_t	*obj = NULL;
-	sat_t			*sat = SAT(value);
-	gfloat			x, y;
-	gdouble			oldx, oldy; 
-	gdouble			now;// = get_current_daynum ();
-	GooCanvasModel	*model;
-	GooCanvasItem	*root;
-	gint			idx;
-	guint32			col,covcol;
+	gint               *catnum;
+	GtkSatMap          *satmap = GTK_SAT_MAP (data);
+	sat_map_obj_t      *obj = NULL;
+	sat_t              *sat = SAT(value);
+	gfloat             x, y;
+	gdouble            oldx, oldy; 
+	gdouble            now;  // = get_current_daynum ();
+	GooCanvasItemModel *root;
+	gint               idx;
+	guint32            col,covcol;
 
 	//gdouble sspla,ssplo;
 
-	model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (satmap->canvas));
-	root = goo_canvas_model_get_root_item (model);
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (satmap->canvas));
 
 	catnum = g_new0 (gint, 1);
 	*catnum = sat->tle.catnr;
@@ -1862,14 +1859,14 @@ update_sat (gpointer key, gpointer value, gpointer data)
 				else {
 					covcol = 0x00000000;
 				}
-				obj->range2 = goo_canvas_item_new (root, GOO_TYPE_CANVAS_POLYLINE,
-												   "points", points2,
-												   "line-width", 1.0,
-												   "fill-color-rgba", covcol,
-												   "stroke-color-rgba", col,
-												   "line-cap", CAIRO_LINE_CAP_SQUARE,
-												   "line-join", CAIRO_LINE_JOIN_MITER,
-												   NULL);
+				obj->range2 = goo_canvas_polyline_model_new (root, FALSE, 0,
+															 "points", points2,
+															 "line-width", 1.0,
+															 "fill-color-rgba", covcol,
+															 "stroke-color-rgba", col,
+															 "line-cap", CAIRO_LINE_CAP_SQUARE,
+															 "line-join", CAIRO_LINE_JOIN_MITER,
+															 NULL);
 				g_object_set_data (G_OBJECT (obj->range2), "catnum",
 								   GINT_TO_POINTER (*catnum));
 			}
@@ -1883,9 +1880,9 @@ update_sat (gpointer key, gpointer value, gpointer data)
 		else {
 			if (obj->oldrcnum == 2) {
 				/* remove second part */
-				idx = goo_canvas_item_find_child (root, obj->range2);
+				idx = goo_canvas_item_model_find_child (root, obj->range2);
 				if (idx != -1) {
-					goo_canvas_item_remove_child (root, idx);
+					goo_canvas_item_model_remove_child (root, idx);
 				}
 			}
 		}
@@ -1914,7 +1911,12 @@ update_sat (gpointer key, gpointer value, gpointer data)
 }
 
 
-/** \brief Update information about the selected satellite. */
+/** \brief Update information about the selected satellite.
+ *  \param satmap Pointer to the GtkSatMap widget.
+ *  \param sat Pointer to the selected satellite
+ *
+ * 
+ */
 static void
 update_selected (GtkSatMap *satmap, sat_t *sat)
 {
@@ -1922,73 +1924,98 @@ update_selected (GtkSatMap *satmap, sat_t *sat)
 	gchar        *ch,*cm,*cs;
 	gchar        *alsstr,*text;
 	gdouble       number, now;
+	gboolean      isgeo = FALSE;  /* set to TRUE if satellite appears to be GEO */
 
 	now = satmap->tstamp;//get_current_daynum ();
 
 	if (sat->el > 0.0) {
-		number = sat->los - now;
-		alsstr = g_strdup ("LOS");
+		if (sat->los > 0.0) {
+			number = sat->los - now;
+			alsstr = g_strdup ("LOS");
+		}
+		else {
+			isgeo = TRUE;
+		}
 	}
 	else {
-		number = sat->aos - now;
-		alsstr = g_strdup ("AOS");
+		if (sat->aos > 0.0) {
+			number = sat->aos - now;
+			alsstr = g_strdup ("AOS");
+		}
+		else {
+			isgeo = TRUE;
+		}
 	}
 
-	/* convert julian date to seconds */
-	s = (guint) (number * 86400);
-
-	/* extract hours */
-	h = (guint) floor (s/3600);
-	s -= 3600*h;
-
-	/* leading zero */
-	if ((h > 0) && (h < 10))
-		ch = g_strdup ("0");
-	else
-		ch = g_strdup ("");
-
-	/* extract minutes */
-	m = (guint) floor (s/60);
-	s -= 60*m;
-
-	/* leading zero */
-	if (m < 10)
-		cm = g_strdup ("0");
-	else
-		cm = g_strdup ("");
-
-	/* leading zero */
-	if (s < 10)
-		cs = g_strdup (":0");
-	else
-		cs = g_strdup (":");
-
-	if (h > 0) {
-		text = g_strdup_printf ("<span background=\"#%s\"> "\
-								"%s %s in %s%d:%s%d%s%d </span>",
-								satmap->infobgd, sat->tle.sat_name,
-								alsstr, ch, h, cm, m, cs, s);
+	/* if satellite appears to be GEO don't attempt to show AOS/LOS */
+	if (isgeo) {
+		if (sat->el > 0.0) {
+			text = g_strdup_printf ("<span background=\"#%s\"> %s: Always in range </span>",
+									satmap->infobgd, sat->tle.sat_name);
+		}
+		else {
+			text = g_strdup_printf ("<span background=\"#%s\"> %s: Always out of range </span>",
+									satmap->infobgd, sat->tle.sat_name);
+		}
 	}
 	else {
-		text = g_strdup_printf ("<span background=\"#%s\"> "\
-								"%s %s in %s%d%s%d </span>",
-								satmap->infobgd, sat->tle.sat_name,
-								alsstr,	cm, m, cs, s);
+		/* convert julian date to seconds */
+		s = (guint) (number * 86400);
+
+		/* extract hours */
+		h = (guint) floor (s/3600);
+		s -= 3600*h;
+
+		/* leading zero */
+		if ((h > 0) && (h < 10))
+			ch = g_strdup ("0");
+		else
+			ch = g_strdup ("");
+
+		/* extract minutes */
+		m = (guint) floor (s/60);
+		s -= 60*m;
+
+		/* leading zero */
+		if (m < 10)
+			cm = g_strdup ("0");
+		else
+			cm = g_strdup ("");
+
+		/* leading zero */
+		if (s < 10)
+			cs = g_strdup (":0");
+		else
+			cs = g_strdup (":");
+
+		if (h > 0) {
+			text = g_strdup_printf ("<span background=\"#%s\"> "\
+									"%s %s in %s%d:%s%d%s%d </span>",
+									satmap->infobgd, sat->tle.sat_name,
+									alsstr, ch, h, cm, m, cs, s);
+		}
+		else {
+			text = g_strdup_printf ("<span background=\"#%s\"> "\
+									"%s %s in %s%d%s%d </span>",
+									satmap->infobgd, sat->tle.sat_name,
+									alsstr, cm, m, cs, s);
+		}
+
+		g_free (ch);
+		g_free (cm);
+		g_free (cs);
+		g_free (alsstr);
 	}
 
+	/* update info text */
 	g_object_set (satmap->sel, "text", text, NULL);
-
 	g_free (text);
-	g_free (ch);
-	g_free (cm);
-	g_free (cs);
-	g_free (alsstr);
 }
 
 
 /** \brief Add grid lines and labels to the map. */
 static void
-draw_grid_lines (GtkSatMap *satmap, GooCanvasItem *root)
+draw_grid_lines (GtkSatMap *satmap, GooCanvasItemModel *root)
 {
 	gdouble		xstep, ystep;
 	gfloat		lon, lat;
@@ -2008,16 +2035,17 @@ draw_grid_lines (GtkSatMap *satmap, GooCanvasItem *root)
 	/* horizontal grid */
 	for (i = 0; i < 5; i++) {
 		/* line */
-		satmap->gridh[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) satmap->x0,
-														 (gdouble) (satmap->y0 + (i+1)*ystep),
-														 (gdouble) (satmap->x0 + satmap->width),
-														 (gdouble) (satmap->y0 + (i+1)*ystep),
-														 "stroke-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 0.5,
-														 NULL);
+		satmap->gridh[i] = goo_canvas_polyline_model_new_line (root,
+															   (gdouble) satmap->x0,
+															   (gdouble) (satmap->y0 + (i+1)*ystep),
+															   (gdouble) (satmap->x0 + satmap->width),
+															   (gdouble) (satmap->y0 + (i+1)*ystep),
+															   "stroke-color-rgba", col,
+															   "line-cap", CAIRO_LINE_CAP_SQUARE,
+															   "line-join", CAIRO_LINE_JOIN_MITER,
+															   "line-width", 0.5,
+															   NULL);
+
 		/* FIXME: Use dotted line pattern? */
 
 		/* label */
@@ -2032,41 +2060,41 @@ draw_grid_lines (GtkSatMap *satmap, GooCanvasItem *root)
 			}
 		}
 		buf = g_strdup_printf ("%.0f\302\260%c", lat, hmf);
-		satmap->gridhlab[i] = goo_canvas_text_new (root, 
-													buf,
-													(gdouble) (satmap->x0 + 15),
-													(gdouble) (satmap->y0 + (i+1)*ystep),
-													-1, GTK_ANCHOR_NORTH,
-													"font", "Sans 8", "fill-color-rgba", col,
-													NULL);
-		g_free (buf);	
+		satmap->gridhlab[i] = goo_canvas_text_model_new (root, 
+														 buf,
+														 (gdouble) (satmap->x0 + 15),
+														 (gdouble) (satmap->y0 + (i+1)*ystep),
+														 -1, GTK_ANCHOR_NORTH,
+														 "font", "Sans 8", "fill-color-rgba", col,
+														 NULL);
+		g_free (buf);
 
 		/* lower items to be just above the background map
 		   or below it if lines are invisible
 		*/
 		if (satmap->showgrid) {
-			goo_canvas_item_raise (satmap->gridh[i], satmap->map);
-			goo_canvas_item_raise (satmap->gridhlab[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridh[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridhlab[i], satmap->map);
 		}
 		else {
-			goo_canvas_item_lower (satmap->gridh[i], satmap->map);
-			goo_canvas_item_lower (satmap->gridhlab[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridh[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridhlab[i], satmap->map);
 		}
 	}
 
 	/* vertical grid */
 	for (i = 0; i < 11; i++) {
 		/* line */
-		satmap->gridv[i] = goo_canvas_polyline_new_line (root,
-														 (gdouble) (satmap->x0 + (i+1)*xstep),
-														 (gdouble) satmap->y0,
-														 (gdouble) (satmap->x0 + (i+1)*xstep),
-														 (gdouble) (satmap->y0 + satmap->height),
-														 "stroke-color-rgba", col,
-														 "line-cap", CAIRO_LINE_CAP_SQUARE,
-														 "line-join", CAIRO_LINE_JOIN_MITER,
-														 "line-width", 0.5,
-														 NULL);
+		satmap->gridv[i] = goo_canvas_polyline_model_new_line (root,
+															   (gdouble) (satmap->x0 + (i+1)*xstep),
+															   (gdouble) satmap->y0,
+															   (gdouble) (satmap->x0 + (i+1)*xstep),
+															   (gdouble) (satmap->y0 + satmap->height),
+															   "stroke-color-rgba", col,
+															   "line-cap", CAIRO_LINE_CAP_SQUARE,
+															   "line-join", CAIRO_LINE_JOIN_MITER,
+															   "line-width", 0.5,
+															   NULL);
 
 		/* label */
 		xy_to_lonlat (satmap, satmap->x0 + (i+1)*xstep, satmap->y0, &lon, &lat);
@@ -2080,25 +2108,25 @@ draw_grid_lines (GtkSatMap *satmap, GooCanvasItem *root)
 			}
 		}
 		buf = g_strdup_printf ("%.0f\302\260%c", lon, hmf);
-		satmap->gridvlab[i] = goo_canvas_text_new (root, 
-													buf,
-													(gdouble) (satmap->x0 + (i+1)*xstep),
-													(gdouble) (satmap->y0 + satmap->height - 5),
-													-1, GTK_ANCHOR_EAST,
-													"font", "Sans 8", "fill-color-rgba", col,
-													NULL);
+		satmap->gridvlab[i] = goo_canvas_text_model_new (root, 
+														 buf,
+														 (gdouble) (satmap->x0 + (i+1)*xstep),
+														 (gdouble) (satmap->y0 + satmap->height - 5),
+														 -1, GTK_ANCHOR_EAST,
+														 "font", "Sans 8", "fill-color-rgba", col,
+														 NULL);
 		g_free (buf);
 
 		/* lower items to be just above the background map
 		   or below it if lines are invisible
 		*/
 		if (satmap->showgrid) {
-			goo_canvas_item_raise (satmap->gridv[i], satmap->map);
-			goo_canvas_item_raise (satmap->gridvlab[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridv[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridvlab[i], satmap->map);
 		}
 		else {
-			goo_canvas_item_lower (satmap->gridv[i], satmap->map);
-			goo_canvas_item_lower (satmap->gridvlab[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridv[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridvlab[i], satmap->map);
 		}
 	}
 }
@@ -2136,11 +2164,11 @@ static void redraw_grid_lines (GtkSatMap *satmap)
 		   or below it if lines are invisible
 		*/
 		if (satmap->showgrid) {
-			goo_canvas_item_raise (satmap->gridh[i], satmap->map);
-			goo_canvas_item_raise (satmap->gridhlab[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridh[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridhlab[i], satmap->map);
 		}
 		else
-			goo_canvas_item_lower (satmap->gridh[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridh[i], satmap->map);
 	}
 
 	/* vertical grid */
@@ -2156,20 +2184,20 @@ static void redraw_grid_lines (GtkSatMap *satmap)
 
 		/* update label */
 		g_object_set (satmap->gridvlab[i],
-						"x", (gdouble) (satmap->x0 + (i+1)*xstep),
-					  	"y", (gdouble) (satmap->y0 + satmap->height - 5),
-					  	NULL);
+					  "x", (gdouble) (satmap->x0 + (i+1)*xstep),
+					  "y", (gdouble) (satmap->y0 + satmap->height - 5),
+					  NULL);
 
 		/* lower items to be just above the background map
 		   or below it if lines are invisible
 		*/
 		if (satmap->showgrid) {
-			goo_canvas_item_raise (satmap->gridv[i], satmap->map);
-			goo_canvas_item_raise (satmap->gridvlab[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridv[i], satmap->map);
+			goo_canvas_item_model_raise (satmap->gridvlab[i], satmap->map);
 		}
 		else {
-			goo_canvas_item_lower (satmap->gridv[i], satmap->map);
-			goo_canvas_item_lower (satmap->gridvlab[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridv[i], satmap->map);
+			goo_canvas_item_model_lower (satmap->gridvlab[i], satmap->map);
 		}
 	}
 }
