@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
     Copyright (C)  2006-2007  William J Beksi, KC2EXL.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
@@ -90,10 +90,10 @@ typedef struct {
 	gboolean        istarget;     /*!< is this object the target */
 
 	/* graphical elements */
-	GooCanvasItem  *marker;       /*!< A small rectangle showing sat pos. */
-	GooCanvasItem  *label;        /*!< Satellite name. */
-	GooCanvasItem  *range1;       /*!< First part of the range circle. */
-	GooCanvasItem  *range2;       /*!< Second part of the range circle. */
+	GooCanvasItemModel  *marker;  /*!< A small rectangle showing sat pos. */
+	GooCanvasItemModel  *label;   /*!< Satellite name. */
+	GooCanvasItemModel  *range1;  /*!< First part of the range circle. */
+	GooCanvasItemModel  *range2;  /*!< Second part of the range circle. */
 
 	/* book keeping */
 	guint           oldrcnum;     /*!< Number of RC parts in prev. cycle. */
@@ -112,52 +112,52 @@ typedef struct {
 typedef struct {
 	GtkVBox vbox;
 
-	GtkWidget  *canvas;            /*!< The canvas widget. */
+	GtkWidget  *canvas;                 /*!< The canvas widget. */
 
-	GooCanvasItem *map;            /*!< The canvas map item. */
+	GooCanvasItemModel *map;            /*!< The canvas map item. */
 
-	GooCanvasItem *qthmark;        /*!< QTH marker, e.g. small rectangle. */
-	GooCanvasItem *qthlabel;       /*!< Label showing the QTH name. */
+	GooCanvasItemModel *qthmark;        /*!< QTH marker, e.g. small rectangle. */
+	GooCanvasItemModel *qthlabel;       /*!< Label showing the QTH name. */
 
-	GooCanvasItem *locnam;         /*!< Location name. */
-	GooCanvasItem *curs;           /*!< Cursor tracking text. */
-	GooCanvasItem *next;           /*!< Next event text. */
-	GooCanvasItem *sel;            /*!< Text showing info about the selected satellite. */
+	GooCanvasItemModel *locnam;         /*!< Location name. */
+	GooCanvasItemModel *curs;           /*!< Cursor tracking text. */
+	GooCanvasItemModel *next;           /*!< Next event text. */
+	GooCanvasItemModel *sel;            /*!< Text showing info about the selected satellite. */
 
-	GooCanvasItem *gridv[11];      /*!< Vertical grid lines, 30 deg resolution. */
-	GooCanvasItem *gridvlab[11];   /*!< Vertical grid  labels. */
-	GooCanvasItem *gridh[5];       /*!< Horizontal grid lines, 30 deg resolution. */
-	GooCanvasItem *gridhlab[5];    /*!< Horizontal grid labels. */
+	GooCanvasItemModel *gridv[11];      /*!< Vertical grid lines, 30 deg resolution. */
+	GooCanvasItemModel *gridvlab[11];   /*!< Vertical grid  labels. */
+	GooCanvasItemModel *gridh[5];       /*!< Horizontal grid lines, 30 deg resolution. */
+	GooCanvasItemModel *gridhlab[5];    /*!< Horizontal grid labels. */
 
-	gdouble     naos;    	       /*!< Next event time. */
-	gint        ncat;              /*!< Next event catnum. */
+	gdouble     naos;                   /*!< Next event time. */
+	gint        ncat;                   /*!< Next event catnum. */
 
-	gdouble     tstamp;            /*!< Time stamp for calculations; set by GtkSatModule */
+	gdouble     tstamp;                 /*!< Time stamp for calculations; set by GtkSatModule */
 
-	GKeyFile   *cfgdata;           /*!< Module configuration data. */
-	GHashTable *sats;              /*!< Pointer to satellites (owned by parent GtkSatModule). */
-	qth_t      *qth;               /*!< Pointer to current location. */
+	GKeyFile   *cfgdata;                /*!< Module configuration data. */
+	GHashTable *sats;                   /*!< Pointer to satellites (owned by parent GtkSatModule). */
+	qth_t      *qth;                    /*!< Pointer to current location. */
 
-	GHashTable *obj;     	       /*!< Canvas items representing each satellite. */
+	GHashTable *obj;                    /*!< Canvas items representing each satellite. */
 
-	guint       x0;      	       /*!< X0 of the canvas map. */
-	guint       y0;      	       /*!< Y0 of the canvas map. */
-	guint       width;   	       /*!< Map width. */
-	guint       height;  	       /*!< Map height. */
+	guint       x0;                     /*!< X0 of the canvas map. */
+	guint       y0;                     /*!< Y0 of the canvas map. */
+	guint       width;                  /*!< Map width. */
+	guint       height;                 /*!< Map height. */
 
-	guint       refresh; 	       /*!< Refresh rate. */
-	guint       counter; 	       /*!< Cycle counter. */
+	guint       refresh;                /*!< Refresh rate. */
+	guint       counter;                /*!< Cycle counter. */
 
-	gboolean    qthinfo;           /*!< Show the QTH info. */
-	gboolean    eventinfo;         /*!< Show info about the next event. */
-	gboolean    cursinfo;          /*!< Track the mouse cursor. */
-	gboolean    showgrid;          /*!< Show grid on map. */
-	gboolean    keepratio;         /*!< Keep map aspect ratio. */
-	gboolean    resize;            /*!< Flag indicating that the map has been resized. */
+	gboolean    qthinfo;                /*!< Show the QTH info. */
+	gboolean    eventinfo;              /*!< Show info about the next event. */
+	gboolean    cursinfo;               /*!< Track the mouse cursor. */
+	gboolean    showgrid;               /*!< Show grid on map. */
+	gboolean    keepratio;              /*!< Keep map aspect ratio. */
+	gboolean    resize;                 /*!< Flag indicating that the map has been resized. */
 
-	gchar      *infobgd;           /*!< Background color of info text. */
+	gchar      *infobgd;                /*!< Background color of info text. */
 
-	GdkPixbuf  *origmap;           /*!< Original map kept here for high quality scaling. */
+	GdkPixbuf  *origmap;                /*!< Original map kept here for high quality scaling. */
 
 } GtkSatMap;
 
