@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -34,14 +34,18 @@
 #include "mod-mgr.h"
 #include "compat.h"
 #include "gtk-sky-glance.h"
+#include "sat-cfg.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "gtk-sat-module.h"
 #include "gtk-sat-module-tmg.h"
 #include "gtk-sat-module-popup.h"
+#include "config-keys.h"
 
 
+extern GtkWidget *app; /* in main.c */
+
 
 static void config_cb        (GtkWidget *menuitem, gpointer data);
 static void clone_cb         (GtkWidget *menuitem, gpointer data);
@@ -55,6 +59,7 @@ static void name_changed     (GtkWidget *widget, gpointer data);
 static gint window_delete    (GtkWidget *widget, GdkEvent *event, gpointer data);
 
 
+
 /** \brief Create and run GtkSatModule popup menu.
  *  \param module The module that should have the popup menu attached to it.
  *
@@ -242,6 +247,8 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 	GtkSatModule *module = GTK_SAT_MODULE (data);
 	GtkSatModule *newmod;
 	gchar        *source,*target;
+	gchar        *icon;      /* icon file name */
+	gchar        *title;     /* window title */
 
 
 	dialog = gtk_dialog_new_with_buttons (_("Clone Module"),
@@ -337,8 +344,31 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 				newmod->state = module->state;
 
 				if (newmod->state == GTK_SAT_MOD_STATE_DOCKED) {
-					/* just add to module manager */
+
+					/* add to module manager */
 					mod_mgr_add_module (GTK_WIDGET (newmod), TRUE);
+
+					/* try to reproduce divisions betwenn views */
+					switch (module->layout) {
+
+					case GTK_SAT_MOD_LAYOUT_2:
+						gtk_paned_set_position (GTK_PANED (newmod->vpaned),
+												gtk_paned_get_position (GTK_PANED (module->vpaned)));
+						break;
+
+					case GTK_SAT_MOD_LAYOUT_3:
+					case GTK_SAT_MOD_LAYOUT_4:
+						gtk_paned_set_position (GTK_PANED (newmod->vpaned),
+												gtk_paned_get_position (GTK_PANED (module->vpaned)));
+						gtk_paned_set_position (GTK_PANED (newmod->hpaned),
+												gtk_paned_get_position (GTK_PANED (module->hpaned)));
+						break;
+
+					default:
+						break;
+
+					}
+
 				}
 				else {
 					/* add to module manager */
@@ -348,21 +378,31 @@ clone_cb         (GtkWidget *menuitem, gpointer data)
 					newmod->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 					gtk_window_set_title (GTK_WINDOW (newmod->win),
 										  newmod->name);
+					title = g_strconcat ("GPREDICT: ",
+										 newmod->name,
+										 " (", newmod->qth->name, ")",
+										 NULL);
+					gtk_window_set_title (GTK_WINDOW (newmod->win), title);
+					g_free (title);
 
 					/* use size of source module */
 					gtk_window_set_default_size (GTK_WINDOW (newmod->win),
 												 GTK_WIDGET (module)->allocation.width,
 												 GTK_WIDGET (module)->allocation.height);
 
-					/** FIXME: window icon and such */
+					g_signal_connect (G_OBJECT (newmod->win), "configure_event",
+									  G_CALLBACK (module_window_config_cb), newmod);
 
 					/* add module to window */
 					gtk_container_add (GTK_CONTAINER (newmod->win),
 									   GTK_WIDGET (newmod));
 
-					if (newmod->state == GTK_SAT_MOD_STATE_FULLSCREEN) {
-						gtk_window_fullscreen (GTK_WINDOW (newmod->win));
+					/* window icon */
+					icon = icon_file_name ("gpredict-icon.png");
+					if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+						gtk_window_set_icon_from_file (GTK_WINDOW (newmod->win), icon, NULL);
 					}
+					g_free (icon);
 
 					/* show window */
 					gtk_widget_show_all (newmod->win);
@@ -410,7 +450,9 @@ static void
 docking_state_cb (GtkWidget *menuitem, gpointer data)
 {
 	GtkWidget *module = GTK_WIDGET (data);
-	gint w,h;
+	gint       w,h;
+	gchar     *icon;      /* icon file name */
+	gchar     *title;     /* window title */
 
 
 
@@ -418,9 +460,32 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 
 	case GTK_SAT_MOD_STATE_DOCKED:
 
-		w = module->allocation.width;
-		h = module->allocation.height;
-
+        /* get stored size; use size from main window if size not explicitly stoed */
+        if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_WIN_WIDTH,
+								NULL)) {
+            w = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+										MOD_CFG_GLOBAL_SECTION,
+										MOD_CFG_WIN_WIDTH,
+										NULL);
+        }
+        else {
+            w = module->allocation.width;
+        }
+        if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_WIN_HEIGHT,
+								NULL)) {
+            h = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+										MOD_CFG_GLOBAL_SECTION,
+										MOD_CFG_WIN_HEIGHT,
+										NULL);
+        }
+        else {
+            h = module->allocation.height;
+        }
+        
 		/* increase reference count of module */
 		g_object_ref (module);
 
@@ -433,11 +498,44 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 
 		/* create window */
 		GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
-							  GTK_SAT_MODULE (module)->name);
+		title = g_strconcat ("GPREDICT: ",
+							 GTK_SAT_MODULE (module)->name,
+							 " (", GTK_SAT_MODULE (module)->qth->name, ")",
+							 NULL);
+		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win), title);
+		g_free (title);
 		gtk_window_set_default_size (GTK_WINDOW (GTK_SAT_MODULE (module)->win), w, h);
+        g_signal_connect (G_OBJECT (GTK_SAT_MODULE (module)->win), "configure_event",
+                          G_CALLBACK (module_window_config_cb), module);
 
-		/** FIXME: window icon and such */
+		/* window icon */
+		icon = icon_file_name ("gpredict-icon.png");
+		if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+			gtk_window_set_icon_from_file (GTK_WINDOW (GTK_SAT_MODULE (module)->win), icon, NULL);
+		}
+		g_free (icon);
+
+        /* move window to stored position if requested by configuration */
+        if (sat_cfg_get_bool (SAT_CFG_BOOL_MOD_WIN_POS) &&
+            g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_WIN_POS_X,
+								NULL) &&
+            g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_WIN_POS_Y,
+								NULL)) {
+                
+            gtk_window_move (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
+                             g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+													 MOD_CFG_GLOBAL_SECTION,
+													 MOD_CFG_WIN_POS_X, NULL),
+                             g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+													 MOD_CFG_GLOBAL_SECTION,
+													 MOD_CFG_WIN_POS_Y,
+													 NULL));
+
+        }
 
 		/* add module to window */
 		gtk_container_add (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
@@ -445,14 +543,23 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 		/* change internal state */
 		GTK_SAT_MODULE (module)->state = GTK_SAT_MOD_STATE_WINDOW;
 
+        /* store new state in configuration */
+        g_key_file_set_integer (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_STATE,
+								GTK_SAT_MOD_STATE_WINDOW);
+
 		/* decrease reference count of module */
 		g_object_unref (module);
 
 		/* show window */
 		gtk_widget_show_all (GTK_SAT_MODULE (module)->win);
-
+        
 		/* reparent time manager window if visible */
-		/* gtk_window_Set_transient_for */
+		if (GTK_SAT_MODULE (module)->tmgActive) {
+			gtk_window_set_transient_for (GTK_WINDOW (GTK_SAT_MODULE (module)->tmgWin),
+										  GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+		}
 
 		break;
 
@@ -472,6 +579,12 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
 			GTK_SAT_MODULE (module)->hpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->hpaned));
 		}
+        
+		/* reparent time manager window if visible */
+		if (GTK_SAT_MODULE (module)->tmgActive) {
+			gtk_window_set_transient_for (GTK_WINDOW (GTK_SAT_MODULE (module)->tmgWin),
+										  GTK_WINDOW (app));
+		}
 
 		/* remove module from window, destroy window */
 		gtk_container_remove (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
@@ -483,13 +596,16 @@ docking_state_cb (GtkWidget *menuitem, gpointer data)
 
 		/* change internal state */
 		GTK_SAT_MODULE (module)->state = GTK_SAT_MOD_STATE_DOCKED;
+        
+        /* store new state in configuration */
+        g_key_file_set_integer (GTK_SAT_MODULE (module)->cfgdata,
+								MOD_CFG_GLOBAL_SECTION,
+								MOD_CFG_STATE,
+								GTK_SAT_MOD_STATE_DOCKED);
 
 		/* decrease reference count of module */
 		g_object_unref (module);
 
-		/* reparent time manager window if visible */
-		/* gtk_window_Set_transient_for */
-
 
 		break;
 
@@ -516,6 +632,9 @@ static void
 screen_state_cb  (GtkWidget *menuitem, gpointer data)
 {
 	GtkWidget *module = GTK_WIDGET (data);
+    gint       w,h;
+	gchar     *icon;      /* icon file name */
+	gchar     *title;     /* window title */
 
 
 	switch (GTK_SAT_MODULE (module)->state) {
@@ -534,8 +653,19 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 
 		/* create window */
 		GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
-							  GTK_SAT_MODULE (module)->name);
+		title = g_strconcat ("GPREDICT: ",
+							 GTK_SAT_MODULE (module)->name,
+							 " (", GTK_SAT_MODULE (module)->qth->name, ")",
+							 NULL);
+		gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win), title);
+		g_free (title);
+
+		/* window icon */
+		icon = icon_file_name ("gpredict-icon.png");
+		if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+			gtk_window_set_icon_from_file (GTK_WINDOW (GTK_SAT_MODULE (module)->win), icon, NULL);
+		}
+		g_free (icon);
 
 		/* add module to window */
 		gtk_container_add (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
@@ -550,6 +680,12 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 
 		/* show window */
 		gtk_widget_show_all (GTK_SAT_MODULE (module)->win);
+        
+		/* reparent time manager window if visible */
+		if (GTK_SAT_MODULE (module)->tmgActive) {
+			gtk_window_set_transient_for (GTK_WINDOW (GTK_SAT_MODULE (module)->tmgWin),
+										  GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+		}
 
 		break;
 
@@ -569,7 +705,7 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 
 
 	case GTK_SAT_MOD_STATE_FULLSCREEN:
-
+        
 		/* store paned positions */
 		if (GTK_SAT_MODULE (module)->layout == GTK_SAT_MOD_LAYOUT_2) {
 			GTK_SAT_MODULE (module)->vpanedpos = gtk_paned_get_position (GTK_PANED (GTK_SAT_MODULE (module)->vpaned));
@@ -583,7 +719,36 @@ screen_state_cb  (GtkWidget *menuitem, gpointer data)
 
 		/* change internal state */
 		GTK_SAT_MODULE (module)->state = GTK_SAT_MOD_STATE_WINDOW;
-		gtk_window_unfullscreen (GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+        gtk_window_unfullscreen (GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+
+        /* get stored size; use some standard size if not explicitly specified */
+        if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_WIDTH, NULL)) {
+            w = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_WIDTH, NULL);
+        }
+        else {
+            w = 800;
+        }
+        if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_HEIGHT, NULL)) {
+            h = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_HEIGHT, NULL);
+        }
+        else {
+            h = 600;
+        }
+        gtk_window_set_default_size (GTK_WINDOW (GTK_SAT_MODULE (module)->win), w, h);
+
+        /* move window to stored position if requested by configuration */
+        if (sat_cfg_get_bool (SAT_CFG_BOOL_MOD_WIN_POS) &&
+            g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_X, NULL) &&
+            g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_Y, NULL)) {
+                
+            gtk_window_move (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
+                             g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_X, NULL),
+                                     g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_Y, NULL));
+
+            }
+
+        /* store new state in configuration */
+        g_key_file_set_integer (GTK_SAT_MODULE (module)->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_STATE, GTK_SAT_MOD_STATE_WINDOW);
 
 		break;
 
@@ -791,3 +956,57 @@ window_delete      (GtkWidget *widget,
 {
 	return FALSE;
 }
+
+
+
+/** \brief Snoop window position and size when main window receives configure event.
+ *  \param widget Pointer to the module window.
+ *  \param event  Pointer to the event structure.
+ *  \param data   Pointer to user data, in this case the module.
+ *
+ * This function is used to trap configure events in order to store the current
+ * position and size of the module window.
+ *
+ * \note unfortunately GdkEventConfigure ignores the window gravity, while
+ *       the only way we have of setting the position doesn't. We have to
+ *       call get_position because it does pay attention to the gravity.
+ *
+ * \note The logic in the code has been borrowed from gaim/pidgin http://pidgin.im/
+ *
+ */
+gboolean
+module_window_config_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
+{
+    gint x, y;
+    GtkSatModule *module = GTK_SAT_MODULE (data);
+
+
+    /* data is only useful when window is visible */
+    if (GTK_WIDGET_VISIBLE (widget))
+        gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
+    else
+        return FALSE; /* carry on normally */
+ 
+#ifdef G_OS_WIN32
+    /* Workaround for GTK+ bug # 169811 - "configure_event" is fired
+    when the window is being maximized */
+    if (gdk_window_get_state (widget->window) & GDK_WINDOW_STATE_MAXIMIZED) {
+        return FALSE;
+    }
+#endif
+
+    /* don't save off-screen positioning */
+    if (x + event->width < 0 || y + event->height < 0 ||
+        x > gdk_screen_width() || y > gdk_screen_height()) {
+        return FALSE; /* carry on normally */
+    }
+
+    /* store the position and size */
+    g_key_file_set_integer (module->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_X, x);
+    g_key_file_set_integer (module->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_POS_Y, y);
+    g_key_file_set_integer (module->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_WIDTH, event->width);
+    g_key_file_set_integer (module->cfgdata, MOD_CFG_GLOBAL_SECTION, MOD_CFG_WIN_HEIGHT, event->height);
+
+    /* continue to handle event normally */
+    return FALSE;
+}
