@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -452,7 +452,6 @@ tmg_time_set (GtkWidget *widget, gpointer data)
 
 	/* update time only if we are in manual time control */
 	if (!mod->throttle && !mod->reset) {
-		g_print ("TIME SET\n");
 
 		/* get date and time from widgets */
 		gtk_calendar_get_date (GTK_CALENDAR (mod->tmgCal),
@@ -471,9 +470,11 @@ tmg_time_set (GtkWidget *widget, gpointer data)
 		tim.tm_min = (int) min;
 		tim.tm_sec = (int) sec;
 
-		g_print ("%d/%d/%d %d:%d:%d.%d\n", tim.tm_year,	tim.tm_mon,
-				 tim.tm_mday, tim.tm_hour, tim.tm_min, tim.tm_sec, msec);
-
+		sat_log_log (SAT_LOG_LEVEL_DEBUG,
+					 _("%s: %d/%d/%d %d:%d:%d.%d"),
+					 __FUNCTION__,
+					 tim.tm_year, tim.tm_mon, tim.tm_mday,
+					 tim.tm_hour, tim.tm_min, tim.tm_sec, msec);
 
 		/* convert to Julian Date (FIXME: only UTC?) */
 		jd = Julian_Date (&tim);
