@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -51,7 +51,7 @@
 #include "mod-cfg-get-param.h"
 #include "mod-mgr.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "time-tools.h"
 #include "orbit-tools.h"
@@ -191,6 +191,7 @@ gtk_sat_module_destroy (GtkObject *object)
 {
 	GtkSatModule *module = GTK_SAT_MODULE (object);
 
+    
 	/* stop timeout */
 	if (module->timerid != -1)
 		g_source_remove (module->timerid);
@@ -201,8 +202,6 @@ gtk_sat_module_destroy (GtkObject *object)
 		module->tmgActive = FALSE;
 	}
 
-	/* FIXME: save state */
-
 	if (module->qth) {
 		gtk_sat_data_free_qth (module->qth);
 		module->qth = NULL;
@@ -261,8 +260,19 @@ gtk_sat_module_new (const gchar *cfgfile)
 	gtk_sat_module_read_cfg_data (GTK_SAT_MODULE (widget), cfgfile);
 
 	/* module state */
-	/* FIXME: may want to put in own window */
-	GTK_SAT_MODULE (widget)->state = GTK_SAT_MOD_STATE_DOCKED;
+	if ((g_key_file_has_key (GTK_SAT_MODULE (widget)->cfgdata,
+							 MOD_CFG_GLOBAL_SECTION,
+							 MOD_CFG_STATE, NULL)) &&
+		sat_cfg_get_bool (SAT_CFG_BOOL_MOD_STATE)) {
+
+		GTK_SAT_MODULE (widget)->state =
+			g_key_file_get_integer (GTK_SAT_MODULE (widget)->cfgdata,
+									MOD_CFG_GLOBAL_SECTION,
+									MOD_CFG_STATE, NULL);
+	}
+	else {
+		GTK_SAT_MODULE (widget)->state = GTK_SAT_MOD_STATE_DOCKED;
+	}
 
 	/* initialise time keeping vars to current time */
 	GTK_SAT_MODULE (widget)->rtNow = get_current_daynum ();
@@ -905,7 +915,7 @@ gtk_sat_module_update_sat    (gpointer key, gpointer val, gpointer data)
 	obs_set_t     obs_set = {0,0,0,0};
 	geodetic_t    sat_geodetic = {0,0,0,0};
 	geodetic_t    obs_geodetic = {0,0,0,0};
-
+	gdouble       maxdt;
 
 	g_return_if_fail ((val != NULL) && (data != NULL));
 
@@ -924,8 +934,15 @@ gtk_sat_module_update_sat    (gpointer key, gpointer val, gpointer data)
 	    (sat->otype != ORBIT_TYPE_DECAYED) &&
 	    has_aos (sat, module->qth))	{
 
-		sat->aos = find_aos (sat, module->qth, daynum);
-		sat->los = find_los (sat, module->qth, daynum);
+		/* Note that has_aos may return TRUE for geostationary sats
+		   whose orbit deviate from a true-geostat orbit, however,
+		   find_aos and find_los will not go beyond the time limit
+		   we specify (in those cases they return 0.0 for AOS/LOS times.
+		   We use SAT_CFG_INT_PRED_LOOK_AHEAD for upper time limit
+		*/
+		maxdt = (gdouble) sat_cfg_get_int (SAT_CFG_INT_PRED_LOOK_AHEAD);
+		sat->aos = find_aos (sat, module->qth, daynum, maxdt);
+		sat->los = find_los (sat, module->qth, daynum, maxdt);
 
 	}
 
@@ -1027,10 +1044,8 @@ gtk_sat_module_close_cb       (GtkWidget *button, gpointer data)
 				 _("%s: Module %s recevied CLOSE signal."),
 				 __FUNCTION__, name);
 
-	/* no need, in fact, should NOT save config here otherwise
-	   we may overwrite new configuration.
-	*/
-
+    /* save configuration to ensure that dynamic data like state is stored */
+    mod_cfg_save (module->name, module->cfgdata);
 
 	switch (module->state) {
 
