@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -43,7 +43,7 @@
 #include "locator.h"
 #include "sat-vis.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 
 
@@ -499,6 +499,10 @@ update_field            (GtkSingleSat *ssat, guint i)
 			buff = g_strconcat (alstr, tbuf, NULL);
 
 		}
+		else {
+			buff = g_strdup (_("N/A"));
+		}
+
 		g_free (alstr);
 
 		break;
@@ -527,6 +531,9 @@ update_field            (GtkSingleSat *ssat, guint i)
 
 			buff = g_strdup (tbuf);
 		}
+		else {
+			buff = g_strdup (_("N/A"));
+		}
 		break;
 
 
@@ -553,6 +560,9 @@ update_field            (GtkSingleSat *ssat, guint i)
 
 			buff = g_strdup (tbuf);
 		}
+		else {
+			buff = g_strdup (_("N/A"));
+		}
 		break;
 
 
@@ -835,6 +845,20 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 	menuitem = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
+	/* Alarm */
+	menuitem = gtk_check_menu_item_new_with_label (_("Alarm"));
+	gtk_widget_set_sensitive (menuitem, FALSE);
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+
+	/* Announce */
+	menuitem = gtk_check_menu_item_new_with_label (_("Announce"));
+	gtk_widget_set_sensitive (menuitem, FALSE);
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+
+	/* separator */
+	menuitem = gtk_separator_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
+
 	select_menu = gtk_menu_new ();
 
 	for (i = 0; i < n; i++) {
@@ -865,20 +889,6 @@ gtk_single_sat_popup_cb       (GtkWidget *button, gpointer data)
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), select_menu);
 	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
 
-	/* separator */
-	menuitem = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-
-	/* Alarm */
-	menuitem = gtk_check_menu_item_new_with_label (_("Alarm"));
-	gtk_widget_set_sensitive (menuitem, FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-
-	/* Announce */
-	menuitem = gtk_check_menu_item_new_with_label (_("Announce"));
-	gtk_widget_set_sensitive (menuitem, FALSE);
-	gtk_menu_shell_append (GTK_MENU_SHELL(menu), menuitem);
-
 	gtk_widget_show_all (menu);
 
 	/* Note: event can be NULL here when called from view_onPopupMenu;
