@@ -51,7 +51,7 @@
 //#include "gtk-sky-glance-popup.h"
 #include "gtk-sky-glance.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include <goocanvas.h>
 
@@ -70,25 +70,25 @@ static void gtk_sky_glance_destroy     (GtkObject *object);
 static void size_allocate_cb           (GtkWidget *widget,
 										GtkAllocation *allocation,
 										gpointer data);
-static gboolean on_motion_notify       (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_motion_notify       (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventMotion *event,
 										gpointer data);
-static void on_item_view_created       (GooCanvasView     *view,
-										GooCanvasItemView *item_view,
-										GooCanvasItem     *item,
-										gpointer           data);
+static void on_item_created            (GooCanvas *canvas,
+										GooCanvasItem *item,
+										GooCanvasItemModel *model,
+										gpointer data);
 static void on_canvas_realized         (GtkWidget *canvas, gpointer data);
-static gboolean on_button_press        (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_button_press        (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventButton *event,
 										gpointer data);
-static gboolean on_button_release      (GooCanvasItemView *view,
-										GooCanvasItemView *target,
+static gboolean on_button_release      (GooCanvasItem *item,
+										GooCanvasItem *target,
 										GdkEventButton *event,
 										gpointer data);
 
-static GooCanvasModelSimple* create_canvas_model (GtkSkyGlance *skg);
+static GooCanvasItemModel* create_canvas_model (GtkSkyGlance *skg);
 
 static gdouble t2x (GtkSkyGlance *skg, gdouble t);
 static gdouble x2t (GtkSkyGlance *skg, gdouble x);
@@ -184,7 +184,6 @@ gtk_sky_glance_destroy (GtkObject *object)
 		n = g_slist_length (GTK_SKY_GLANCE (object)->passes);
 		for (i = 0; i < n; i++) {
 			skypass = (sky_pass_t *) g_slist_nth_data (GTK_SKY_GLANCE (object)->passes, i);
-			//GTK_SKY_GLANCE (object)->passes = g_slist_remove (GTK_SKY_GLANCE (object)->passes, skypass);
 			free_pass (skypass->pass);
 			g_free (skypass);
 		}
@@ -227,13 +226,11 @@ GtkWidget*
 gtk_sky_glance_new (GHashTable *sats, qth_t *qth)
 {
 	GtkWidget *skg;
-	GooCanvasModelSimple *canvas_model;
+	GooCanvasItemModel *root;
 	GdkColor bg_color = {0, 0xFFFF, 0xFFFF, 0xFFFF};
 
-
 	skg = g_object_new (GTK_TYPE_SKY_GLANCE, NULL);
 
-
 	/* FIXME? */
 	GTK_SKY_GLANCE (skg)->sats = sats;
 	GTK_SKY_GLANCE (skg)->qth  = qth;
@@ -252,20 +249,20 @@ gtk_sky_glance_new (GHashTable *sats, qth_t *qth)
 	GTK_SKY_GLANCE (skg)->pps = SKG_PIX_PER_SAT;
 
 	/* create the canvas */
-	GTK_SKY_GLANCE (skg)->canvas = goo_canvas_view_new ();
+	GTK_SKY_GLANCE (skg)->canvas = goo_canvas_new ();
 	gtk_widget_modify_base (GTK_SKY_GLANCE (skg)->canvas, GTK_STATE_NORMAL, &bg_color);
 	gtk_widget_set_size_request (GTK_SKY_GLANCE (skg)->canvas,
 								 GTK_SKY_GLANCE (skg)->w,
 								 GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
-	goo_canvas_view_set_bounds (GOO_CANVAS_VIEW (GTK_SKY_GLANCE (skg)->canvas), 0, 0,
-								GTK_SKY_GLANCE (skg)->w,
-								GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
+	goo_canvas_set_bounds (GOO_CANVAS (GTK_SKY_GLANCE (skg)->canvas), 0, 0,
+							GTK_SKY_GLANCE (skg)->w,
+							GTK_SKY_GLANCE (skg)->h + SKG_FOOTER);
 
 	/* connect size-request signal */
 	g_signal_connect (GTK_SKY_GLANCE (skg)->canvas, "size-allocate",
 					  G_CALLBACK (size_allocate_cb), skg);
-	g_signal_connect (GTK_SKY_GLANCE (skg)->canvas, "item_view_created",
-					  (GtkSignalFunc) on_item_view_created, skg);
+	g_signal_connect (GTK_SKY_GLANCE (skg)->canvas, "item_created",
+					  (GtkSignalFunc) on_item_created, skg);
 	g_signal_connect_after (GTK_SKY_GLANCE (skg)->canvas, "realize",
 							(GtkSignalFunc) on_canvas_realized, skg);
 
@@ -273,77 +270,70 @@ gtk_sky_glance_new (GHashTable *sats, qth_t *qth)
 
 
 	/* Create the canvas model */
-	canvas_model = create_canvas_model (GTK_SKY_GLANCE (skg));
-	goo_canvas_view_set_model (GOO_CANVAS_VIEW (GTK_SKY_GLANCE (skg)->canvas),
-							   GOO_CANVAS_MODEL (canvas_model));
-	g_object_unref (canvas_model);
+	root = create_canvas_model (GTK_SKY_GLANCE (skg));
+	goo_canvas_set_root_item_model (GOO_CANVAS (GTK_SKY_GLANCE (skg)->canvas), root);
+
+	g_object_unref (root);
 
 	/* add satellite passes */
 	g_hash_table_foreach (GTK_SKY_GLANCE (skg)->sats, create_sat, skg);
 
-
 	gtk_container_add (GTK_CONTAINER (skg), GTK_SKY_GLANCE (skg)->canvas);
 
 	return skg;
 }
 
 
-
-static GooCanvasModelSimple *
+static GooCanvasItemModel *
 create_canvas_model (GtkSkyGlance *skg)
 {
-	GooCanvasModelSimple *canvas_model;
-	GooCanvasItem        *root;
-	GooCanvasItem        *hrt,*hrl,*hrm;
-	guint                 i,n;
-	gdouble               th,tm;
-	time_t                tt;
-	gdouble               xh,xm;
-	gchar                 buff[3];
+	GooCanvasItemModel *root;
+	GooCanvasItemModel *hrt,*hrl,*hrm;
+	guint              i,n;
+	gdouble            th,tm;
+	time_t             tt;
+	gdouble            xh,xm;
+	gchar              buff[3];
 
 
-	canvas_model = goo_canvas_model_simple_new ();
-
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_group_model_new (NULL, NULL);
 
 	/* cursor tracking line */
-	skg->cursor = goo_canvas_polyline_new_line (root,
-												skg->x0, skg->y0, skg->x0, skg->h,
-												"stroke-color-rgba", 0x000000AF,
-												"line-width", 0.5,
-												NULL);
+	skg->cursor = goo_canvas_polyline_model_new_line (root,
+													  skg->x0, skg->y0, skg->x0, skg->h,
+													  "stroke-color-rgba", 0x000000AF,
+													  "line-width", 0.5,
+													  NULL);
 
 	/* time label */
-	skg->timel = goo_canvas_text_new (root, "--:--", skg->x0 + 5, skg->y0, -1, GTK_ANCHOR_NW,
-									  "font", "Sans 8",
-									  "fill-color-rgba", 0x000000AF,
-									  NULL);
-												
+	skg->timel = goo_canvas_text_model_new (root, "--:--", skg->x0 + 5, skg->y0, -1, GTK_ANCHOR_NW,
+											"font", "Sans 8",
+											"fill-color-rgba", 0x000000AF,
+											NULL);
 
 	/* footer */
-	skg->footer = goo_canvas_rect_new (root,
-									   skg->x0, skg->h,
-									   skg->w, SKG_FOOTER,
-									   "fill-color-rgba", 0x00003FFF,
-									   "stroke-color-rgba", 0xFFFFFFFF,
-									   NULL);
+	skg->footer = goo_canvas_rect_model_new (root,
+											 skg->x0, skg->h,
+											 skg->w, SKG_FOOTER,
+											 "fill-color-rgba", 0x00003FFF,
+											 "stroke-color-rgba", 0xFFFFFFFF,
+											 NULL);
 
 	/* time ticks and labels */
 	if (sat_cfg_get_bool (SAT_CFG_BOOL_USE_LOCAL_TIME))
-		skg->axisl = goo_canvas_text_new (root, _("TIME"),
-										  skg->w / 2, skg->h + SKG_FOOTER - 5,
-										  -1, GTK_ANCHOR_S,
-										  "font", "Sans 9",
-										  "fill-color-rgba", 0xFFFFFFFF,
-										  NULL);
+		skg->axisl = goo_canvas_text_model_new (root, _("TIME"),
+												skg->w / 2, skg->h + SKG_FOOTER - 5,
+												-1, GTK_ANCHOR_S,
+												"font", "Sans 9",
+												"fill-color-rgba", 0xFFFFFFFF,
+												NULL);
 	else
-		skg->axisl = goo_canvas_text_new (root, _("UTC"),
-										  skg->w / 2, skg->h + SKG_FOOTER - 5,
-										  -1, GTK_ANCHOR_S,
-										  "font", "Sans 9",
-										  "fill-color-rgba", 0xFFFFFFFF,
-										  NULL);
-
+		skg->axisl = goo_canvas_text_model_new (root, _("UTC"),
+												skg->w / 2, skg->h + SKG_FOOTER - 5,
+												-1, GTK_ANCHOR_S,
+												"font", "Sans 9",
+												"fill-color-rgba", 0xFFFFFFFF,
+												NULL);
 
 	/* get the first hour and first 30 min slot */
 	/*** FIXME: still a little rough because of rounding errors */
@@ -365,9 +355,9 @@ create_canvas_model (GtkSkyGlance *skg)
 
 		/* hour tick */
 		xh = t2x (skg, th);
-		hrt = goo_canvas_polyline_new_line (root, xh, skg->h, xh, skg->h + 10,
-											"stroke-color-rgba", 0xFFFFFFFF,
-											NULL);
+		hrt = goo_canvas_polyline_model_new_line (root, xh, skg->h, xh, skg->h + 10,
+												  "stroke-color-rgba", 0xFFFFFFFF,
+												  NULL);
 
 		/* hour tick label */
 		tt = (th - 2440587.5)*86400.;
@@ -377,18 +367,17 @@ create_canvas_model (GtkSkyGlance *skg)
 			strftime (buff, 3, "%H", gmtime (&tt));
 		
 		buff[2] = '\0';
-		hrl = goo_canvas_text_new (root, buff, xh, skg->h + 12,
-								   -1, GTK_ANCHOR_N,
-								   "font", "Sans 8",
-								   "fill-color-rgba", 0xFFFFFFFF,
-								   NULL);
+		hrl = goo_canvas_text_model_new (root, buff, xh, skg->h + 12,
+										 -1, GTK_ANCHOR_N,
+										  "font", "Sans 8",
+										  "fill-color-rgba", 0xFFFFFFFF,
+										  NULL);
 
 		/* 30 min tick */
 		xm = t2x (skg, tm);
-		hrm = goo_canvas_polyline_new_line (root, xm, skg->h, xm, skg->h + 5,
-											"stroke-color-rgba", 0xFFFFFFFF,
-											NULL);
-
+		hrm = goo_canvas_polyline_model_new_line (root, xm, skg->h, xm, skg->h + 5,
+												  "stroke-color-rgba", 0xFFFFFFFF,
+												  NULL);
 
 		/* store canvas items */
 		skg->majors = g_slist_append (skg->majors, hrt);
@@ -399,11 +388,10 @@ create_canvas_model (GtkSkyGlance *skg)
 		tm += 0.04167;
 	}
 
-	return canvas_model;
+	return root;
 }
 
 
-
 /** \brief Manage new size allocation.
  *
  * This function is called when the canvas receives a new size allocation,
@@ -576,11 +564,10 @@ on_canvas_realized (GtkWidget *canvas, gpointer data)
 }
 
 
-
 /** \brief Manage mouse motion events. */
 static gboolean
-on_motion_notify (GooCanvasItemView *view,
-				  GooCanvasItemView *target,
+on_motion_notify (GooCanvasItem *item,
+				  GooCanvasItem *target,
 				  GdkEventMotion *event,
 				  gpointer data)
 {
@@ -636,39 +623,36 @@ on_motion_notify (GooCanvasItemView *view,
 }
 
 
-
-
 /** \brief Finish canvas item setup.
- *  \param view
- *  \param item_view
+ *  \param canvas 
  *  \param item
+ *  \param model 
  *  \param data Pointer to the GtkSkyGlance object.
  *
  * This function is called when a canvas item is created. Its purpose is to connect
  * the corresponding signals to the created items.
  */
 static void
-on_item_view_created (GooCanvasView     *view,
-					  GooCanvasItemView *item_view,
-					  GooCanvasItem     *item,
-					  gpointer           data)
+on_item_created (GooCanvas *canvas,
+				 GooCanvasItem *item,
+				 GooCanvasItemModel *model,
+				 gpointer data)
 {
-	if (!goo_canvas_item_get_parent (item))	{
+	if (!goo_canvas_item_model_get_parent (model))	{
 		/* root item / canvas */
-		g_signal_connect (item_view, "motion_notify_event",
+		g_signal_connect (item, "motion_notify_event",
 						  (GtkSignalFunc) on_motion_notify, data);
 	}
 
 	else if (!g_object_get_data (G_OBJECT (item), "skip-signal-connection")) {
-		g_signal_connect (item_view, "button_press_event",
+		g_signal_connect (item, "button_press_event",
 						  (GtkSignalFunc) on_button_press, data);
-		g_signal_connect (item_view, "button_release_event",
+		g_signal_connect (item, "button_release_event",
 						  (GtkSignalFunc) on_button_release, data);
 	}
 }
 
 
-
 /** \brief Manage button press events
  *
  * This function is called when a mouse button is pressed on a satellite object.
@@ -676,13 +660,13 @@ on_item_view_created (GooCanvasView     *view,
  * created and executed.
  */
 static gboolean
-on_button_press (GooCanvasItemView *view,
-				 GooCanvasItemView *target,
+on_button_press (GooCanvasItem *item,
+				 GooCanvasItem *target,
 				 GdkEventButton *event,
 				 gpointer data)
 {
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
-	GtkSkyGlance  *skg = GTK_SKY_GLANCE (data);
+/*  GooCanvasItemModel *model = goo_canvas_item_get_model (item); */
+/*  GtkSkyGlance  *skg = GTK_SKY_GLANCE (data); */
 
 
 	switch (event->button) {
@@ -710,13 +694,13 @@ on_button_press (GooCanvasItemView *view,
  * deselecting a satellite
  */
 static gboolean
-on_button_release (GooCanvasItemView *view,
-				   GooCanvasItemView *target,
+on_button_release (GooCanvasItem *item,
+				   GooCanvasItem *target,
 				   GdkEventButton *event,
 				   gpointer data)
 {
-	GooCanvasItem *item = goo_canvas_item_view_get_item (view);
-	GtkSkyGlance *skg = GTK_SKY_GLANCE (data);
+/*  GooCanvasItemModel *model = goo_canvas_item_get_model (item); */
+/*  GtkSkyGlance  *skg = GTK_SKY_GLANCE (data); */
 
 	switch (event->button) {
 
@@ -734,7 +718,6 @@ on_button_release (GooCanvasItemView *view,
 }
 
 
-
 /** \brief Convert time value to x position.
  *  \param skg The GtkSkyGlance widget.
  *  \param t Julian date
@@ -837,6 +820,7 @@ static void get_colours (guint i, guint *bcol, guint *fcol)
 	*fcol = (tmp * 0x100) | 0xF0;
 }
 
+
 /** \brief Create canvas items for a satellite
  *  \param key Pointer to the hash key (catnum of sat)
  *  \param value Pointer to the current satellite.
@@ -849,17 +833,16 @@ static void get_colours (guint i, guint *bcol, guint *fcol)
 static void
 create_sat (gpointer key, gpointer value, gpointer data)
 {
-	sat_t          *sat = SAT(value);
-	GtkSkyGlance   *skg = GTK_SKY_GLANCE(data);
-	GSList         *passes = NULL;
-	gdouble         maxdt;
-	guint           i,n;
-	pass_t         *tmppass = NULL;
-	sky_pass_t     *skypass;
-	guint           bcol,fcol;          /* colours */
-	GooCanvasItem  *root;
-	GooCanvasModel *canvas_model;
-	GooCanvasItem  *lab;
+	sat_t              *sat = SAT(value);
+	GtkSkyGlance       *skg = GTK_SKY_GLANCE(data);
+	GSList             *passes = NULL;
+	gdouble             maxdt;
+	guint               i,n;
+	pass_t             *tmppass = NULL;
+	sky_pass_t         *skypass;
+	guint               bcol,fcol;          /* colours */
+	GooCanvasItemModel *root;
+	GooCanvasItemModel *lab;
 
 
 	/* FIXME: 
@@ -872,8 +855,7 @@ create_sat (gpointer key, gpointer value, gpointer data)
 /* 	} */
 
 	/* get canvas root */
-	canvas_model = goo_canvas_view_get_model (GOO_CANVAS_VIEW (skg->canvas));
-	root = goo_canvas_model_get_root_item (GOO_CANVAS_MODEL (canvas_model));
+	root = goo_canvas_get_root_item_model (GOO_CANVAS (skg->canvas));
 
 	get_colours (skg->satcnt++, &bcol, &fcol);
 
@@ -900,10 +882,10 @@ create_sat (gpointer key, gpointer value, gpointer data)
 				skypass->catnum = sat->tle.catnr;
 				tmppass = (pass_t *) g_slist_nth_data (passes, i);
 				skypass->pass = copy_pass (tmppass);
-				skypass->box = goo_canvas_rect_new (root, 10, 10, 20, 20, /* dummy coordinates */
-													"stroke-color-rgba", bcol,
-													"fill-color-rgba", fcol,
-													NULL);
+				skypass->box = goo_canvas_rect_model_new (root, 10, 10, 20, 20, /* dummy coordinates */
+														  "stroke-color-rgba", bcol,
+														  "fill-color-rgba", fcol,
+														  NULL);
 													
 				/* store pass data */
 				skg->passes = g_slist_append (skg->passes, skypass);
@@ -919,11 +901,11 @@ create_sat (gpointer key, gpointer value, gpointer data)
 		free_passes (passes);
 
 		/* add satellite label */
-		lab = goo_canvas_text_new (root, sat->tle.sat_name,
-								   5, 0, -1, GTK_ANCHOR_W,
-								   "font", "Sans 8",
-								   "fill-color-rgba", bcol,
-								   NULL);
+		lab = goo_canvas_text_model_new (root, sat->tle.sat_name,
+										 5, 0, -1, GTK_ANCHOR_W,
+										 "font", "Sans 8",
+										 "fill-color-rgba", bcol,
+										 NULL);
 		skg->satlab = g_slist_append (skg->satlab, lab);
 	}
 }
