@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -32,7 +32,7 @@
 #include <glib/gi18n.h>
 #include <math.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sat-cfg.h"
 #include "loc-tree.h"
@@ -118,6 +118,7 @@ loc_tree_create (const gchar *fname,
 	}
 
 	view = gtk_tree_view_new ();
+    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
 
 	/* Create columns.
 	   Note that there are several ways to create and add the individual
