@@ -11,7 +11,7 @@
 
 /*
  *  Hamlib Interface - locator and bearing conversion calls
- *  Copyright (c) 2001-2006 by Stephane Fillod
+ *  Copyright (c) 2001-2007 by Stephane Fillod
  *  Copyright (c) 2003 by Nate Bargmann
  *  Copyright (c) 2003 by Dave Hines
  *
@@ -51,7 +51,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "build-config.h"
 #endif
 
 #include <stdio.h>
