@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -39,7 +39,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #ifdef HAVE_GETOPT_H
 #  include <getopt.h>
@@ -75,6 +75,7 @@ static gboolean tle_upd_note_sent = FALSE;
 static void     gpredict_app_create   (void);
 static gint     gpredict_app_delete   (GtkWidget *, GdkEvent *, gpointer);
 static void     gpredict_app_destroy  (GtkWidget *, gpointer);
+static gboolean gpredict_app_config   (GtkWidget *, GdkEventConfigure *, gpointer);
 static void     gpredict_sig_handler  (int sig);
 static gboolean tle_mon_task          (gpointer data);
 static void     tle_mon_stop          (void);
@@ -84,7 +85,11 @@ static gpointer update_tle_thread     (gpointer data);
 int
 main (int argc, char *argv[])
 {
-	guint  error;
+	guint  error = 0;
+
+#ifdef G_OS_WIN32
+	printf ("Starting gpredict. This may take some time...\n");
+#endif
 
 
 #ifdef ENABLE_NLS
@@ -96,10 +101,11 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* start logger first, so that we can catch error messages if any */
-
+	sat_log_init ();
 
 	/* check that user settings are ok */
 	error = first_time_check_run ();
+
 	if (error) {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
 					 _("%s: User config check failed (code %d). This is fatal.\n"\
@@ -121,6 +127,9 @@ main (int argc, char *argv[])
 
 	sat_cfg_load ();
 
+	/* get logging level */
+	sat_log_set_level (sat_cfg_get_int (SAT_CFG_INT_LOG_LEVEL));
+
 	/* create application */
 	gpredict_app_create ();
 	gtk_widget_show_all (app);
@@ -155,13 +164,24 @@ gpredict_app_create ()
 	title = g_strdup (_("GPREDICT"));
 	icon = icon_file_name ("gpredict-icon.png");
 
-	/* ceate window, add title and icon */
+	/* ceate window, add title and icon, restore size and position */
 	app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+
+	gtk_window_set_title (GTK_WINDOW (app), title);
+
+	/* restore window position and size if requested by config */
+	/* trunk/gtk/gtkblist.c */
+	/* size is always restored */
 	gtk_window_set_default_size (GTK_WINDOW (app),
 								 sat_cfg_get_int (SAT_CFG_INT_WINDOW_WIDTH),
 								 sat_cfg_get_int (SAT_CFG_INT_WINDOW_HEIGHT));
 
-	gtk_window_set_title (GTK_WINDOW (app), title);
+	/* position restored only if requested in config */
+	if (sat_cfg_get_bool (SAT_CFG_BOOL_MAIN_WIN_POS)) {
+		gtk_window_move (GTK_WINDOW (app),
+						 sat_cfg_get_int (SAT_CFG_INT_WINDOW_POS_X),
+						 sat_cfg_get_int (SAT_CFG_INT_WINDOW_POS_Y));
+	}
 
 	gtk_container_add (GTK_CONTAINER (app),
 					   gui_create (app));
@@ -178,6 +198,8 @@ gpredict_app_create ()
 	/* connect delete and destroy signals */
 	g_signal_connect (G_OBJECT (app), "delete_event",
 					  G_CALLBACK (gpredict_app_delete), NULL);    
+	g_signal_connect (G_OBJECT (app), "configure_event",
+					  G_CALLBACK (gpredict_app_config), NULL);    
 	g_signal_connect (G_OBJECT (app), "destroy",
 					  G_CALLBACK (gpredict_app_destroy), NULL);
 
@@ -265,6 +287,7 @@ gpredict_app_destroy    (GtkWidget *widget,
 		sat_cfg_set_int (SAT_CFG_INT_WINDOW_HEIGHT, h);	
 	*/
 	sat_cfg_save ();
+	sat_log_close ();
 	sat_cfg_close ();
 
 	/* exit Gtk+ */
@@ -273,6 +296,59 @@ gpredict_app_destroy    (GtkWidget *widget,
 
 
 
+/** \brief Snoop window position and size when main window receives configure event.
+ *  \param widget Pointer to the gpredict main window.
+ *  \param event  Pointer to the even structure.
+ *  \param data   Pointer to user data (always NULL).
+ *
+ * This function is used to trap configure events in order to store the current
+ * position and size of the main window.
+ *
+ * \note unfortunately GdkEventConfigure ignores the window gravity, while
+ *       the only way we have of setting the position doesn't. We have to
+ *       call get_position because it does pay attention to the gravity.
+ *
+ * \note The logic in the code has been borrowed from gaim/pidgin http://pidgin.im/
+ *
+ */
+static gboolean
+gpredict_app_config   (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
+{
+	gint x, y;
+
+
+	/* data is only useful when window is visible */
+	if (GTK_WIDGET_VISIBLE (widget))
+ 		gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
+	else
+ 		return FALSE; /* carry on normally */
+ 
+#ifdef G_OS_WIN32
+	/* Workaround for GTK+ bug # 169811 - "configure_event" is fired
+	   when the window is being maximized */
+ 	if (gdk_window_get_state (widget->window) & GDK_WINDOW_STATE_MAXIMIZED) {
+ 		return FALSE;
+	}
+#endif
+
+	/* don't save off-screen positioning */
+   	if (x + event->width < 0 || y + event->height < 0 ||
+		x > gdk_screen_width() || y > gdk_screen_height()) {
+
+ 		return FALSE; /* carry on normally */
+	}
+
+ 	/* store the position and size */
+	sat_cfg_set_int (SAT_CFG_INT_WINDOW_POS_X, x);
+	sat_cfg_set_int (SAT_CFG_INT_WINDOW_POS_Y, y);
+	sat_cfg_set_int (SAT_CFG_INT_WINDOW_WIDTH, event->width);
+	sat_cfg_set_int (SAT_CFG_INT_WINDOW_HEIGHT, event->height);
+
+	/* continue to handle event normally */
+	return FALSE;
+}
+
+
 /** \brief Monitor TLE age.
  *
  * This function is called periodically in order to check
