@@ -1,29 +1,29 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
-    Gpredict: Real-time satellite tracking and orbit prediction program
+  Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <csete@users.sourceforge.net>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 /** \defgroup menu The menubar
  *  \ingroup gui
@@ -43,14 +43,17 @@
 #include "sat-cfg.h"
 #include "mod-mgr.h"
 #include "sat-log.h"
+#include "sat-log-browser.h"
 #include "about.h"
 #include "gtk-sat-module.h"
+#include "gtk-sat-module-popup.h"
 #include "gpredict-help.h"
 #include "tle-update.h"
 #include "compat.h"
 #include "menubar.h"
+#include "config-keys.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 
 extern GtkWidget *app;
@@ -59,6 +62,7 @@ extern GtkWidget *app;
 /* private function prototypes */
 static void   menubar_new_mod_cb   (GtkWidget *widget, gpointer data);
 static void   menubar_open_mod_cb  (GtkWidget *widget, gpointer data);
+static void   menubar_message_log  (GtkWidget *widget, gpointer data);
 static void   menubar_app_exit_cb  (GtkWidget *widget, gpointer data);
 static void   menubar_freq_edit_cb (GtkWidget *widget, gpointer data);
 static void   menubar_pref_cb      (GtkWidget *widget, gpointer data);
@@ -70,8 +74,11 @@ static void   menubar_window_cb    (GtkWidget *widget, gpointer data);
 static void   menubar_predict_cb   (GtkWidget *widget, gpointer data);
 static void   menubar_getting_started_cb (GtkWidget *widget, gpointer data);
 static void   menubar_help_cb      (GtkWidget *widget, gpointer data);
+static void   menubar_license_cb   (GtkWidget *widget, gpointer data);
+static void   menubar_news_cb      (GtkWidget *widget, gpointer data);
 static void   menubar_about_cb     (GtkWidget *widget, gpointer data);
 static gchar *select_module        (void);
+static void   create_module_window (GtkWidget *module);
 
 
 /** \brief Regular menu items.
@@ -89,6 +96,8 @@ static GtkActionEntry entries[] = {
 	  N_("Create a new module"), G_CALLBACK (menubar_new_mod_cb) },
 	{ "Open", GTK_STOCK_OPEN, N_("_Open module"), "<control>O",
 	  N_("Open an existing module"), G_CALLBACK (menubar_open_mod_cb) },
+	{ "Log", GTK_STOCK_JUSTIFY_LEFT, "_Log browser", "<control>L",
+	  N_("Open the message log browser"), G_CALLBACK (menubar_message_log) },
 	{ "Exit", GTK_STOCK_QUIT, N_("E_xit"), "<control>Q",
 	  N_("Exit the program"), G_CALLBACK (menubar_app_exit_cb) },
 
@@ -124,9 +133,13 @@ static GtkActionEntry entries[] = {
 	{ "GettingStarted", GTK_STOCK_EXECUTE, N_("Getting Started"), NULL,
 	  N_("Show online user manual, Getting Started Section"),
 	  G_CALLBACK (menubar_getting_started_cb)},
-	{ "Manual", GTK_STOCK_HELP, N_("User Manual"), NULL,
+	{ "Manual", GTK_STOCK_HELP, N_("User Manual"), "F1",
 	  N_("Show online user manual"), G_CALLBACK (menubar_help_cb)},
-	{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	{ "License", NULL, N_("_License"), NULL,
+	  N_("Show the Gpredict license"), G_CALLBACK (menubar_license_cb) },
+	{ "News", NULL, N_("_News"), NULL,
+	  N_("Show what's new in this release"), G_CALLBACK (menubar_news_cb) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About Gpredict"), NULL,
 	  N_("Show about dialog"), G_CALLBACK (menubar_about_cb) },
 };
 
@@ -141,6 +154,8 @@ static const char *menu_desc =
 "         <menuitem action='New'/>"
 "         <menuitem action='Open'/>"
 "         <separator/>"
+"         <menuitem action='Log'/>"
+"         <separator/>"
 "         <menuitem action='Exit'/>"
 "      </menu>"
 "      <menu action='EditMenu'>"
@@ -165,6 +180,9 @@ static const char *menu_desc =
 /* "         <menuitem action='GettingStarted'/>" */
 /* "         <menuitem action='Manual'/>" */
 "         <separator/>"
+"         <menuitem action='License'/>"
+"         <menuitem action='News'/>"
+"         <separator/>"
 "         <menuitem action='About'/>"
 "      </menu>"
 "   </menubar>"
@@ -186,9 +204,9 @@ menubar_create (GtkWidget *window)
 	GtkUIManager   *uimgr;
 	GtkAccelGroup  *accgrp;
 	GError         *error = NULL;
-	GtkWidget      *menuitem;
-	GtkWidget      *image;
-	gchar          *icon;
+/* 	GtkWidget      *menuitem; */
+/* 	GtkWidget      *image; */
+/* 	gchar          *icon; */
 
 
 	/* create action group */
@@ -212,11 +230,11 @@ menubar_create (GtkWidget *window)
 	}
 
 	/* load custom icons */
-/* 	icon = icon_file_name ("gpredict-planner-small.png"); */
-/* 	image = gtk_image_new_from_file (icon); */
-/* 	g_free (icon); */
-/* 	menuitem = gtk_ui_manager_get_widget (uimgr, "/GpredictMenu/ToolsMenu/Glance"); */
-/* 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image); */
+	/* 	icon = icon_file_name ("gpredict-planner-small.png"); */
+	/* 	image = gtk_image_new_from_file (icon); */
+	/* 	g_free (icon); */
+	/* 	menuitem = gtk_ui_manager_get_widget (uimgr, "/GpredictMenu/ToolsMenu/Glance"); */
+	/* 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), image); */
 
 	/* now, finally, get the menubar */
 	menubar = gtk_ui_manager_get_widget (uimgr, "/GpredictMenu");
@@ -242,38 +260,37 @@ menubar_new_mod_cb  (GtkWidget *widget, gpointer data)
 
 
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: Starting new module configurator..."),
-		     __FUNCTION__);
+				 _("%s: Starting new module configurator..."),
+				 __FUNCTION__);
 
 	modnam = mod_cfg_new ();
 
 	if (modnam) {
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			    _("%s: New module name is %s."),
-			    __FUNCTION__, modnam);
+					 _("%s: New module name is %s."),
+					 __FUNCTION__, modnam);
 
 		modfile = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-				       ".gpredict2", G_DIR_SEPARATOR_S,
-				       "modules", G_DIR_SEPARATOR_S,
-				       modnam,
-				       ".mod", NULL);
+							   ".gpredict2", G_DIR_SEPARATOR_S,
+							   "modules", G_DIR_SEPARATOR_S,
+							   modnam,
+							   ".mod", NULL);
 
 		/* create new module */
 		module = gtk_sat_module_new (modfile);
-		GTK_SAT_MODULE (module)->state = GTK_SAT_MOD_STATE_DOCKED;
 
 		if (module == NULL) {
 
 			GtkWidget *dialog;
 
 			dialog = gtk_message_dialog_new (GTK_WINDOW (app),
-							 GTK_DIALOG_MODAL |
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 _("Could not open %s. Please examine "\
-							   "the log messages for details."),
-							 modnam);
+											 GTK_DIALOG_MODAL |
+											 GTK_DIALOG_DESTROY_WITH_PARENT,
+											 GTK_MESSAGE_ERROR,
+											 GTK_BUTTONS_OK,
+											 _("Could not open %s. Please examine "\
+											   "the log messages for details."),
+											 modnam);
 
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -295,8 +312,8 @@ menubar_new_mod_cb  (GtkWidget *widget, gpointer data)
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			    _("%s: New module config cancelled."),
-			    __FUNCTION__);
+					 _("%s: New module config cancelled."),
+					 __FUNCTION__);
 	}
 }
 
@@ -311,44 +328,57 @@ menubar_open_mod_cb  (GtkWidget *widget, gpointer data)
 
 
 	sat_log_log (SAT_LOG_LEVEL_DEBUG,
-		     _("%s: Open existing module..."),
-		     __FUNCTION__);
+				 _("%s: Open existing module..."),
+				 __FUNCTION__);
 	
 	modnam = select_module ();
 
 	if (modnam) {
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			    _("%s: Open module %s."),
-			    __FUNCTION__, modnam);
+					 _("%s: Open module %s."),
+					 __FUNCTION__, modnam);
 
 		modfile = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-				       ".gpredict2", G_DIR_SEPARATOR_S,
-				       "modules", G_DIR_SEPARATOR_S,
-				       modnam,
-				       ".mod", NULL);
+							   ".gpredict2", G_DIR_SEPARATOR_S,
+							   "modules", G_DIR_SEPARATOR_S,
+							   modnam,
+							   ".mod", NULL);
 
 		/* create new module */
 		module = gtk_sat_module_new (modfile);
-		GTK_SAT_MODULE (module)->state = GTK_SAT_MOD_STATE_DOCKED;
 
 		if (module == NULL) {
 			/* mod manager could not create the module */
 			GtkWidget *dialog;
 
 			dialog = gtk_message_dialog_new (GTK_WINDOW (app),
-							 GTK_DIALOG_MODAL |
-							 GTK_DIALOG_DESTROY_WITH_PARENT,
-							 GTK_MESSAGE_ERROR,
-							 GTK_BUTTONS_OK,
-							 _("Could not open %s. Please examine "\
-							   "the log messages for details."),
-							 modnam);
+											 GTK_DIALOG_MODAL |
+											 GTK_DIALOG_DESTROY_WITH_PARENT,
+											 GTK_MESSAGE_ERROR,
+											 GTK_BUTTONS_OK,
+											 _("Could not open %s. Please examine "\
+											   "the log messages for details."),
+											 modnam);
 
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
 		else {
-			mod_mgr_add_module (module, TRUE);
+
+			/* if module state was window or user does not want to restore the
+			   state of the modules, pack the module into the notebook */
+			if ((GTK_SAT_MODULE (module)->state == GTK_SAT_MOD_STATE_DOCKED) ||
+				!sat_cfg_get_bool (SAT_CFG_BOOL_MOD_STATE)) {
+				
+				mod_mgr_add_module (module, TRUE);
+				
+			}
+			else {
+				mod_mgr_add_module (module, FALSE);
+				create_module_window (module);
+			}
+
+			//mod_mgr_add_module (module, TRUE);
 
 			/* get size allocation from parent and set some reasonable
 			   initial GtkPaned positions
@@ -364,12 +394,19 @@ menubar_open_mod_cb  (GtkWidget *widget, gpointer data)
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			    _("%s: Open module cancelled."),
-			    __FUNCTION__);
+					 _("%s: Open module cancelled."),
+					 __FUNCTION__);
 	}
 }
 
 
+static void
+menubar_message_log  (GtkWidget *widget, gpointer data)
+{
+	sat_log_browser_open ();
+}
+
+
 static void
 menubar_app_exit_cb  (GtkWidget *widget, gpointer data)
 {
@@ -390,6 +427,7 @@ menubar_pref_cb      (GtkWidget *widget, gpointer data)
 }
 
 
+
 /** \brief Update TLE from network.
  *  \param widget The menu item (unused).
  *  \param data User data (unused).
@@ -403,13 +441,15 @@ static void
 menubar_tle_net_cb       (GtkWidget *widget, gpointer data)
 {
 	GtkWidget *dialog;          /* dialog window  */
+#if HAVE_LIBCURL
 	GtkWidget *label;           /* misc labels */
 	GtkWidget *progress;        /* progress indicator */
 	GtkWidget *label1,*label2;  /* activitity and stats labels */
 	GtkWidget *box;
 
 
-	/* create new dialog with progress indicator */
+	
+    /* create new dialog with progress indicator */
 	dialog = gtk_dialog_new_with_buttons (_("TLE Update"),
 										  GTK_WINDOW (app),
 										  GTK_DIALOG_MODAL | 
@@ -480,9 +520,27 @@ menubar_tle_net_cb       (GtkWidget *widget, gpointer data)
 	/* reload satellites */
 	mod_mgr_reload_sats ();
 
+#else
+    
+    dialog = gtk_message_dialog_new (GTK_WINDOW (app),
+                                     GTK_DIALOG_MODAL |
+                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+									 GTK_MESSAGE_ERROR,
+									 GTK_BUTTONS_OK,
+									 _("This version of gpredict has been compiled "\
+									   "without network support. Therefore, TLE update "\
+									   "from network is not available.\n\n"\
+									   "Consult the user manual for details."));
+                              
+    gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+
+#endif
+    
 }
 
 
+
 /** \brief Update TLE from local files.
  *  \param widget The menu item (unused).
  *  \param data User data (unused).
@@ -712,6 +770,20 @@ menubar_help_cb (GtkWidget *widget, gpointer data)
 }
 
 
+static void
+menubar_license_cb (GtkWidget *widget, gpointer data)
+{
+	gpredict_help_show_txt ("COPYING");
+}
+
+
+static void
+menubar_news_cb (GtkWidget *widget, gpointer data)
+{
+	gpredict_help_show_txt ("NEWS");
+}
+
+
 static void
 menubar_about_cb (GtkWidget *widget, gpointer data)
 {
@@ -752,16 +824,16 @@ select_module        ()
 	   add the contents of each .qth file to the list store
 	*/
 	dirname = g_strconcat (g_get_home_dir (),
-			       G_DIR_SEPARATOR_S, ".gpredict2",
-			       G_DIR_SEPARATOR_S, "modules",
-			       NULL);
+						   G_DIR_SEPARATOR_S, ".gpredict2",
+						   G_DIR_SEPARATOR_S, "modules",
+						   NULL);
 	dir = g_dir_open (dirname, 0, &error);
 
 	if (dir) {
 
 		sat_log_log (SAT_LOG_LEVEL_DEBUG,
-			     _("%s:%s: Scanning directory %s for modules."),
-			     __FILE__, __FUNCTION__, dirname);
+					 _("%s:%s: Scanning directory %s for modules."),
+					 __FILE__, __FUNCTION__, dirname);
 
 		while ((filename = g_dir_read_name (dir))) {
 
@@ -772,8 +844,8 @@ select_module        ()
 
 				gtk_list_store_append (liststore, &item);
 				gtk_list_store_set (liststore, &item,
-						    0, buffv[0],
-						    -1);
+									0, buffv[0],
+									-1);
 
 				g_strfreev (buffv);
 
@@ -783,8 +855,8 @@ select_module        ()
 	}
 	else {
 		sat_log_log (SAT_LOG_LEVEL_ERROR,
-			     _("%s:%d: Failed to open module dir %s (%s)"),
-			     __FILE__, __LINE__, dirname, error->message);
+					 _("%s:%d: Failed to open module dir %s (%s)"),
+					 __FILE__, __LINE__, dirname, error->message);
 		g_clear_error (&error);
 	}
 
@@ -794,13 +866,13 @@ select_module        ()
 	if (count < 1) {
 		/* tell user that there are no modules, try "New" instead */
 		dialog = gtk_message_dialog_new (GTK_WINDOW (app),
-						 GTK_DIALOG_MODAL |
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_INFO,
-						 GTK_BUTTONS_OK,
-						 _("You do not have any modules "\
-						   "set up yet. Please use File->New "\
-						   "in order to create a module."));
+										 GTK_DIALOG_MODAL |
+										 GTK_DIALOG_DESTROY_WITH_PARENT,
+										 GTK_MESSAGE_INFO,
+										 GTK_BUTTONS_OK,
+										 _("You do not have any modules "\
+										   "set up yet. Please use File->New "\
+										   "in order to create a module."));
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -817,22 +889,22 @@ select_module        ()
 
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Module"), renderer,
-							   "text", 0,
-							   NULL);
+													   "text", 0,
+													   NULL);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (modlist), column, -1);
 
 	gtk_widget_show (modlist);
 
 	/* create dialog */
 	dialog = gtk_dialog_new_with_buttons (_("Select a module"),
-					      GTK_WINDOW (app),
-					      GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_CANCEL,
-					      GTK_RESPONSE_CANCEL,
-					      GTK_STOCK_OK,
-					      GTK_RESPONSE_OK,
-					      NULL);
+										  GTK_WINDOW (app),
+										  GTK_DIALOG_MODAL |
+										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  GTK_STOCK_CANCEL,
+										  GTK_RESPONSE_CANCEL,
+										  GTK_STOCK_OK,
+										  GTK_RESPONSE_OK,
+										  NULL);
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), -1, 200);
 
@@ -847,17 +919,17 @@ select_module        ()
 
 		if (gtk_tree_selection_get_selected (selection, &selmod, &item)) {
 			gtk_tree_model_get (selmod, &item,
-					    0, &dirname,
-					    -1);
+								0, &dirname,
+								-1);
 
 			sat_log_log (SAT_LOG_LEVEL_DEBUG,
-				     _("%s:%s: Selected module is: %s"),
-				     __FILE__, __FUNCTION__, dirname);
+						 _("%s:%s: Selected module is: %s"),
+						 __FILE__, __FUNCTION__, dirname);
 		}
 		else {
 			sat_log_log (SAT_LOG_LEVEL_BUG,
-				     _("%s:%s: No selection is list of modules."),
-				     __FILE__, __FUNCTION__);
+						 _("%s:%s: No selection is list of modules."),
+						 __FILE__, __FUNCTION__);
 
 			dirname = NULL;
 		}
@@ -876,3 +948,110 @@ select_module        ()
 	return dirname;
 }
 
+
+
+/** \brief Create a module window.
+ *
+ * This function is used to create a module window when opening modules
+ * that should not be packed into the notebook.
+ */
+static void
+create_module_window (GtkWidget *module)
+{
+	gint       w,h;
+	gchar     *icon;      /* icon file name */
+	gchar     *title;     /* window title */
+
+
+	/* get stored size; use size from main window if size not explicitly stoed */
+	if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_WIDTH,
+							NULL)) {
+		w = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+									MOD_CFG_GLOBAL_SECTION,
+									MOD_CFG_WIN_WIDTH,
+									NULL);
+	}
+	else {
+		w = module->allocation.width;
+	}
+	if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_HEIGHT,
+							NULL)) {
+		h = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+									MOD_CFG_GLOBAL_SECTION,
+									MOD_CFG_WIN_HEIGHT,
+									NULL);
+	}
+	else {
+		h = module->allocation.height;
+	}
+        
+	/* increase reference count of module */
+	//g_object_ref (module);
+
+	/* we don't need the positions */
+	//GTK_SAT_MODULE (module)->vpanedpos = -1;
+	//GTK_SAT_MODULE (module)->hpanedpos = -1;
+
+	/* undock from mod-mgr */
+	//mod_mgr_undock_module (module);
+
+	/* create window */
+	GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	title = g_strconcat ("GPREDICT: ",
+						 GTK_SAT_MODULE (module)->name,
+						 " (", GTK_SAT_MODULE (module)->qth->name, ")",
+						 NULL);
+	gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win), title);
+	g_free (title);
+	gtk_window_set_default_size (GTK_WINDOW (GTK_SAT_MODULE (module)->win), w, h);
+	g_signal_connect (G_OBJECT (GTK_SAT_MODULE (module)->win), "configure_event",
+					  G_CALLBACK (module_window_config_cb), module);
+
+	/* window icon */
+	icon = icon_file_name ("gpredict-icon.png");
+	if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+		gtk_window_set_icon_from_file (GTK_WINDOW (GTK_SAT_MODULE (module)->win), icon, NULL);
+	}
+	g_free (icon);
+
+	/* move window to stored position if requested by configuration */
+	if (sat_cfg_get_bool (SAT_CFG_BOOL_MOD_WIN_POS) &&
+		g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_POS_X,
+							NULL) &&
+		g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_POS_Y,
+							NULL)) {
+                
+		gtk_window_move (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
+						 g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+												 MOD_CFG_GLOBAL_SECTION,
+												 MOD_CFG_WIN_POS_X, NULL),
+						 g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+												 MOD_CFG_GLOBAL_SECTION,
+												 MOD_CFG_WIN_POS_Y,
+												 NULL));
+
+	}
+
+	/* add module to window */
+	gtk_container_add (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
+
+	/* show window */
+	gtk_widget_show_all (GTK_SAT_MODULE (module)->win);
+        
+	/* reparent time manager window if visible */
+	if (GTK_SAT_MODULE (module)->tmgActive) {
+		gtk_window_set_transient_for (GTK_WINDOW (GTK_SAT_MODULE (module)->tmgWin),
+									  GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+	}
+
+
+}
+
