@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -51,12 +51,15 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include "gtk-sat-module.h"
+#include "gtk-sat-module-popup.h"
 #include "sat-cfg.h"
 #include "sat-log.h"
 #include "config-keys.h"
 #include "mod-mgr.h"
+#include "mod-cfg.h"
+#include "compat.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 
 /** \brief Main application widget. */
@@ -76,6 +79,8 @@ static void switch_page_cb      (GtkNotebook     *notebook,
 								 guint            page_num,
 								 gpointer         user_data);
 
+static void create_module_window (GtkWidget *module);
+
 
 /** \brief Create and initialise module manger.
  *  \return The main module container widget (GtkNotebook).
@@ -123,7 +128,19 @@ mod_mgr_create (void)
 			module = gtk_sat_module_new (modfile);
 
 			if (IS_GTK_SAT_MODULE (module)) {
-				mod_mgr_add_module (module, TRUE);
+
+				/* if module state was window or user does not want to restore the
+				   state of the modules, pack the module into the notebook */
+				if ((GTK_SAT_MODULE (module)->state == GTK_SAT_MOD_STATE_DOCKED) ||
+					!sat_cfg_get_bool (SAT_CFG_BOOL_MOD_STATE)) {
+
+					mod_mgr_add_module (module, TRUE);
+
+				}
+				else {
+					mod_mgr_add_module (module, FALSE);
+					create_module_window (module);
+				}
 			}
 			else {
 				sat_log_log (SAT_LOG_LEVEL_ERROR,
@@ -321,6 +338,9 @@ mod_mgr_save_state ()
 
 	for (i = 0; i < num; i++) {
 		module = GTK_WIDGET (g_slist_nth_data (modules, i));
+        
+        /* save state of the module */
+        mod_cfg_save (GTK_SAT_MODULE (module)->name, GTK_SAT_MODULE (module)->cfgdata);
 		
 		if (i == 0) {
 			buff = g_strdup (GTK_SAT_MODULE (module)->name);
@@ -587,3 +607,111 @@ mod_mgr_reload_sats    ()
 	}
 
 }
+
+
+
+/** \brief Create a module window.
+ *
+ * This function is used to create a module window when opening modules
+ * that should not be packed into the notebook.
+ */
+static void
+create_module_window (GtkWidget *module)
+{
+	gint       w,h;
+	gchar     *icon;      /* icon file name */
+	gchar     *title;     /* window title */
+
+
+	/* get stored size; use size from main window if size not explicitly stoed */
+	if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_WIDTH,
+							NULL)) {
+		w = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+									MOD_CFG_GLOBAL_SECTION,
+									MOD_CFG_WIN_WIDTH,
+									NULL);
+	}
+	else {
+		w = module->allocation.width;
+	}
+	if (g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_HEIGHT,
+							NULL)) {
+		h = g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+									MOD_CFG_GLOBAL_SECTION,
+									MOD_CFG_WIN_HEIGHT,
+									NULL);
+	}
+	else {
+		h = module->allocation.height;
+	}
+        
+	/* increase reference count of module */
+	//g_object_ref (module);
+
+	/* we don't need the positions */
+	//GTK_SAT_MODULE (module)->vpanedpos = -1;
+	//GTK_SAT_MODULE (module)->hpanedpos = -1;
+
+	/* undock from mod-mgr */
+	//mod_mgr_undock_module (module);
+
+	/* create window */
+	GTK_SAT_MODULE (module)->win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	title = g_strconcat ("GPREDICT: ",
+						 GTK_SAT_MODULE (module)->name,
+						 " (", GTK_SAT_MODULE (module)->qth->name, ")",
+						 NULL);
+	gtk_window_set_title (GTK_WINDOW (GTK_SAT_MODULE (module)->win), title);
+	g_free (title);
+	gtk_window_set_default_size (GTK_WINDOW (GTK_SAT_MODULE (module)->win), w, h);
+	g_signal_connect (G_OBJECT (GTK_SAT_MODULE (module)->win), "configure_event",
+					  G_CALLBACK (module_window_config_cb), module);
+
+	/* window icon */
+	icon = icon_file_name ("gpredict-icon.png");
+	if (g_file_test (icon, G_FILE_TEST_EXISTS)) {
+		gtk_window_set_icon_from_file (GTK_WINDOW (GTK_SAT_MODULE (module)->win), icon, NULL);
+	}
+	g_free (icon);
+
+	/* move window to stored position if requested by configuration */
+	if (sat_cfg_get_bool (SAT_CFG_BOOL_MOD_WIN_POS) &&
+		g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_POS_X,
+							NULL) &&
+		g_key_file_has_key (GTK_SAT_MODULE (module)->cfgdata,
+							MOD_CFG_GLOBAL_SECTION,
+							MOD_CFG_WIN_POS_Y,
+							NULL)) {
+                
+		gtk_window_move (GTK_WINDOW (GTK_SAT_MODULE (module)->win),
+						 g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+												 MOD_CFG_GLOBAL_SECTION,
+												 MOD_CFG_WIN_POS_X, NULL),
+						 g_key_file_get_integer (GTK_SAT_MODULE (module)->cfgdata,
+												 MOD_CFG_GLOBAL_SECTION,
+												 MOD_CFG_WIN_POS_Y,
+												 NULL));
+
+	}
+
+	/* add module to window */
+	gtk_container_add (GTK_CONTAINER (GTK_SAT_MODULE (module)->win), module);
+
+	/* show window */
+	gtk_widget_show_all (GTK_SAT_MODULE (module)->win);
+        
+	/* reparent time manager window if visible */
+	if (GTK_SAT_MODULE (module)->tmgActive) {
+		gtk_window_set_transient_for (GTK_WINDOW (GTK_SAT_MODULE (module)->tmgWin),
+									  GTK_WINDOW (GTK_SAT_MODULE (module)->win));
+	}
+
+
+}
+
