@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
     Parts are Copyright John A. Magliacane, KD2BD 1991-2003 (indicated below)
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
@@ -32,7 +32,7 @@
 #include <glib/gi18n.h>
 #include "sgpsdp/sgp4sdp4.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "gtk-sat-data.h"
 #include "time-tools.h"
@@ -112,6 +112,7 @@ predict_calc (sat_t *sat, qth_t *qth, gdouble t)
  *  \param sat Pointer to the satellite data.
  *  \param qth Pointer to the QTH data.
  *  \param start The time where calculation should start.
+ *  \param maxdt The upper time limit in days (0.0 = no limit)
  *  \return The time of the next AOS or 0.0 if the satellite has no AOS.
  *
  * This function finds the time of AOS for the first coming pass taking place
@@ -119,12 +120,10 @@ predict_calc (sat_t *sat, qth_t *qth, gdouble t)
  * If the satellite is currently within range, the function first calls
  * find_los to get the next LOS time. Then the calculations are done using
  * the new start time.
- * The function has a built-in watchdog to ensure that we don't end up in
- * lengthy loops.
  *
  */
 gdouble
-find_aos (sat_t *sat, qth_t *qth, gdouble start)
+find_aos (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 {
 	gdouble t = start;
 	gdouble aostime = 0.0;
@@ -145,35 +144,72 @@ find_aos (sat_t *sat, qth_t *qth, gdouble start)
 	}
 
 
-	if (sat->el > 0.0) 
-		t = find_los (sat, qth, start) + 0.014; // +20 min
+	if (sat->el > 0.0)
+		t = find_los (sat, qth, start, maxdt) + 0.014; // +20 min
+
+	/* invalid time (potentially returned by find_los) */
+	if (t < 0.014)
+		return 0.0;
 
 	/* update satellite data */
 	predict_calc (sat, qth, t);
 
-	/* coarse time steps */
-	while (sat->el < -1.0) {
+	/* use upper time limit */
+	if (maxdt > 0.0) {
 
-		t -= 0.00035 * (sat->el * ((sat->alt / 8400.0) + 0.46) - 2.0);
-		predict_calc (sat, qth, t);
-	}
+		/* coarse time steps */
+		while ((sat->el < -1.0) && (t <= (start + maxdt))) {
 
-	/* fine steps */
-	while (aostime == 0.0) {
-
-		/* FIXME: should change to el < -0.3?
-		   accuracy seems to be less than +/- 1 sec
-		   except when the sat is around 0.0 EL
-		*/
-		if (fabs (sat->el) < 0.03) {
-			aostime = t;
-		}
-		else {
-			t -= sat->el * sqrt (sat->alt) / 530000.0;
+			t -= 0.00035 * (sat->el * ((sat->alt / 8400.0) + 0.46) - 2.0);
 			predict_calc (sat, qth, t);
 		}
 
+		/* fine steps */
+		while ((aostime == 0.0) && (t <= (start + maxdt))) {
+
+			/* FIXME: should change to el < -0.3?
+			   accuracy seems to be less than +/- 1 sec
+			   except when the sat is around 0.0 EL
+			*/
+			if (fabs (sat->el) < 0.03) {
+				aostime = t;
+			}
+			else {
+				t -= sat->el * sqrt (sat->alt) / 530000.0;
+				predict_calc (sat, qth, t);
+			}
+
+		}
+
 	}
+	/* don't use upper time limit */
+	else {
+
+		/* coarse time steps */
+		while (sat->el < -1.0) {
+
+			t -= 0.00035 * (sat->el * ((sat->alt / 8400.0) + 0.46) - 2.0);
+			predict_calc (sat, qth, t);
+		}
+
+		/* fine steps */
+		while (aostime == 0.0) {
+
+			/* FIXME: should change to el < -0.3?
+			   accuracy seems to be less than +/- 1 sec
+			   except when the sat is around 0.0 EL
+			*/
+			if (fabs (sat->el) < 0.03) {
+				aostime = t;
+			}
+			else {
+				t -= sat->el * sqrt (sat->alt) / 530000.0;
+				predict_calc (sat, qth, t);
+			}
+
+		}
+	}
+
 
 	return aostime;
 }
@@ -185,6 +221,7 @@ find_aos (sat_t *sat, qth_t *qth, gdouble start)
  *  \param sat Pointer to the satellite data.
  *  \param qth Pointer to the QTH data.
  *  \param start The time where calculation should start.
+ *  \param maxdt The upper time limit in days (0.0 = no limit)
  *  \return The time of the next LOS or 0.0 if the satellite has no LOS.
  *
  * This function finds the time of LOS for the first coming pass taking place
@@ -197,7 +234,7 @@ find_aos (sat_t *sat, qth_t *qth, gdouble start)
  *
  */
 gdouble
-find_los (sat_t *sat, qth_t *qth, gdouble start)
+find_los (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 {
 	gdouble t = start;
 	gdouble lostime = 0.0;
@@ -216,26 +253,54 @@ find_los (sat_t *sat, qth_t *qth, gdouble start)
 
 
 	if (sat->el < 0.0)
-		t = find_aos (sat, qth, start) + 0.001; // +1.5 min
+		t = find_aos (sat, qth, start, maxdt) + 0.001; // +1.5 min
+
+	/* invalid time (potentially returned by find_aos) */
+	if (t < 0.01)
+		return 0.0;
 
 	/* update satellite data */
 	predict_calc (sat, qth, t);
 
-	/* coarse steps */
-	while (sat->el >= 1.0) {
-		t += cos((sat->el - 1.0) * de2ra) * sqrt(sat->alt) / 25000.0;
-		predict_calc (sat, qth, t);
+
+	/* use upper time limit */
+	if (maxdt > 0.0) {
+
+		/* coarse steps */
+		while ((sat->el >= 1.0) && (t <= (start + maxdt))) {
+			t += cos((sat->el - 1.0) * de2ra) * sqrt(sat->alt) / 25000.0;
+			predict_calc (sat, qth, t);
+		}
+
+		/* fine steps */
+		while ((lostime == 0.0) && (t <= (start + maxdt)))  {
+			
+			t += sat->el * sqrt(sat->alt)/502500.0;
+			predict_calc (sat, qth, t);
+			
+			if (fabs(sat->el) < 0.03)
+				lostime = t;
+		}
 	}
 
-	/* fine steps */
-	while (lostime == 0.0) {
+	/* don't use upper limit */
+	else {
 
-		t += sat->el * sqrt(sat->alt)/502500.0;
-		predict_calc (sat, qth, t);
-
-		if (fabs(sat->el) < 0.03)
-			lostime = t;
+		/* coarse steps */
+		while (sat->el >= 1.0) {
+			t += cos((sat->el - 1.0) * de2ra) * sqrt(sat->alt) / 25000.0;
+			predict_calc (sat, qth, t);
+		}
 
+		/* fine steps */
+		while (lostime == 0.0) {
+			
+			t += sat->el * sqrt(sat->alt)/502500.0;
+			predict_calc (sat, qth, t);
+			
+			if (fabs(sat->el) < 0.03)
+				lostime = t;
+		}
 	}
 	
 
@@ -389,7 +454,7 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 	*/
 	while (!done) {
 
-		aos = find_aos (sat, qth, t0);
+		aos = find_aos (sat, qth, t0, maxdt);
 
 		/* aos = 0.0 means no aos */
 		if (aos == 0.0) {
@@ -403,7 +468,7 @@ get_pass   (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 			done = TRUE;
 		}
 		else {
-			los = find_los (sat, qth, aos + 0.001); // +1.5 min later
+			los = find_los (sat, qth, aos + 0.001, maxdt); // +1.5 min later
 			dt = los - aos;
 	
 			/* get time step, which will give us the max number of entries */
@@ -805,16 +870,22 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 	tres = sat_cfg_get_int (SAT_CFG_INT_PRED_RESOLUTION) / 86400.0;
 
 
-	aos = find_aos (sat, qth, t0);
+	aos = find_aos (sat, qth, t0, maxdt);
 
+
+	/* aos = 0.0 means no aos */
+	if (aos == 0.0) {
+		done = TRUE;
+	}
+	
 	/* check whether we are within time limits;
 	   maxdt = 0 mean no time limit.
 	*/
-	if ((maxdt > 0.0) && (aos > (start + maxdt))) {
+	else if ((maxdt > 0.0) && (aos > (start + maxdt))) {
 		done = TRUE;
 	}
 	else {
-		los = find_los (sat, qth, aos + 0.001); // +1.5 min later
+		los = find_los (sat, qth, aos + 0.001, maxdt); // +1.5 min later
 		dt = los - aos;
 	
 		/* get time step, which will give us the max number of entries */
@@ -928,6 +999,7 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
 /** \brief Get current pass.
  *  \param sat Pointer to the satellite data.
  *  \param qth Pointer to the QTH data.
+ *  \param start Time to start calculations; use 0.0 for now.
  *  \return Pointer to a newly allocated pass_t structure or NULL if
  *          there was an error.
  *
@@ -937,14 +1009,20 @@ get_pass_no_min_el (sat_t *sat, qth_t *qth, gdouble start, gdouble maxdt)
  * the get_pass_no_min_el function to get the details of the current pass
  * disregarding any minimum elevation requirements.
  *
+ * \note The start parameter has been introduced to allow correct use of this
+ *       function in non-realtime cases.
+ *
  */
 pass_t *
-get_current_pass (sat_t *sat, qth_t *qth)
+get_current_pass (sat_t *sat, qth_t *qth, gdouble start)
 {
 	gdouble t;
 
 
-	t = get_current_daynum ();
+	if (start > 0.0)
+		t = start;
+	else
+		t = get_current_daynum ();
 	predict_calc (sat, qth, t);	
 
 	/* find a time before AOS */
