@@ -34,7 +34,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sat-log.h"
 #include "config-keys.h"
@@ -116,6 +116,9 @@ sat_cfg_bool_t sat_cfg_bool[SAT_CFG_BOOL_NUM] = {
 	{ "GLOBAL",  "USE_LOCAL_TIME",     FALSE},
 	{ "GLOBAL",  "USE_NSEW",           FALSE},
 	{ "GLOBAL",  "USE_IMPERIAL",       FALSE},
+	{ "GLOBAL",  "MAIN_WIN_POS",       FALSE},
+	{ "GLOBAL",  "MOD_WIN_POS",        FALSE},
+    { "GLOBAL",  "MOD_STATE",          FALSE},
 	{ "MODULES", "RULES_HINT",         TRUE},
 	{ "MODULES", "MAP_QTH_INFO",       TRUE},
 	{ "MODULES", "MAP_NEXT_EVENT",     TRUE},
@@ -127,6 +130,7 @@ sat_cfg_bool_t sat_cfg_bool[SAT_CFG_BOOL_NUM] = {
 	{ "MODULES", "POLAR_CURSOR_TRACK", TRUE},
 	{ "TLE",     "SERVER_AUTH",        FALSE},
 	{ "TLE",     "PROXY_AUTH",         FALSE},
+	{ "LOG",     "KEEP_LOG_FILES",     FALSE},
 	{ "MODULES", "POLAR_EXTRA_AZ_TICKS", FALSE}
 };
 
@@ -170,6 +174,8 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
 	{ "PREDICT", "NUMBER_OF_ENTRIES", 20},
 	{ "PREDICT", "SINGLE_PASS_COL", SINGLE_PASS_COL_DEFAULTS},
 	{ "PREDICT", "MULTI_PASS_COL", MULTI_PASS_COL_DEFAULTS},
+	{ "PREDICT", "SAVE_FORMAT", 0},
+	{ "PREDICT", "SAVE_CONTENTS", 0},
 	{ "SKY_AT_GLANCE", "TIME_SPAN_HOURS", 8},
 	{ "SKY_AT_GLANCE", "COLOUR_01", 0x3c46c8},
 	{ "SKY_AT_GLANCE", "COLOUR_02", 0x00500a},
@@ -181,12 +187,16 @@ sat_cfg_int_t sat_cfg_int[SAT_CFG_INT_NUM] = {
 	{ "SKY_AT_GLANCE", "COLOUR_08", 0x0420bf},
 	{ "SKY_AT_GLANCE", "COLOUR_09", 0xa304bf},
 	{ "SKY_AT_GLANCE", "COLOUR_10", 0x04bdbf},
+	{ "GLOBAL",  "WINDOW_POS_X", 0},
+	{ "GLOBAL",  "WINDOW_POS_Y", 0},
 	{ "GLOBAL",  "WINDOW_WIDTH", 700},
 	{ "GLOBAL",  "WINDOW_HEIGHT", 700},
 	{ "GLOBAL",  "HTML_BROWSER_TYPE", 0},
 	{ "TLE",     "AUTO_UPDATE_FREQ", 2},
 	{ "TLE",     "AUTO_UPDATE_ACTION", 1},
-	{ "TLE",     "LAST_UPDATE", 0}
+	{ "TLE",     "LAST_UPDATE", 0},
+	{ "LOG",     "CLEAN_AGE", 0},  /* 0 = Never clean */
+	{ "LOG",     "LEVEL", 4}
 };
 
 
@@ -204,7 +214,8 @@ sat_cfg_str_t sat_cfg_str[SAT_CFG_STR_NUM] = {
 	  "iridium.txt;military.txt;radar.txt;science.txt;weather.txt"},
 	{ "TLE",     "PROXY", NULL},
 	{ "TLE",     "FILE_DIR", NULL},
-	{ "TLE",     "EXTENSION", "*.*"}
+	{ "TLE",     "EXTENSION", "*.*"},
+	{ "PREDICT", "SAVE_DIR", NULL}
 };
         
 
