@@ -38,6 +38,9 @@ typedef enum {
 	SAT_CFG_BOOL_USE_LOCAL_TIME = 0,  /*!< Display local time instead of UTC. */
 	SAT_CFG_BOOL_USE_NSEW,            /*!< Use N, S, E and W instead of sign */
 	SAT_CFG_BOOL_USE_IMPERIAL,        /*!< Use Imperial units instead of Metric */
+	SAT_CFG_BOOL_MAIN_WIN_POS,        /*!< Restore position of main window */
+	SAT_CFG_BOOL_MOD_WIN_POS,         /*!< Restore size and position of module windows */
+    SAT_CFG_BOOL_MOD_STATE,           /*!< Restore module state */
 	SAT_CFG_BOOL_RULES_HINT,          /*!< Enable rules hint in GtkSatList. */
 	SAT_CFG_BOOL_MAP_SHOW_QTH_INFO,   /*!< Show QTH info on map */
 	SAT_CFG_BOOL_MAP_SHOW_NEXT_EV,    /*!< Show next event on map */
@@ -50,6 +53,7 @@ typedef enum {
   	SAT_CFG_BOOL_POL_SHOW_EXTRA_AZ_TICKS, /*!< Extra Az ticks at every 30 deg. */
 	SAT_CFG_BOOL_TLE_SERVER_AUTH,     /*!< TLE server requires authentication. */
 	SAT_CFG_BOOL_TLE_PROXY_AUTH,      /*!< Proxy requires authentication. */
+	SAT_CFG_BOOL_KEEP_LOG_FILES,      /*!< Whether to keep old log files */
 	SAT_CFG_BOOL_NUM                  /*!< Number of boolean parameters */
 } sat_cfg_bool_e;
 
@@ -93,6 +97,8 @@ typedef enum {
 	SAT_CFG_INT_PRED_NUM_ENTRIES,     /*!< Number of entries in single pass. */
 	SAT_CFG_INT_PRED_SINGLE_COL,      /*!< Visible columns in single-pass dialog */
 	SAT_CFG_INT_PRED_MULTI_COL,       /*!< Visible columns in multi-pass dialog */
+	SAT_CFG_INT_PRED_SAVE_FORMAT,     /*!< Last used save format for predictions */
+	SAT_CFG_INT_PRED_SAVE_CONTENTS,   /*!< Last selection for save file contents */
 	SAT_CFG_INT_SKYATGL_TIME,         /*!< Time span for sky at a glance predictions */
 	SAT_CFG_INT_SKYATGL_COL_01,       /*!< Colour 1 in sky at a glance predictions */
 	SAT_CFG_INT_SKYATGL_COL_02,       /*!< Colour 2 in sky at a glance predictions */
@@ -104,12 +110,16 @@ typedef enum {
 	SAT_CFG_INT_SKYATGL_COL_08,       /*!< Colour 8 in sky at a glance predictions */
 	SAT_CFG_INT_SKYATGL_COL_09,       /*!< Colour 9 in sky at a glance predictions */
 	SAT_CFG_INT_SKYATGL_COL_10,       /*!< Colour 10 in sky at a glance predictions */
+	SAT_CFG_INT_WINDOW_POS_X,         /*!< Main window X during last session */
+	SAT_CFG_INT_WINDOW_POS_Y,         /*!< Main window Y during last session */
 	SAT_CFG_INT_WINDOW_WIDTH,         /*!< Main window width during last session */
 	SAT_CFG_INT_WINDOW_HEIGHT,        /*!< Main window height during last session */
 	SAT_CFG_INT_WEB_BROWSER_TYPE,     /*!< Web browser type, see browser_type_t */
 	SAT_CFG_INT_TLE_AUTO_UPD_FREQ,    /*!< TLE auto-update frequency. */
 	SAT_CFG_INT_TLE_AUTO_UPD_ACTION,  /*!< TLE auto-update action. */
 	SAT_CFG_INT_TLE_LAST_UPDATE,      /*!< Date and time of last update, Unix seconds. */
+	SAT_CFG_INT_LOG_CLEAN_AGE,        /*!< Age of log file to delete (seconds) */
+	SAT_CFG_INT_LOG_LEVEL,            /*!< Logging level */
 	SAT_CFG_INT_NUM                   /*!< Number of integer parameters. */
 } sat_cfg_int_e;
 
@@ -129,6 +139,7 @@ typedef enum {
 	SAT_CFG_STR_TLE_PROXY,      /*!< Proxy server. */
 	SAT_CFG_STR_TLE_FILE_DIR,   /*!< Local directory from which tle were last updated. */
 	SAT_CFG_STR_TLE_FILE_EXT,   /*!< File extensions. */
+	SAT_CFG_STR_PRED_SAVE_DIR,  /*!< Last used save directory for pass predictions */
 	SAT_CFG_STR_NUM             /*!< Number of string parameters */
 } sat_cfg_str_e;
 
