@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -34,7 +34,7 @@
 #include "gpredict-utils.h"
 #include "sat-log.h"
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "compat.h"
 #include "locator.h"
@@ -45,9 +45,13 @@
 #include "sat-pass-dialogs.h"
 #include "gtk-polar-plot.h"
 #include "gtk-azel-plot.h"
+#include "save-pass.h"
 
 
 
+#define RESPONSE_PRINT 10
+#define RESPONSE_SAVE  11
+
 
 /** \brief Column titles for multi-pass lists */
 const gchar *MULTI_PASS_COL_TITLE[MULTI_PASS_COL_NUMBER] = {
@@ -237,6 +241,8 @@ static void       view_popup_menu (GtkWidget *treeview,
 static void Calc_RADec (gdouble jul_utc, gdouble saz, gdouble sel,
 						qth_t *qth, obs_astro_t *obs_set);
 
+static void single_pass_response (GtkWidget *dialog, gint response, gpointer data);
+static void multi_pass_response (GtkWidget *dialog, gint response, gpointer data);
 
 
 /** \brief Show details about a satellite pass.
@@ -484,21 +490,30 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 	dialog = gtk_dialog_new_with_buttons (title,
 										  GTK_WINDOW (toplevel),
 										  GTK_DIALOG_DESTROY_WITH_PARENT,
-										  GTK_STOCK_CLOSE,
-										  GTK_RESPONSE_ACCEPT,
+										  //GTK_STOCK_PRINT, RESPONSE_PRINT,
+										  GTK_STOCK_SAVE, RESPONSE_SAVE,
+										  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 										  NULL);
 	g_free (title);
 
-	/*** FIXME: set list-like window icon */
+	/* Make Close button default */
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
+
+	/* window icon */
+	buff = icon_file_name ("gpredict-sat-list.png");
+	gtk_window_set_icon_from_file (GTK_WINDOW (dialog), buff, NULL);
+	g_free (buff);
 
 	/* allow interaction with other windows */
 	gtk_window_set_modal (GTK_WINDOW (dialog), FALSE);
 
+	g_object_set_data (G_OBJECT (dialog), "sat", (gpointer) satname);
+	g_object_set_data (G_OBJECT (dialog), "qth", qth);
 	g_object_set_data (G_OBJECT (dialog), "pass", pass);
 
 
 	g_signal_connect (dialog, "response",
-					  G_CALLBACK (gtk_widget_destroy), NULL);
+					  G_CALLBACK (single_pass_response), NULL);
  	g_signal_connect (dialog, "destroy",
 					  G_CALLBACK (single_pass_dialog_destroy), NULL);
 	g_signal_connect (dialog, "delete_event",
@@ -513,6 +528,35 @@ show_pass (const gchar *satname, qth_t *qth, pass_t *pass, GtkWidget *toplevel)
 }
 
 
+/** \brief Manage button responses for single-pass dialogues.
+ *  \param dialog The dialog widget.
+ *  \param response The ID of the response signal, i.e. the pressed button.
+ *  \param data User data (currently NULL).
+ *
+ * Use sat, qth, and passes labels to obtain the relevant data
+ *
+ */
+static void
+single_pass_response (GtkWidget *dialog, gint response, gpointer data)
+{
+
+	switch (response) {
+
+	case RESPONSE_PRINT:
+		break;
+
+	case RESPONSE_SAVE:
+		save_pass (dialog);
+		break;
+
+		/* Close button or delete events */
+	default:
+		gtk_widget_destroy (dialog);
+		break;
+	}
+}
+
+
 
 /** \brief Set cell renderer function. */
 static void
@@ -939,6 +983,7 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 	guint              flags;
 	guint              i, num;
 	pass_t            *pass = NULL; 
+	gchar             *buff;
 
 
 
@@ -1010,9 +1055,6 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 							-1);
 
 
-		//MULTI_PASS_COL_VIS
-
-			    
 	}
 
 	/* connect model to tree view */
@@ -1046,21 +1088,30 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 	dialog = gtk_dialog_new_with_buttons (title,
 										  GTK_WINDOW (toplevel),
 										  GTK_DIALOG_DESTROY_WITH_PARENT,
+										  //GTK_STOCK_PRINT, RESPONSE_PRINT,
+										  GTK_STOCK_SAVE, RESPONSE_SAVE,
 										  GTK_STOCK_CLOSE,
-										  GTK_RESPONSE_ACCEPT,
+										  GTK_RESPONSE_CLOSE,
 										  NULL);
 	g_free (title);
 
-	/*** FIXME: set list-like window icon */
+	/* Make Close button default */
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
+
+	/* window icon */
+	buff = icon_file_name ("gpredict-sat-list.png");
+	gtk_window_set_icon_from_file (GTK_WINDOW (dialog), buff, NULL);
+	g_free (buff);
 
 	/* allow interaction with other windows */
 	gtk_window_set_modal (GTK_WINDOW (dialog), FALSE);
 
+	g_object_set_data (G_OBJECT (dialog), "sat", (gpointer) satname);
+	g_object_set_data (G_OBJECT (dialog), "qth", qth);
 	g_object_set_data (G_OBJECT (dialog), "passes", passes);
 
-
 	g_signal_connect (dialog, "response",
-					  G_CALLBACK (gtk_widget_destroy), NULL);
+					  G_CALLBACK (multi_pass_response), NULL);
  	g_signal_connect (dialog, "destroy",
 					  G_CALLBACK (multi_pass_dialog_destroy), NULL);
 	g_signal_connect (dialog, "delete_event",
@@ -1076,6 +1127,35 @@ show_passes (const gchar *satname, qth_t *qth, GSList *passes, GtkWidget *toplev
 }
 
 
+/** \brief Manage button responses for multi-pass dialogues.
+ *  \param dialog The dialog widget.
+ *  \param response The ID of the response signal, i.e. the pressed button.
+ *  \param data User data (currently NULL).
+ *
+ * Use sat, qth, and passes labels to obtain the relevant data
+ *
+ */
+static void
+multi_pass_response (GtkWidget *dialog, gint response, gpointer data)
+{
+	switch (response) {
+
+	case RESPONSE_PRINT:
+		break;
+
+	case RESPONSE_SAVE:
+		save_passes (dialog);
+		break;
+
+		/* Close button or delete events */
+	default:
+		gtk_widget_destroy (dialog);
+		break;
+	}
+}
+
+
+
 static gint
 multi_pass_dialog_delete  (GtkWidget *dialog, GdkEvent *event, gpointer pass)
 {
@@ -1083,6 +1163,7 @@ multi_pass_dialog_delete  (GtkWidget *dialog, GdkEvent *event, gpointer pass)
 	return FALSE;
 }
 
+
 static void
 multi_pass_dialog_destroy (GtkWidget *dialog, gpointer data)
 {
@@ -1090,6 +1171,7 @@ multi_pass_dialog_destroy (GtkWidget *dialog, gpointer data)
 
 	free_passes (passes);
 
+
 	gtk_widget_destroy (dialog);
 }
 
