@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -30,7 +30,7 @@
 #include <time.h>
 //#include <sys/time.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sat-cfg.h"
 #include "sat-pref-qth.h"
@@ -197,7 +197,6 @@ tfprev_cb (gpointer data)
 	//struct timezone tzone;
 	GTimeVal tval;
 	time_t t;
-	gint x;
 	guint size;
 	gchar buff[TIME_FORMAT_MAX_LENGTH+1];
 
