@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sat-pref-general.h"
 #include "sat-pref-formats.h"
@@ -59,9 +59,9 @@ GtkWidget *sat_pref_general_create ()
 	gtk_notebook_append_page (GTK_NOTEBOOK (nbook),
 				  sat_pref_tle_create (),
 				  gtk_label_new (_("TLE Update")));
-/* 	gtk_notebook_append_page (GTK_NOTEBOOK (nbook), */
-/* 				  sat_pref_debug_create (), */
-/* 				  gtk_label_new (_("Messages"))); */
+	gtk_notebook_append_page (GTK_NOTEBOOK (nbook),
+				  sat_pref_debug_create (),
+				  gtk_label_new (_("Message Logs")));
 /* 	gtk_notebook_append_page (GTK_NOTEBOOK (nbook), */
 /* 				  sat_pref_help_create (), */
 /* 				  gtk_label_new (_("Help System"))); */
@@ -78,8 +78,8 @@ sat_pref_general_cancel ()
 	sat_pref_formats_cancel ();
 	sat_pref_qth_cancel ();
 	sat_pref_tle_cancel ();
-/* 	sat_pref_debug_cancel (); */
-	sat_pref_help_cancel ();
+	sat_pref_debug_cancel ();
+	//sat_pref_help_cancel ();
 }
 
 
@@ -91,8 +91,8 @@ sat_pref_general_ok     ()
 	sat_pref_formats_ok ();
 	sat_pref_qth_ok ();
 	sat_pref_tle_ok ();
-/* 	sat_pref_debug_ok (); */
-	sat_pref_help_ok ();
+	sat_pref_debug_ok ();
+	//sat_pref_help_ok ();
 }
 
 
