@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sat-cfg.h"
 #include "mod-cfg-get-param.h"
