@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -29,7 +29,7 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "gpredict-utils.h"
 #include "sat-cfg.h"
@@ -78,10 +78,10 @@ static void add_cb    (GtkWidget *button, gpointer data);
 static void edit_cb   (GtkWidget *button, gpointer data);
 static void delete_cb (GtkWidget *button, gpointer data);
 
-static gboolean check_and_set_default_qth (GtkTreeModel *model,
-										   GtkTreePath  *path,
-										   GtkTreeIter  *iter,
-										   gpointer      data);
+/* static gboolean check_and_set_default_qth (GtkTreeModel *model, */
+/* 										   GtkTreePath  *path, */
+/* 										   GtkTreeIter  *iter, */
+/* 										   gpointer      data); */
 
 static gboolean save_qth (GtkTreeModel *model,
 						  GtkTreePath  *path,
@@ -781,7 +781,8 @@ float_cell_data_function (GtkTreeViewColumn *col,
 }
 
 
-
+/* function below not used */
+#if 0
 /** \brief Callback function to check each QTH for beeing the default */
 static gboolean
 check_and_set_default_qth (GtkTreeModel *model,
@@ -814,7 +815,7 @@ check_and_set_default_qth (GtkTreeModel *model,
 
 	return FALSE;
 }
-
+#endif
 
 /** \brief save a row from the QTH list (called by the save function) */
 static gboolean
