@@ -2,7 +2,7 @@
 /*
   Gpredict: Real-time satellite tracking and orbit prediction program
 
-  Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+  Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
   Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "tle-update.h"
 #include "sat-cfg.h"
@@ -46,7 +46,7 @@ static GtkWidget *server,*proxy,*files;
 
 
 /* book keeping */
-static tle_auto_upd_freq_t auto_freq = TLE_AUTO_UPDATE_NEVER;
+/* static tle_auto_upd_freq_t auto_freq = TLE_AUTO_UPDATE_NEVER; */
 static gboolean dirty = FALSE;  /* used to check whether any changes have occurred */
 static gboolean reset = FALSE;
 
