@@ -2,7 +2,7 @@
 /*
     Gpredict: Real-time satellite tracking and orbit prediction program
 
-    Copyright (C)  2001-2006  Alexandru Csete, OZ9AEC.
+    Copyright (C)  2001-2007  Alexandru Csete, OZ9AEC.
 
     Authors: Alexandru Csete <csete@users.sourceforge.net>
 
@@ -30,7 +30,7 @@
 #include <glib/gi18n.h>
 //#include <sys/time.h>
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#  include <build-config.h>
 #endif
 #include "sgpsdp/sgp4sdp4.h"
 #include "time-tools.h"
